IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'adfBusinessCardBrowse')
	BEGIN
		PRINT 'Dropping Procedure adfBusinessCardBrowse'
		DROP  Procedure  adfBusinessCardBrowse
	END

GO

PRINT 'Creating Procedure adfBusinessCardBrowse'
GO
/******************************************************************************
**		File: 
**		Name: adfBusinessCardBrowse
**		Desc: 
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		13/03/2010	SPV				    
**									  
**		20.01.2011	MAN				  
**		15.12.11	PAM				      
**		17.02.12	DAV				  
**		13.03.12	PAM				     
*******************************************************************************/
CREATE Procedure adfBusinessCardBrowse
	@Subset varchar(32),
	@ActiveEmployee bit = 1,
	@NotActiveEmployee int = 2
AS
	SET NOCOUNT ON

	DECLARE
		@ManageCompanies	TBool,
		@ViewAllCompanies	TBool,
		@ManageContacts		TBool,
		@ViewAllContacts	TBool,
		@ViewEmployees		TBool

	SET @ManageCompanies	= dbo.adfHasAccessRightByName('ManageCompanies')
	SET @ViewAllCompanies	= dbo.adfHasAccessRightByName('ViewAllCompanies')
	SET @ManageContacts		= dbo.adfHasAccessRightByName('ManageContacts')
	SET @ViewAllContacts	= dbo.adfHasAccessRightByName('ViewAllContacts')
	SET @ViewEmployees      = dbo.adfHasAccessRightByName('ViewEmployee')

	IF @Subset = 'Own' 
	BEGIN
		SELECT
			[Company].[ID],
			[Company].[Class],
			1 as [ImageIndex],
			[Company].[State],
			[Company].[FileAs],
			NULL as [CompanyID],
			NULL as [PositionID],
			NULL as [Position],
			[FileAs] as [Company],
			[Company].[Created],
			[Company].[CreatedBy],
			[Company].[Modified],
			[Company].[ModifiedBy],
			[Company].[Timestamp]
		FROM
			[Company]
		WHERE
			(@ManageCompanies = 1 OR @ViewAllCompanies = 1)
			AND
			[Company].[State] = 1 AND [Company].[Own] = 1
		UNION ALL				
		SELECT
			[Employee].[ID],
			[Employee].[Class],
			2 as [ImageIndex],
			[Employee].[State],
			[Employee].[FileAs],
			[Employee].[CompanyID],
			[Employee].[PositionID],
			(SELECT [FileAs] FROM [Position] WHERE [ID] = [Employee].[PositionID]) as [Position],
			(SELECT [FileAs] FROM [Company] WHERE [ID] = [Employee].[CompanyID]) as [Company],
			[Employee].[Created],
			[Employee].[CreatedBy],
			[Employee].[Modified],
			[Employee].[ModifiedBy],
			[Employee].[Timestamp]
		FROM
			[Employee]
			INNER JOIN [Company]
				ON ([Employee].[CompanyID] = [Company].[ID] AND [Company].[Own] = 1 AND [Company].[State]=1)
		WHERE
			((([Employee].[State] = 1 OR @ActiveEmployee = 0) AND @NotActiveEmployee = 2)
			OR
			([Employee].[State] = 1 AND @NotActiveEmployee = 0)
			OR
			([Employee].[State] = 2 AND @NotActiveEmployee = 1))
			AND
			(@ViewEmployees = 1)
	END
	ELSE IF @Subset = 'All'
	BEGIN
		SELECT
			[Company].[ID],
			[Company].[Class],
			1 as [ImageIndex],
			[Company].[State],
			[Company].[FileAs],
			NULL as [CompanyID],
			NULL as [PositionID],
			NULL as [Position],
			[FileAs] as [Company],
			[Company].[Created],
			[Company].[CreatedBy],
			[Company].[Modified],
			[Company].[ModifiedBy],
			[Company].[Timestamp]
		FROM
			[Company]
		WHERE
			(@ManageCompanies = 1 OR @ViewAllCompanies = 1)
			AND
			[Company].[State] = 1
		UNION ALL				
		SELECT
			[Employee].[ID],
			[Employee].[Class],
			2 as [ImageIndex],
			[Employee].[State],
			[Employee].[FileAs],
			[Employee].[CompanyID],
			[Employee].[PositionID],
			(SELECT [FileAs] FROM [Position] WHERE [ID] = [Employee].[PositionID]) as [Position],
			(SELECT [FileAs] FROM [Company] WHERE [ID] = [Employee].[CompanyID]) as [Company],
			[Employee].[Created],
			[Employee].[CreatedBy],
			[Employee].[Modified],
			[Employee].[ModifiedBy],
			[Employee].[Timestamp]
		FROM
			[Employee]
			LEFT OUTER JOIN  [Company]
				ON ([Employee].[CompanyID] = [Company].[ID] AND [Company].[State]=1)
		WHERE
		(
			(([Employee].[CompanyID] IS NULL OR [Company].[Own] = 0) AND (@ManageContacts = 1 OR @ViewAllContacts = 1))
			OR
			([Company].[Own] = 1 AND @ViewEmployees = 1)
		)
		AND
		[Employee].[State] = 1 OR @ActiveEmployee = 0
	END
	ELSE IF @Subset = 'Private'
	BEGIN
		DECLARE @UserID TIdentifier
		
		SET @UserID = dbo.adfGetCurrentUserID()
		
		SELECT
			[Company].[ID],
			[Company].[Class],
			1 as [ImageIndex],
			[Company].[State],
			[Company].[FileAs],
			NULL as [CompanyID],
			NULL as [PositionID],
			NULL as [Position],
			[FileAs] as [Company],
			[Company].[Created],
			[Company].[CreatedBy],
			[Company].[Modified],
			[Company].[ModifiedBy],
			[Company].[Timestamp]
		FROM
			[Company] INNER JOIN [UserContact]
				ON ([Company].[Class] = [UserContact].[BusinessCardClass] AND 
					[Company].[ID] = [UserContact].[BusinessCardID] AND
					[UserContact].[UserID] = @UserID)
		WHERE
			(@ManageCompanies = 1 OR @ViewAllCompanies = 1)
			AND
			[Company].[State] = 1
		UNION ALL	
		SELECT
			[Employee].[ID],
			[Employee].[Class],
			2 as [ImageIndex],
			[Employee].[State],
			[Employee].[FileAs],
			[Employee].[CompanyID],
			[Employee].[PositionID],
			(SELECT [FileAs] FROM [Position] WHERE [ID] = [Employee].[PositionID]) as [Position],
			(SELECT [FileAs] FROM [Company] WHERE [ID] = [Employee].[CompanyID]) as [Company],
			[Employee].[Created],
			[Employee].[CreatedBy],
			[Employee].[Modified],
			[Employee].[ModifiedBy],
			[Employee].[Timestamp]
		FROM
			[Employee]
			LEFT OUTER JOIN [Company]
				ON ([Employee].[CompanyID] = [Company].[ID] AND [Company].[State]=1)
			INNER JOIN [UserContact]
				ON ([Employee].[Class] = [UserContact].[BusinessCardClass] AND 
					[Employee].[ID] = [UserContact].[BusinessCardID] AND
					[UserContact].[UserID] = @UserID)
		WHERE
		(
			(([Employee].[CompanyID] IS NULL OR [Company].[Own] = 0) AND (@ManageContacts = 1 OR @ViewAllContacts = 1))
			OR
			([Company].[Own] = 1 AND @ViewEmployees = 1)
		)
		AND
		[Employee].[State] = 1 OR @ActiveEmployee = 0
	END
	/*
	END
	ELSE
		SELECT
				NULL as [ID],
				NULL as [Class],
				NULL as [ImageIndex],
				NULL as [State],
				NULL as [FileAs],
				NULL as [CompanyID],
				NULL as [PositionID],
				NULL as [Position],
				NULL as  [Company],
				NULL as [Created],
				NULL as [CreatedBy],
				NULL as [Modified],
				NULL as [ModifiedBy],
				NULL as [Timestamp]
		WHERE
			1=2
	*/
	RETURN 0
GO

GRANT EXEC ON adfBusinessCardBrowse TO PUBLIC
GO
