IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'adfBusinessCardCreate')
	BEGIN
		PRINT 'Dropping Procedure adfBusinessCardCreate'
		DROP  Procedure  adfBusinessCardCreate
	END

GO

PRINT 'Creating Procedure adfBusinessCardCreate'
GO
/******************************************************************************
**		File: 
**		Name: adfBusinessCardCreate
**		Desc: 
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE Procedure adfBusinessCardCreate
	@doc			INT,
	@XPathRoot		nvarchar(256),
	@ID				TIdentifier,
	@Class			TClass,
	@State			TState,
	@FileAs			TName,
	@Comments		TNotes,
	@CompanyID		TIdentifier,
	@PositionID		TIdentifier,
	@ExternalID		TExternalIdentifier,
	@LastContact	TDate,
	@NextContact	TDate
AS
	DECLARE @XPath nvarchar(256),
			@result INT
			
	SET NOCOUNT ON

	INSERT INTO [BusinessCard]
		([ID], [Class], [Flag], [State], [FileAs], [Comments], [CompanyID], [PositionID], [ExternalID],
		[LastContact], [NextContact])
	VALUES
		(@ID, @Class, 0, @State, @FileAs, @Comments, @CompanyID, @PositionID, @ExternalID,
		@LastContact, @NextContact)
	IF @@error != 0
		RETURN 1
	
	SET @XPath = @XPathRoot + N'/Phone'
	
	INSERT INTO [Phone] 
		([BusinessCardID], [BusinessCardClass], [PhoneTypeID], [Phone])
	SELECT
		@ID,
		@Class,
		[PhoneTypeID],
		[Phone]
	FROM
		OPENXML(@doc, @XPath, 2)
			WITH ([PhoneTypeID] INT, [Phone] varchar(50))
			
	IF @@error != 0
		RETURN 1
		
	SET @XPath = @XPathRoot + N'/Address'
	INSERT INTO [Address]
		([BusinessCardID], [BusinessCardClass], [AddressTypeID], [Street], [City], [Region], 
		[PostalCode], [Country], [Mail])
	SELECT
		@ID,
		@Class,
		[AddressTypeID],
		[Street],
		[City],
		[Region],
		[PostalCode],
		[Country],
		(CASE WHEN [Mail]='false' THEN 0 ELSE 1 END)
	FROM
		OPENXML(@doc, @XPath, 2)
			WITH (
				[AddressTypeID] INT,
				[Street] nvarchar(256),
				[City] nvarchar(50),
				[Region] nvarchar(256),
				[PostalCode] varchar(10),
				[Country] nvarchar(256),
				[Mail] varchar(5)
				)
	IF @@error != 0
		RETURN 1

	SET @XPath = @XPathRoot + N'/Email'
	INSERT INTO [Email]
		([BusinessCardID], [BusinessCardClass], [EmailTypeID], [Email], [DisplayAs])
	SELECT
		@ID,
		@Class,
		[EmailTypeID],
		[Email],
		[Email]
	FROM
		OPENXML(@doc, @XPath, 2)
			WITH (
				[EmailTypeID] INT,
				[Email] nvarchar(256)
				)
	IF @@error != 0
		RETURN 1

	RETURN 0
GO

