IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[adfServiceCPWProjectsBrowse]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure adfServiceCPWProjectsBrowse'
		DROP PROCEDURE [dbo].adfServiceCPWProjectsBrowse
	END
GO

PRINT 'Creating procedure adfServiceCPWProjectsBrowse'
GO

/******************************************************************************
**		File: adfServiceCPWProjectsBrowse.sql
**		Name: adfServiceCPWProjectsBrowse
**		Desc:         ""
**				   
**		Author: Maria Bastrakova
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		26.11.12	SAP				        
*******************************************************************************/
CREATE PROCEDURE [dbo].[adfServiceCPWProjectsBrowse]
	@CostCentersXML				XML,
	@ProjectManagerXML			XML,
	@CustomerXML				XML,
	@ProjectCategoriesXML		XML,
	@CurrencyCode				NCHAR(4),
	@WithEmptyCostCenter		INT,
	@WithEmptyManager			INT,
	@WithEmptyCustomer			INT,
	@WithEmptyProjectCategories	INT
		
AS
	SET NOCOUNT ON
	
	DECLARE 
		@CostCenters		INT, 
		@ProjectManager		INT, 
		@Customer			INT,
		@ProjectCategories	INT
	
	EXEC sp_xml_preparedocument @CostCenters		OUTPUT, @CostCentersXML
	EXEC sp_xml_preparedocument @ProjectManager		OUTPUT, @ProjectManagerXML
	EXEC sp_xml_preparedocument @Customer			OUTPUT, @CustomerXML
	EXEC sp_xml_preparedocument @ProjectCategories	OUTPUT, @ProjectCategoriesXML
		
	SELECT
		[Project].[ID],
		[Project].[Number],
		[Project].[FileAs],
		[ServiceAssignment].[ID] AS [AssignmentID],
		[ServiceAssignment].[Price] AS [CurrentPrice],
		[ServiceAssignment].[FileAs] AS [ServiceName],
		[ServiceAssignment].[ServiceID],
		[Service].[Code] AS [ServiceCode]
	FROM
		[Project] 
		INNER JOIN [ServiceAssignment] 
			ON ([Project].[ID] = [ServiceAssignment].[ProjectID])
		LEFT OUTER JOIN [DocumentCategory]
			ON ([Project].[Class] = [DocumentCategory].[DocumentClass] AND [Project].[ID] = [DocumentCategory].[DocumentID])
		LEFT JOIN [Service]
			ON [Service].[ID] = [ServiceAssignment].[ServiceID]
			
	WHERE
	([Project].[CostCenterID] IN (SELECT [CentersTable].[ID] 
								   FROM OPENXML (@CostCenters, '/CostCenters/CostCenter', 2) 
								   WITH ([ID] INT) AS [CentersTable]) OR 
	(@WithEmptyCostCenter = 1 AND 
		(([Project].[CostCenterID] IS NULL) OR
		  [Project].[CostCenterID] IN (SELECT [CentersTable].[ID] 
									   FROM OPENXML(@CostCenters, '/CostCenters/CostCenter', 2) 
									   WITH ([ID] int) AS [CentersTable]))))

	AND 
	
	([Project].[ProjectManagerEmployeeID] IN (SELECT [ManagersTable].[ID] 
											   FROM OPENXML(@ProjectManager, '/Managers/Manager', 2) 
											   WITH ([ID] int) AS [ManagersTable]) OR 
	(@WithEmptyManager = 1 AND (([Project].[ProjectManagerEmployeeID]  IS NULL) OR 
		[Project].[ProjectManagerEmployeeID] IN (SELECT [ManagersTable].[ID] 
												 FROM OPENXML(@ProjectManager, '/Managers/Manager', 2) 
												 WITH ([ID] int) AS [ManagersTable]))))
	AND 
	
	([Project].[CustomerCompanyID] IN (SELECT [CustomersTable].[ID] 
										FROM OPENXML(@Customer, '/Customers/Customer', 2) 
										WITH ([ID] int) AS [CustomersTable]) OR 
	(@WithEmptyCustomer = 1 AND (([Project].[CustomerCompanyID] IS NULL) OR 
		[Project].[CustomerCompanyID] IN (SELECT [CustomersTable].[ID] 
										  FROM OPENXML(@Customer, '/Customers/Customer', 2) 
										  WITH ([ID] int) AS [CustomersTable]))))
	AND

	([DocumentCategory].[CategoryID] IN (SELECT [ProjectCategories].[ID] 
										  FROM OPENXML(@ProjectCategories, '/ProjectCategories/ProjectCategory', 2) 
										  WITH ([ID] int) AS [ProjectCategories]) OR 
	(@WithEmptyProjectCategories = 1 AND (([DocumentCategory].[CategoryID] IS NULL) OR 
		[DocumentCategory].[CategoryID] IN (SELECT [ProjectCategories].[ID] 
										    FROM OPENXML(@ProjectCategories, '/ProjectCategories/ProjectCategory', 2) 
											WITH ([ID] int) AS [ProjectCategories]))))

	AND
	(((@CurrencyCode <> 'NULL') AND ([Project].[CurrencyCode] = @CurrencyCode)) OR (@CurrencyCode = 'NULL'))
	AND ([Project].[State] = 2) AND ([ServiceAssignment].[State] = 1)
		
	IF @@ERROR != 0
	BEGIN
		EXEC sp_xml_removedocument @CostCenters
		EXEC sp_xml_removedocument @ProjectManager
		EXEC sp_xml_removedocument @Customer
		EXEC sp_xml_removedocument @ProjectCategories
		RETURN 1
	END

	EXEC sp_xml_removedocument @CostCenters
	EXEC sp_xml_removedocument @ProjectManager
	EXEC sp_xml_removedocument @Customer
	EXEC sp_xml_removedocument @ProjectCategories

	RETURN 0
GO

GRANT EXECUTE ON [adfServiceCPWProjectsBrowse] TO PUBLIC
GO
 
