IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'adfSecurityImport')
	BEGIN
		PRINT 'Dropping Procedure adfSecurityImport'
		DROP  Procedure  adfSecurityImport
	END

GO

PRINT 'Creating Procedure adfSecurityImport'
GO
/******************************************************************************
**		File: 
**		Name: adfSecurityImport
**		Desc: 
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE Procedure adfSecurityImport
	@XML XML
AS
	DECLARE @hdoc INT, @result INT, @pic varbinary(8000)
	SET NOCOUNT ON
	
	EXEC sp_xml_preparedocument @hdoc OUTPUT, @XML
	
	/* Import rights */
	DECLARE rights_cursor CURSOR LOCAL FAST_FORWARD READ_ONLY FOR
	SELECT 
		[ID], [Name], [DisplayName], [Comments], [Group]
	FROM 
		OPENXML(@hdoc, '/SecurityDataSet/Right', 2)
			WITH (	[ID] INT, 
					[Name] nvarchar(128), 
					[DisplayName] nvarchar(256), 
					[Comments] nvarchar(max), 
					[Group] nvarchar(128)
					)
	OPEN rights_cursor
	DECLARE @rID INT,
			@rName nvarchar(128),
			@rDisplayName nvarchar(256),
			@rComments nvarchar(max),
			@rGroup nvarchar(128)
	
	BEGIN TRANSACTION

	FETCH NEXT FROM rights_cursor INTO @rID, @rName, @rDisplayName, @rComments, @rGroup
	WHILE @@FETCH_STATUS = 0
	BEGIN
		IF EXISTS(SELECT * FROM [Right] WHERE [Name]=@rName)
		BEGIN
			UPDATE 
				[Right]
			SET
				[Name] = @rName,
				[DisplayName] = @rDisplayName,
				[Comments] = @rComments,
				[Group] = @rGroup
			WHERE
				[Right].[Name] = @rName
			IF @@ERROR != 0 GOTO ERROR_HANDLER
		END
		ELSE
		BEGIN
			INSERT INTO [Right]
				([Name], [DisplayName], [Comments], [Group])
			VALUES
				(@rName, @rDisplayName, @rComments, @rGroup)
			IF @@ERROR != 0 GOTO ERROR_HANDLER
		END
		FETCH NEXT FROM rights_cursor INTO @rID, @rName, @rDisplayName, @rComments, @rGroup
	END
	
	COMMIT TRANSACTION
	
	CLOSE rights_cursor
	DEALLOCATE rights_cursor
	
	DELETE [RightGlobal]
	
	INSERT [RightGlobal]
		([ID], [Language], [DisplayName], [Comments])
	SELECT
		(SELECT [ID] FROM [Right] WHERE [Name] = [X].[Name]),
		[X].[Language],
		[X].[DisplayName],
		[X].[Comments]
	FROM
		OPENXML(@hdoc, '/SecurityDataSet/RightGlobal', 2)
			WITH (	[Name] nvarchar(128), 
					[Language] varchar(2),
					[DisplayName] nvarchar(256), 
					[Comments] nvarchar(max)
					) as [X]

	/* import actions */
	DECLARE actions_cursor CURSOR LOCAL FAST_FORWARD READ_ONLY FOR
	SELECT 
		[ID],
		[Name],
		[Comments],
		[Image]  
	FROM 
		OPENXML(@hdoc, '/SecurityDataSet/Action', 2)
			WITH (	[ID] INT, 
					[Name] nvarchar(256), 
					[Comments] nvarchar(max),
					[Image] varchar(8000)
					)
	OPEN actions_cursor
	DECLARE @aID INT, 
			@aName nvarchar(256),
			@aComments nvarchar(max),
			@aImage varchar(8000)
	
	SET IDENTITY_INSERT [Action] ON
	
	BEGIN TRANSACTION

	FETCH NEXT FROM actions_cursor INTO @aID, @aName, @aComments, @aImage
	WHILE @@FETCH_STATUS = 0
	BEGIN
		SET @pic = dbo.adfBase64ToBin(@aImage)
		IF EXISTS(SELECT * FROM [Action] WHERE [ID] = @aID)
		BEGIN
			UPDATE 
				[Action]
			SET
				[Name] = @aName,
				[Comments] = @aComments,
				[Image] = @pic
			WHERE
				[ID] = @aID
			IF @@ERROR != 0 GOTO ERROR_HANDLER
		END	
		ELSE
		BEGIN
			INSERT INTO [Action]
				([ID], [Name], [Comments], [Image])
			VALUES
				(@aID, @aName, @aComments, @pic)
			IF @@ERROR != 0 GOTO ERROR_HANDLER
		END
		FETCH NEXT FROM actions_cursor INTO @aID, @aName, @aComments, @aImage
	END

	COMMIT TRANSACTION
	
	SET IDENTITY_INSERT [Action] OFF
	
	DELETE [ActionGlobal]
	
	INSERT [ActionGlobal]
		([ID], [Language], [Name], [Comments])
	SELECT
		[ID],
		[Language],
		[Name],
		[Comments]
	FROM
		OPENXML(@hdoc, '/SecurityDataSet/ActionGlobal', 2)
			WITH (	[ID] INT, 
					[Language] varchar(2),
					[Name] nvarchar(256), 
					[Comments] nvarchar(max)
					)
		
	CLOSE actions_cursor
	DEALLOCATE actions_cursor
	
	/* import roles */
	
	DECLARE roles_cursor CURSOR LOCAL FAST_FORWARD READ_ONLY FOR
	SELECT 
		[ID],
		[Name],
		[DisplayName],
		[Comments]  
	FROM 
		OPENXML(@hdoc, '/SecurityDataSet/Role', 2)
			WITH (	[ID] INT, 
					[Name] nvarchar(128), 
					[DisplayName] nvarchar(256), 
					[Comments] nvarchar(max)
					)
	OPEN roles_cursor
	
	DECLARE @lID TIdentifier,
			@lName TSysname,
			@lDisplayName TName,
			@lComments TNotes

	BEGIN TRANSACTION
				
	FETCH NEXT FROM roles_cursor INTO @lID, @lName, @lDisplayName, @lComments
	WHILE @@FETCH_STATUS = 0
	BEGIN
		IF EXISTS(SELECT * FROM [Trustee] WHERE [Name] = @lName)
		BEGIN
			UPDATE
				[Trustee]
			SET
				[DisplayName] = @lDisplayName,
				[Comments] = @lComments
			WHERE
				[Name] = @lName
			IF @@ERROR != 0 GOTO ERROR_HANDLER
		END
		ELSE
		BEGIN
			INSERT INTO [Trustee]
				([Name], [DisplayName], [Comments], [Builtin])
			VALUES
				(@lName, @lDisplayName, @lComments, 0)
			IF @@ERROR != 0 GOTO ERROR_HANDLER
				
			SET @lID = SCOPE_IDENTITY()
			INSERT INTO [Role] ([ID]) VALUES(@lID)
			IF @@ERROR != 0 GOTO ERROR_HANDLER
		END
		FETCH NEXT FROM roles_cursor INTO @lID, @lName, @lDisplayName, @lComments
	END
	
	COMMIT TRANSACTION
	
	CLOSE roles_cursor
	DEALLOCATE roles_cursor
	
	DELETE [TrusteeGlobal]
	
	INSERT INTO [TrusteeGlobal]
		([ID], [Language], [DisplayName], [Comments])
	SELECT
		(SELECT [Role].[ID] FROM [Trustee] INNER JOIN [Role] ON ([Trustee].[ID] = [Role].[ID]) WHERE [Name] = [X].[Name]),
		[X].[Language],
		[X].[DisplayName],
		[X].[Comments]
	FROM
		OPENXML(@hdoc, '/SecurityDataSet/RoleName', 2)
			WITH (	[Name] nvarchar(128), 
					[Language] varchar(2),
					[DisplayName] nvarchar(256), 
					[Comments] nvarchar(max)
					) as [X]
	
	/* import access rights */
	
	DECLARE accessrights_cursor CURSOR LOCAL FAST_FORWARD READ_ONLY FOR
	SELECT 
		[Right],
		[Role]
	FROM
		OPENXML(@hdoc, '/SecurityDataSet/AccessRight', 2)
			WITH (	[Right] nvarchar(128),
					[Role] nvarchar(128)
					)
	OPEN accessrights_cursor 
	
	DECLARE @arRight TSysname,
			@arRole TSysname,
			@arRightID TIdentifier,
			@arRoleID TIdentifier
			
	BEGIN TRANSACTION
	FETCH NEXT FROM accessrights_cursor INTO @arRight, @arRole
	WHILE @@FETCH_STATUS = 0
	BEGIN
		SET @arRightID = dbo.adfGetRightID(@arRight)
		SET @arRoleID = dbo.adfGetRoleID(@arRole)
		IF NOT EXISTS(SELECT * FROM [AccessRight] WHERE [RightID] = @arRightID AND [TrusteeID]=@arRoleID)
		BEGIN
			INSERT INTO [AccessRight] VALUES(@arRightID, @arRoleID, 1)
			IF @@ERROR != 0 GOTO ERROR_HANDLER
		END
		FETCH NEXT FROM accessrights_cursor INTO @arRight, @arRole
	END
	COMMIT TRANSACTION
	CLOSE accessrights_cursor
	DEALLOCATE accessrights_cursor

	/* import document classes */
	DECLARE classes_cursor  CURSOR LOCAL FAST_FORWARD READ_ONLY FOR
		SELECT 
			[Class],
			[Code],
			[Name],
			[Guid],
			[Comments],
			[CodeIsUnique],
			[CodeIsNullable],
			[TableName],
			[SmallImage],
			[LargeImage],
			[SPBrowse],
			[SPGet],
			[SPCreate],
			[SPUpdate],
			[SPChangeState],
			[SPDelete],
			[SPList],
			[SPPrint]
		FROM 
			OPENXML(@hdoc, '/SecurityDataSet/Class', 2)
				WITH (	[Class]					SMALLINT, 
						[Code]					nvarchar(128), 
						[Name]					nvarchar(256), 
						[Guid]					uniqueidentifier, 
						[Comments]				nvarchar(max),
						[CodeIsUnique]			bit,
						[CodeIsNullable]		bit,
						[TableName]				nvarchar(128),
						[SmallImage]			varchar(8000),
						[LargeImage]			varchar(8000),
						[SPBrowse]				nvarchar(128),
						[SPGet]					nvarchar(128),
						[SPCreate]				nvarchar(128),
						[SPUpdate]				nvarchar(128),
						[SPChangeState]			nvarchar(128),
						[SPDelete]				nvarchar(128),
						[SPList]				nvarchar(128),
						[SPPrint]				nvarchar(128)
					)
	OPEN classes_cursor
	DECLARE @cClass TClass,
			@cCode TCode,
			@cName TName,
			@cGuid TGuid,
			@cComments TNotes,
			@cCodeIsUnique TBool,
			@cCodeIsNullable TBool,
			@cTableName TSysname,
			@cClassID TIdentifier,
			@cSmallImage varchar(8000),
			@cLargeImage varchar(8000),
			@cSPBrowse TSysname,
			@cSPGet TSysname,
			@cSPCreate TSysname,
			@cSPUpdate TSysname,
			@cSPChangeState TSysname,
			@cSPDelete TSysname,
			@cSPList TSysname,
			@cSPPrint TSysname

	DECLARE @pic1 varbinary(8000)
	BEGIN TRANSACTION	
	FETCH NEXT FROM classes_cursor INTO @cClass, @cCode, @cName, @cGuid, @cComments, @cCodeIsUnique, @cCodeIsNullable,
		@cTableName, @cSmallImage, @cLargeImage,
		@cSPBrowse, @cSPGet, @cSPCreate, @cSPUpdate, @cSPChangeState, @cSPDelete, 
		@cSPList, @cSPPrint

	WHILE @@FETCH_STATUS = 0
	BEGIN
		SET @pic = dbo.adfBase64ToBin(@cSmallImage)
		SET @pic1 = dbo.adfBase64ToBin(@cLargeImage)

		IF NOT EXISTS(SELECT * FROM [Class] WHERE [Guid] = @cGuid)
		BEGIN
			INSERT INTO [Class] 
				([Code], [Name], [Guid], [Comments], [CodeIsUnique], [CodeIsNullable],
				[TableName], [SmallImage], [LargeImage],
				[SPBrowse], [SPGet], [SPCreate], [SPUpdate], [SPChangeState], 
				[SPDelete], [SPList], [SPPrint])
			VALUES
				(@cCode, @cName, @cGuid, @cComments, @cCodeIsUnique, @cCodeIsNullable,
				@cTableName, 
				@pic, @pic1,
				@cSPBrowse, @cSPGet, @cSPCreate, @cSPUpdate, @cSPChangeState, 
				@cSPDelete, @cSPList, @cSPPrint)
				
			IF @@ERROR != 0 GOTO ERROR_HANDLER
		END
		ELSE
		BEGIN
			UPDATE [Class] 
			SET	[Code] = @cCode, 
				[Name] = @cName, 
				[Comments] = @cComments, 
				[CodeIsUnique] = @cCodeIsUnique, 
				[CodeIsNullable] = @cCodeIsNullable,
				[TableName] = @cTableName,
				[SmallImage] = @pic,
				[LargeImage] = @pic1,
				[SPBrowse] = @cSPBrowse,
				[SPGet] = @cSPGet,
				[SPCreate] = @cSPCreate,
				[SPUpdate] = @cSPUpdate,
				[SPChangeState] = @cSPChangeState,
				[SPDelete] = @cSPDelete,
				[SPList] = @cSPList,
				[SPPrint] = @cSPPrint
			WHERE [Guid] = @cGuid
			IF @@ERROR != 0 GOTO ERROR_HANDLER
		END
		SELECT @cClassID = [Class].[Class] FROM [Class] WHERE [Class].[Guid] = @cGuid
		
		FETCH NEXT FROM classes_cursor INTO @cClass, @cCode, @cName, @cGuid, @cComments, @cCodeIsUnique, @cCodeIsNullable,
			@cTableName, @cSmallImage, @cLargeImage,
			@cSPBrowse, @cSPGet, @cSPCreate, @cSPUpdate, @cSPChangeState, @cSPDelete, 
			@cSPList, @cSPPrint
	END
	COMMIT TRANSACTION
	CLOSE classes_cursor
	DEALLOCATE classes_cursor
	
	DELETE [ClassGlobal]
	
	INSERT INTO [ClassGlobal]
		([Class], [Language], [Name], [Comments])
	SELECT
		(SELECT [Class] FROM [Class] WHERE [Class].[Code] = [X].[Code]),
		[X].[Language],
		[X].[Name],
		[X].[Comments]
	FROM
		OPENXML(@hdoc, '/SecurityDataSet/ClassGlobal', 2)
			WITH (
					[Code]					nvarchar(128), 
					[Language]				varchar(2),
					[Name]					nvarchar(256), 
					[Comments]				nvarchar(max)
				) as [X]
				
	/* import states */
	DECLARE states_cursor CURSOR  LOCAL FAST_FORWARD READ_ONLY FOR
		SELECT 
			[Guid],
			[State],
			[Name],
			[Comments],
			[UIText],
			[Image]
		FROM 
			OPENXML(@hdoc, '/SecurityDataSet/State', 2)
				WITH (	[Guid] uniqueidentifier, 
						[State] INT, 
						[Name] nvarchar(256), 
						[Comments] nvarchar(max),
						[UIText] nvarchar(256),
						[Image] varchar(8000)
						)
	OPEN states_cursor
	
	DECLARE @sGuid TGuid,
			@sClass TClass,
			@sState TState,
			@sName TSysname,
			@sComments TNotes,
			@sUIText TName,
			@sImage varchar(8000)
	
	BEGIN TRANSACTION
	FETCH NEXT FROM states_cursor INTO @sGuid, @sState, @sName, @sComments, @sUIText, @sImage
	WHILE @@FETCH_STATUS = 0
	BEGIN
		SET @pic = dbo.adfBase64ToBin(@sImage)
		SELECT @sClass = [Class] FROM [Class] WHERE [Guid] = @sGuid
		
		IF EXISTS (SELECT * FROM [State] WHERE [Class] = @sClass AND [State] = @sState)
		BEGIN
			UPDATE 
				[State]
			SET
				[Name] = @sName,
				[Comments] = @sComments,
				[UIText] = @sUIText,
				[Image] = @pic
			WHERE
				[Class] = @sClass AND [State] = @sState
			IF @@ERROR != 0 GOTO ERROR_HANDLER
		END
		ELSE
		BEGIN
			INSERT INTO [State] 
				([Class], [State], [Name], [Comments], [UIText], [Image])
			VALUES
				(@sClass, @sState, @sName, @sComments, @sUIText, @pic)
			IF @@ERROR != 0 GOTO ERROR_HANDLER
		END
		
		FETCH NEXT FROM states_cursor INTO @sGuid, @sState, @sName, @sComments, @sUIText, @sImage
	END
	COMMIT TRANSACTION
	CLOSE states_cursor
	DEALLOCATE states_cursor
	
	/* import states for another languages */

	BEGIN TRANSACTION
		
	DELETE [StateGlobal]
	
	IF @@ERROR != 0 GOTO ERROR_HANDLER
	
	INSERT INTO [StateGlobal]
		([Class], [State], [Language], [Name], [Comments], [UIText])
	SELECT
		(SELECT [Class] FROM [Class] WHERE [Class].[Code]=[X].[Code]),
		[X].[State],
		[X].[Language],
		[X].[Name],
		[X].[Comments],
		[X].[UIText]
	FROM
		OPENXML(@hdoc, '/SecurityDataSet/StateGlobal', 2)
			WITH (	[Code] varchar(32), 
					[State] INT, 
					[Language] varchar(2),
					[Name] nvarchar(256), 
					[Comments] nvarchar(max),
					[UIText] nvarchar(256)
					) as X
	
	IF @@ERROR != 0 GOTO ERROR_HANDLER
	
	COMMIT TRANSACTION
	
	/* import commands */
	
	DECLARE commands_cursor CURSOR LOCAL FAST_FORWARD READ_ONLY FOR
		SELECT
			[ID],
			[ActionID],
			[Guid],
			[Name],
			[Text],
			[AlternateText],
			[Shortcut],
			[Comments],
			[Picture],
			[Position],
			(CASE WHEN [BeginGroup]='false' THEN 0 ELSE 1 END)
		FROM
			OPENXML(@hdoc, '/SecurityDataSet/UICommand', 2)
				WITH (	[ID] INT,
						[ActionID] nvarchar(128),
						[Guid] uniqueidentifier,
						[Name] nvarchar(128),
						[Text] nvarchar(256),
						[AlternateText] nvarchar(256),
						[Shortcut] varchar(256),
						[Comments] nvarchar(max),
						[Picture] varchar(8000),
						[Position] int,
						[BeginGroup] varchar(5)
						)
	OPEN commands_cursor
	DECLARE @mID INT,
			@mActionID nvarchar(128),
			@mGuid uniqueidentifier,
			@mName nvarchar(128),
			@mText nvarchar(256),
			@mAlternateText nvarchar(256),
			@mShortcut varchar(256),
			@mComments nvarchar(max),
			@mPicture varchar(8000),
			@mClass smallint,
			@mPosition int,
			@mBeginGroup bit
			
	BEGIN TRANSACTION
	FETCH NEXT FROM commands_cursor INTO @mID, @mActionID, @mGuid, @mName, @mText, @mAlternateText,
		@mShortcut, @mComments, @mPicture, @mPosition, @mBeginGroup
	WHILE @@FETCH_STATUS = 0
	BEGIN
		SET @pic = dbo.adfBase64ToBin(@mPicture)

		SELECT @mClass = [Class] FROM [Class] WHERE [Guid] = @mGuid
		
		IF EXISTS(SELECT * FROM [UICommand] WHERE [Name]=@mName)
		BEGIN
			UPDATE 
				[UICommand]
			SET
				[ActionID]=@mActionID,
				[Class] = @mClass,
				[Name] = @mName,
				[Text] = @mText,
				[AlternateText] = @mAlternateText,
				[Shortcut] = @mShortcut,
				[Comments] = @mComments,
				[Picture] = @pic,
				[Position] = @mPosition,
				[BeginGroup] = @mBeginGroup
			WHERE
				[UICommand].[Name] = @mName

			IF @@ERROR != 0	GOTO ERROR_HANDLER
		END
		ELSE
		BEGIN
			INSERT INTO [UICommand]
				([ActionID], [Class], [Name], [Text], [AlternateText], [Shortcut], [Comments], [Picture],
				[Position], [BeginGroup])
			VALUES
				(@mActionID, @mClass, @mName, @mText, @mAlternateText, @mShortcut, @mComments, @pic,
				@mPosition, @mBeginGroup)
			IF @@ERROR != 0	GOTO ERROR_HANDLER
			
		END
		FETCH NEXT FROM commands_cursor INTO @mID, @mActionID, @mGuid, @mName, @mText, @mAlternateText,
			@mShortcut, @mComments, @mPicture, @mPosition, @mBeginGroup
	END
	COMMIT TRANSACTION
	
	CLOSE commands_cursor
	DEALLOCATE commands_cursor
	
	/* import commands for another languages */
	
	BEGIN TRANSACTION
	
	DELETE [UICommandGlobal]
	IF @@ERROR != 0 GOTO ERROR_HANDLER
	
	INSERT INTO [UICommandGlobal]
		([ID], [Language], [Text], [AlternateText], [Comments])
	SELECT
		(SELECT [ID] FROM [UICommand] WHERE [Name]=[X].[Name]),
		[X].[Language],
		[X].[Text],
		[X].[AlternateText],
		[X].[Comments]
	FROM
		OPENXML(@hdoc, '/SecurityDataSet/UICommandGlobal', 2)
			WITH (	[Name] nvarchar(128),
					[Language] varchar(2),
					[Text] nvarchar(256),
					[AlternateText] nvarchar(256),
					[Comments] nvarchar(max)
					) as [X]
	IF @@ERROR != 0 GOTO ERROR_HANDLER
		
	COMMIT TRANSACTION

	EXEC @result = adfSecurityImportTransitionTemplates @hdoc
	IF @result != 0 GOTO ERROR_HANDLER_NOROLLBACK
	
	EXEC @result = adfSecurityPatch @hdoc

	IF @@error != 0 OR @result != 0
		GOTO ERROR_HANDLER
	
	EXEC sp_xml_removedocument @hdoc	
	RETURN 0

ERROR_HANDLER:
	ROLLBACK TRANSACTION
	
ERROR_HANDLER_NOROLLBACK:
	EXEC sp_xml_removedocument @hdoc
	RETURN 1

GO

GRANT EXEC ON adfSecurityImport TO PUBLIC
GO
