IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'adfSecurityImportTransitionTemplates')
	BEGIN
		PRINT 'Dropping Procedure adfSecurityImportTransitionTemplates'
		DROP  Procedure  adfSecurityImportTransitionTemplates
	END

GO

PRINT 'Creating Procedure adfSecurityImportTransitionTemplates'
GO
/******************************************************************************
**		File: 
**		Name: adfSecurityImportTransitionTemplates
**		Desc: 
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE Procedure adfSecurityImportTransitionTemplates
	@hdoc INT
AS
	SET NOCOUNT ON

	DECLARE templates_cursor CURSOR LOCAL FAST_FORWARD READ_ONLY FOR
		SELECT 
			[Right],
			[Guid],
			[FromState],
			[ToState],
			[ActionID],
			[Name],
			[Comments],
			[UICommandName],
			[SPValidate],
			[SPBefore],
			[SPAfter],
			[ConfirmationMessage]
		FROM 
			OPENXML(@hdoc, '/SecurityDataSet/TransitionTemplate', 2)
				WITH (	[ID] INT, 
						[Right] nvarchar(128), 
						[Guid] uniqueidentifier, 
						[FromState] INT, 
						[ToState] INT, 
						[ActionID] INT, 
						[Name] nvarchar(256), 
						[Comments] nvarchar(max),
						[UICommandName] nvarchar(128),
						[SPValidate] nvarchar(128),
						[SPBefore] nvarchar(128),
						[SPAfter] nvarchar(128),
						[ConfirmationMessage] nvarchar(256)
					)
	OPEN templates_cursor
	DECLARE @tRightID TIdentifier,
			@tRight TSysname,
			@tGuid TGuid,
			@tToState TState,
			@tFromState TState,
			@tActionID TIdentifier,
			@tName TName,
			@tComments TNotes,
			@tClass TClass,
			@tUICommandName TSysname,
			@tSPValidate TSysname,
			@tSPBefore TSysname,
			@tSPAfter TSysname,
			@tUICommandID INT,
			@tConfirmationMessage TName
			
	BEGIN TRANSACTION
	FETCH NEXT FROM templates_cursor INTO @tRight, @tGuid, @tFromState, @tToState,
		@tActionID, @tName, @tComments, @tUICommandName, @tSPValidate, @tSPBefore, @tSPAfter,
		@tConfirmationMessage
	WHILE @@FETCH_STATUS = 0
	BEGIN
		SELECT @tClass = [Class] FROM [Class] WHERE [Guid] = @tGuid

		SET @tRightID = dbo.adfGetRightID(@tRight)

		IF @tUICommandName IS NULL
			SET @tUICommandID = NULL
		ELSE
			SELECT @tUICommandID = [ID] FROM [UICommand] WHERE [Name] = @tUICommandName
			
		IF EXISTS(SELECT * FROM [TransitionTemplate] WHERE 
				[Class]=@tClass 
			AND 
				((@tFromState IS NULL AND [FromState] IS NULL) OR (@tFromState IS NOT NULL AND [FromState]=@tFromState)) 
			AND 
				((@tToState IS NULL AND [ToState] IS NULL) OR (@tToState IS NOT NULL AND [ToState]=@tToState)) 
			)
		BEGIN
			UPDATE 
				[TransitionTemplate]
			SET
				[RightID] = @tRightID,
				[ActionID] = @tActionID,
				[Name] = @tName,
				[Comments] = @tComments,
				[UICommandID] = @tUICommandID,
				[SPValidate] = @tSPValidate, 
				[SPBefore] = @tSPBefore, 
				[SPAfter] = @tSPAfter,
				[ConfirmationMessage] = @tConfirmationMessage
			WHERE
				[Class]=@tClass 
			AND 
				((@tFromState IS NULL AND [FromState] IS NULL) OR (@tFromState IS NOT NULL AND [FromState]=@tFromState)) 
			AND 
				((@tToState IS NULL AND [ToState] IS NULL) OR (@tToState IS NOT NULL AND [ToState]=@tToState)) 
			IF @@ERROR != 0	GOTO ERROR_HANDLER
		END
		ELSE
		BEGIN
			INSERT INTO [TransitionTemplate]
				([RightID], [Class], [FromState], [ToState], [ActionID], [Name], [Comments], [UICommandID], [SPValidate], [SPBefore], [SPAfter], [ConfirmationMessage])
			VALUES
				(@tRightID, @tClass, @tFromState, @tToState, @tActionID, @tName, @tComments, @tUICommandID, @tSPValidate, @tSPBefore, @tSPAfter, @tConfirmationMessage)
			IF @@ERROR != 0	GOTO ERROR_HANDLER
		END
	
		FETCH NEXT FROM templates_cursor INTO @tRight, @tGuid, @tFromState, @tToState,
			@tActionID, @tName, @tComments, @tUICommandName, @tSPValidate, @tSPBefore, @tSPAfter,
			@tConfirmationMessage
	END	
	
	COMMIT TRANSACTION

	CLOSE templates_cursor
	DEALLOCATE templates_cursor
	
	DELETE FROM [TransitionTemplateGlobal]
	
	INSERT INTO [TransitionTemplateGlobal]
		([ID], [Language], [Name], [Comments], [ConfirmationMessage])
	SELECT
		dbo.adfSecurityImportGetTransitionTemplateID([Guid], [FromState], [ToState]),
		[Language],
		[Name],
		[Comments],
		[ConfirmationMessage]
	FROM
		OPENXML(@hdoc, '/SecurityDataSet/TransitionTemplateGlobal', 2)
			WITH (	
					[Guid] uniqueidentifier, 
					[FromState] INT, 
					[ToState] INT, 
					[Language] varchar(2),
					[Name] nvarchar(256), 
					[Comments] nvarchar(max),
					[ConfirmationMessage] nvarchar(256)
				)
	
	
	RETURN 0
	
ERROR_HANDLER:
	CLOSE templates_cursor
	DEALLOCATE templates_cursor
	ROLLBACK TRANSACTION
	RETURN 1
GO

