IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'adfRightUpdate')
	BEGIN
		PRINT 'Dropping Procedure adfRightUpdate'
		DROP  Procedure  adfRightUpdate
	END

GO

PRINT 'Creating Procedure adfRightUpdate'
GO
/******************************************************************************
**		File: 
**		Name: adfRightUpdate
**		Desc: 
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE Procedure adfRightUpdate
	@Name TSysname,
	@DisplayName TName,
	@Group TSysname,
	@Comments TNotes
AS
	DECLARE @result INT, @ID TIdentifier
	
	SET NOCOUNT ON

	EXEC @result = adfAccessRightCheck 'ManageRights'
	IF @result != 0
		RETURN @result

	DECLARE @Lang TLanguage
	SET @Lang = dbo.adfGetLanguage()

	BEGIN TRANSACTION
	
	IF @Lang = 'ru'
	BEGIN
		UPDATE [Right]
		SET
			[Right].[DisplayName] = @DisplayName,
			[Right].[Group] = @Group,
			[Right].[Comments] = @Comments
		WHERE
			[Right].[Name] = @Name
	END
	ELSE
	BEGIN
		UPDATE [Right]
		SET
			[Right].[Group] = @Group
		WHERE
			[Right].[Name] = @Name
	END
	
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	
	SELECT @ID = [ID] FROM [Right] WHERE [Name] = @Name
	
	IF EXISTS(SELECT * FROM [RightGlobal] WHERE [ID] = @ID AND [Language] = @Lang)
	BEGIN
		UPDATE [RightGlobal]
		SET
			[DisplayName] = @DisplayName,
			[Comments] = @Comments
		WHERE
			[ID] = @ID AND [Language] = @Lang
	END
	ELSE
	BEGIN
		INSERT INTO [RightGlobal]
			([ID], [Language], [DisplayName], [Comments])
		VALUES
			(@ID, @Lang, @DisplayName, @Comments)
	END
	
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END

	COMMIT TRANSACTION
	
	EXEC adfRightGet @Name
	
	RETURN 0
GO

GRANT EXEC ON adfRightUpdate TO PUBLIC
GO
