IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'DeactivateAssignment')
	BEGIN
		PRINT 'Dropping Procedure DeactivateAssignment'
		DROP  Procedure  DeactivateAssignment
	END

GO

PRINT 'Creating Procedure DeactivateAssignment'
GO
/******************************************************************************
**		File: 
**		Name: DeactivateTaskAssignments
**		Desc: 
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE Procedure DeactivateAssignment
	@AssignmentID TIdentifier
AS
	SET NOCOUNT ON

	DECLARE
		@rv int,
		@DeactivateDate TDateTime
	

	
	IF EXISTS(SELECT * FROM [Assignment] WHERE [ID] = @AssignmentID AND [MsResourceID] IS NOT NULL)
	BEGIN
		BEGIN TRANSACTION
	
		UPDATE 
			[TaskAssignment]
		SET
			[State] = 2
		WHERE
			[TaskAssignment].[AssignmentID] = @AssignmentID		
		
		IF @@ERROR != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END
			
		COMMIT TRANSACTION
		
		RETURN 0
	END

	BEGIN TRANSACTION
	SET @DeactivateDate = DATEADD(day, 1, CAST(CONVERT(varchar(8), GETDATE(), 112) AS DateTime))
	DECLARE @Tasks TABLE([ID] int)
	
	INSERT INTO @Tasks 
	SELECT 
		[Task].[ID]
	FROM 
		[Task]
		INNER JOIN [TaskAssignment]
			ON [TaskAssignment].[TaskID] = [Task].[ID]
			AND [TaskAssignment].[AssignmentID] = @AssignmentID
	WHERE
		--[Task].[DueDate] > @DeactivateDate AND
		[Task].[State] IN (2,8)

	DELETE 
		[BusyEntry]
	FROM
		[BusyEntry]
		INNER JOIN @Tasks as [Tasks]
			ON [Tasks].[ID] = [BusyEntry].[TaskID]
	WHERE 
		[BusyEntry].[AssignmentID] = @AssignmentID AND
		[BusyEntry].[Date] > @DeactivateDate AND
		[BusyEntry].[Planned] > 0
	IF @@error != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END

	;
	WITH [TaskAssignmentWork] ([TaskID], [Work]) AS
	(
		SELECT
			[Tasks].[ID],
			SUM([BusyEntry].[Planned])
		FROM
			@Tasks as [Tasks]
			INNER JOIN [BusyEntry]
				ON [BusyEntry].[TaskID] = [Tasks].[ID]
				AND [BusyEntry].[AssignmentID] = @AssignmentID
		GROUP BY
			[Tasks].[ID]
	)
	UPDATE
		[TaskAssignment]
	SET
		[State] = 2,
		[Work] = [TaskAssignmentWork].[Work],
		[RemainingWork] = 0
	FROM
		[TaskAssignment]
		INNER JOIN [TaskAssignmentWork]
			ON [TaskAssignmentWork].[TaskID] = [TaskAssignment].[TaskID]
	WHERE
		[TaskAssignment].[AssignmentID] = @AssignmentID
	IF @@error != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
-------------------------------

	DECLARE @DueDate TDateTime, @TaskClass TClass
	SET @TaskClass = dbo.adfGetClassByName('Pjm5.Task')
					
	;
	WITH [TaskUpdates] ([TaskID], [DueDate], [ManHour], [Budget]) AS
	(
		SELECT
			[Tasks].[ID],
			(SELECT MAX([Date]) FROM [BusyEntry] WHERE [BusyEntry].[TaskID] = [Tasks].[ID] AND [BusyEntry].[Planned] > 0),
			SUM([TaskAssignment].[Work]),
			SUM([TaskAssignment].[Work] * [Assignment].[StandardRate]) / 60
		FROM
			@Tasks as [Tasks]
			INNER JOIN [TaskAssignment]
				ON [TaskAssignment].[TaskID] = [Tasks].[ID]
			INNER JOIN [Assignment]
				ON [Assignment].[ID] = [TaskAssignment].[AssignmentID]
		GROUP BY
			[Tasks].[ID]
	)
	UPDATE 
		[Task]
	SET
		[Task].[DueDate] = [TaskUpdates].[DueDate],
		[Task].[Duration] = dbo.fnPjm5GetWorkingDays([Task].[StartDate], [TaskUpdates].[DueDate]),
		[ManHour] = [TaskUpdates].[ManHour],
		[Budget] = [TaskUpdates].[Budget]
	FROM
		[Task]
		INNER JOIN [TaskUpdates]
			ON [TaskUpdates].[TaskID] = [Task].[ID]
	IF @@error != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	
	-------------------------------

	IF EXISTS (
			SELECT
				*
			FROM
				[Reminder]
				INNER JOIN @Tasks as [Tasks]
					ON [DocumentID] = [Tasks].[ID]			
			WHERE 
				[DocumentClass] = @TaskClass AND
				[Subtype] = 'TD'
		)
	BEGIN
		UPDATE 
			[Reminder]
		SET 
			[EventTime] = [Task].[DueDate]
		FROM 
			[Reminder]
			INNER JOIN @Tasks as [Tasks]
				ON [Tasks].[ID] = [Reminder].[DocumentID]
			INNER JOIN [Task]
				ON [Task].[ID] = [Tasks].[ID]
		WHERE
			[DocumentClass] = @TaskClass AND
			[Subtype] = 'TD'
		IF @@error != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END
	END
	
	DECLARE @taskpcID TIdentifier
	DECLARE itemspc CURSOR LOCAL FAST_FORWARD FOR 
	SELECT 
		[ID] 
	FROM 
		@Tasks as [Tasks]
	OPEN itemspc
	FETCH NEXT FROM itemspc INTO @taskpcID
	WHILE @@FETCH_STATUS = 0
	BEGIN
		EXEC @rv = pjm6TaskPercentUpdate @taskpcID

		EXEC pjm6AssignmentCheckBudgetOverdraft @taskpcID, @AssignmentID, NULL
		FETCH NEXT FROM itemspc INTO @taskpcID
	END
	CLOSE itemspc
	DEALLOCATE itemspc

	COMMIT TRANSACTION

-----------------------------
	RETURN 0
GO

GRANT EXEC ON DeactivateAssignment TO PUBLIC
GO