﻿IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm6BudgetLineAndGroupCopy]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm6BudgetLineAndGroupCopy'
		DROP PROCEDURE [dbo].[pjm6BudgetLineAndGroupCopy]
	END
GO

PRINT 'Creating procedure pjm6BudgetLineAndGroupCopy'
GO

/******************************************************************************
**		File: pjm6BudgetLineAndGroupCopy.sql
**		Name: pjm6BudgetLineAndGroupCopy
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Anton.Paramonov
**		Date: 24/09/2010 14:20:00
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		13.09.12	MAB				Изменение типа полей PlannedAmount и ActualAmount c TCount на TAmount
*******************************************************************************/
CREATE PROCEDURE [pjm6BudgetLineAndGroupCopy]
	@SourceBudgetID		TIdentifier,
	@ReceiveBudgetID	TIdentifier,
	@ReceiveDocumentID	TIdentifier,
	@CopyActualAsPlan	TBool,
	@CopyDataFromBudget	TBool = 0
AS
	SET NOCOUNT ON
	
	DECLARE 
		@SourceBudgetVATRate						TPercent,
		@SourceBudgetRatesWithVAT					TBool,
		@SourceBudgetStartDate						TDate,
		@SourceBudgetGroupStartDate					TDate,
		@SourceBudgetWorkLineStartDate				TDate,
		@SourceBudgetExpenseLineStartDate			TDate,
		@SourceBudgetPlanningActivityForWork		TBool,
		@SourceBudgetPlanningExpenseTypeForExpense	TBool,
		@SourceBudgetUseWorkPlanning				TBool,
		@SourceBudgetUseExpensePlanning				TBool,
		@ReceiveBudgetVATRate						TPercent,
		@ReceiveBudgetRatesWithVAT					TBool,
		@ReceiveBudgetStartDate						TDate,
		@ShiftDays									TCount,
		@BudgetWorkLineInitialState					TState,
		@BudgetWorkExpenseInitialState				TState

	SET @BudgetWorkLineInitialState = dbo.adfwfGetInitialState('af97690a-3eb9-41a4-bb20-bd145b566a85')
	IF @BudgetWorkLineInitialState IS NULL
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END

	SET @BudgetWorkExpenseInitialState = dbo.adfwfGetInitialState('b8fd335f-1232-4a5a-a823-92225e38f361')
	IF @BudgetWorkExpenseInitialState IS NULL
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END
	--Прочитать параметры бюджета-источника
	SELECT
		@SourceBudgetVATRate						= [Budget].[VATRate],
		@SourceBudgetRatesWithVAT					= [Budget].[VATIsIncluded],
		@SourceBudgetStartDate						= [Budget].[StartDate],
		@SourceBudgetPlanningActivityForWork		= [Budget].[PlanningActivityForWork],
		@SourceBudgetPlanningExpenseTypeForExpense	= [Budget].[PlanningExpenseTypeForExpense],
		@SourceBudgetUseWorkPlanning				= [Budget].[UseWorkPlanning],
		@SourceBudgetUseExpensePlanning				= [Budget].[UseExpensePlanning]
	FROM
		[Budget]
	WHERE
		[Budget].[ID] = @SourceBudgetID

	--Прочитать параметры бюджета-приемника
	SELECT
		@ReceiveBudgetVATRate						= [Budget].[VATRate],
		@ReceiveBudgetRatesWithVAT					= [Budget].[VATIsIncluded],
		@ReceiveBudgetStartDate						= [Budget].[StartDate]
	FROM
		[Budget]
	WHERE
		[Budget].[ID] = @ReceiveBudgetID

	--Расчитать приращение для пересчета дат в линиях и группах
	IF @ReceiveBudgetStartDate IS NOT NULL
		SET @ShiftDays = DATEDIFF(day, @SourceBudgetStartDate, @ReceiveBudgetStartDate)
	ELSE
	BEGIN
		DECLARE
			@SourceBudgetMinStartDate	TDate

		SET @SourceBudgetGroupStartDate = (SELECT MIN([StartDate]) FROM [BudgetLineGroup] WHERE [BudgetID] = @SourceBudgetID
			AND [State] = 1)
		SET @SourceBudgetWorkLineStartDate = (SELECT MIN([StartDate]) FROM [BudgetLineWork] WHERE [BudgetID] = @SourceBudgetID
			AND [State] = 1)
		SET @SourceBudgetExpenseLineStartDate = (SELECT MIN([StartDate]) FROM [BudgetLineExpense] WHERE [BudgetID] = @SourceBudgetID
			AND [State] = 1)

		SET @SourceBudgetMinStartDate = (SELECT MIN([Dates].[StartDate]) FROM 
			(SELECT @SourceBudgetGroupStartDate AS [StartDate] UNION
			SELECT @SourceBudgetWorkLineStartDate AS [StartDate] UNION
			SELECT @SourceBudgetExpenseLineStartDate AS [StartDate]) AS [Dates])
		IF @SourceBudgetMinStartDate IS NOT NULL
			SET @ShiftDays = DATEDIFF(day, @SourceBudgetMinStartDate, @ReceiveBudgetStartDate)
	END

	BEGIN TRANSACTION
	--Скопировать виды деятельности и типы затрат
	IF @CopyDataFromBudget = 1
	BEGIN
	
		IF @SourceBudgetUseWorkPlanning = 1 AND @SourceBudgetPlanningActivityForWork = 1
		BEGIN
			INSERT INTO [ProjectActivityType]
				([ProjectID], [ActivityTypeID], [Billable], [Actively])
			SELECT DISTINCT
				@ReceiveDocumentID, 
				[ActivityTypeID],
				[Billable],
				1
			FROM [BudgetLineWork]
				INNER JOIN [ActivityType]
					ON [BudgetLineWork].[ActivityTypeID] = [ActivityType].[ID] 
			WHERE [BudgetID] = @SourceBudgetID AND [ActivityTypeID] NOT IN (SELECT [ActivityTypeID] FROM [ProjectActivityType] WHERE [ProjectID] = @ReceiveDocumentID)
			IF @@ERROR != 0
				RETURN 1
		END
		IF @SourceBudgetUseExpensePlanning = 1 AND @SourceBudgetPlanningExpenseTypeForExpense = 1
		BEGIN
			INSERT INTO [ProjectExpenseCode]
				([ProjectID], [ExpenseCodeID], [Billable], [Actively])
			SELECT DISTINCT
				@ReceiveDocumentID, 
				[ExpenseCodeID],
				[Billable],
				1
			FROM [BudgetLineExpense]
				INNER JOIN [ExpenseCode]
					ON [BudgetLineExpense].[ExpenseCodeID] = [ExpenseCode].[ID] 
			WHERE [BudgetID] = @SourceBudgetID AND [ExpenseCodeID] NOT IN (SELECT [ExpenseCodeID] FROM [ProjectExpenseCode] WHERE [ProjectID] = @ReceiveDocumentID)
			IF @@ERROR != 0
				RETURN 1
		END
	END
	--Скопировать линии бюджета которые имеют группу
	DECLARE @BudgetGroupID TIdentifier,
			@BudgetGroupType	TIdentifier

	DECLARE SourceBudgetGroupCursor CURSOR FOR
		SELECT [ID], [GroupTypeID] FROM [BudgetLineGroup] WHERE [BudgetID] = @SourceBudgetID AND [State] = 1
		UNION
		SELECT NULL, 1
		UNION
		SELECT NULL, 2
	OPEN SourceBudgetGroupCursor
	FETCH NEXT FROM SourceBudgetGroupCursor INTO @BudgetGroupID, @BudgetGroupType
	WHILE @@FETCH_STATUS = 0
	BEGIN
		--Скопировать группу в новый бюджет
		DECLARE @NewBudgetGroupID	TIdentifier

		IF @BudgetGroupID IS NOT NULL AND ((@BudgetGroupType = 1 AND @SourceBudgetUseWorkPlanning = 1) OR 
			(@BudgetGroupType = 2 AND @SourceBudgetUseExpensePlanning = 1))
		BEGIN
			INSERT INTO [BudgetLineGroup]
				([State], [BudgetID], [FileAs], [StartDate], [EndDate], [Order], [GroupTypeID])
			SELECT
				[State], @ReceiveBudgetID, [FileAs], [StartDate] + @ShiftDays, [EndDate] + @ShiftDays, [Order], [GroupTypeID]
			FROM
				[BudgetLineGroup]
			WHERE
				[BudgetLineGroup].[ID] = @BudgetGroupID
			IF @@ERROR != 0
				RETURN 1
			SET @NewBudgetGroupID = SCOPE_IDENTITY()
		END
		--Скопировать линии бюджета этой группы
		IF @BudgetGroupType = 1 AND @SourceBudgetUseWorkPlanning = 1
		BEGIN
			DECLARE
				@RateTable TABLE ([ID] TIdentifier, [Rate] TMoney, [PlannedManHour] TAmount)
			
			INSERT INTO @RateTable
				([ID], [Rate], [PlannedManHour])
			SELECT
				[ID],
				(CASE WHEN @ReceiveBudgetVATRate IS NOT NULL AND @ReceiveBudgetRatesWithVAT = 1 AND @SourceBudgetRatesWithVAT = 1 THEN
						[Rate]
					WHEN @ReceiveBudgetVATRate IS NOT NULL AND @ReceiveBudgetRatesWithVAT = 1 AND @SourceBudgetRatesWithVAT = 0 THEN
						[Rate] * (1 + @ReceiveBudgetVATRate)
					WHEN @ReceiveBudgetVATRate IS NOT NULL AND @ReceiveBudgetRatesWithVAT = 0 AND @SourceBudgetRatesWithVAT = 1 THEN
						[Rate] / (1 + ISNULL(@SourceBudgetVATRate, 0))
					WHEN @ReceiveBudgetVATRate IS NOT NULL AND @ReceiveBudgetRatesWithVAT = 0 AND @SourceBudgetRatesWithVAT = 0 THEN
						[Rate]
					WHEN @ReceiveBudgetVATRate IS NULL AND @SourceBudgetRatesWithVAT = 1 THEN
						[Rate] / (1 + ISNULL(@SourceBudgetVATRate, 0))
					WHEN @ReceiveBudgetVATRate IS NULL AND @SourceBudgetRatesWithVAT = 0 THEN
						[Rate]
				END) AS [Rate],
				(CASE WHEN @CopyActualAsPlan = 0 THEN [PlannedManHour]
					WHEN @CopyActualAsPlan = 1 THEN [ActualManHour]
				END) AS [PlannedManHour]
			FROM
				[BudgetLineWork]
			WHERE
				[BudgetID] = @SourceBudgetID AND [State] = 1 AND 
					((@BudgetGroupID IS NOT NULL AND [BudgetLineGroupID] = @BudgetGroupID) OR (@BudgetGroupID IS NULL AND [BudgetLineGroupID] IS NULL))
			IF @@ERROR != 0
				RETURN 1

			INSERT INTO [BudgetLineWork]
				([State], [FileAs],[BudgetID],[DocumentClass],[DocumentID],[BudgetLineGroupID],[Order],[Rate],
				[EmployeeID],[ActivityTypeID],[QualificationID],[PlannedManHour],[Comments],
				[TotalPCPlannedManHour],[TotalWithVATPCPlannedManHour])	
			SELECT
				@BudgetWorkLineInitialState, [FileAs], @ReceiveBudgetID,[DocumentClass],[DocumentID],@NewBudgetGroupID,[Order],
				[Rates].[Rate],
				[EmployeeID],[ProjectActivityType].[ActivityTypeID], [QualificationID],[Rates].[PlannedManHour],[Comments],
				CASE WHEN @ReceiveBudgetVATRate IS NOT NULL AND @ReceiveBudgetRatesWithVAT = 1 THEN
						[Rates].[PlannedManHour] * [Rates].[Rate] - ROUND([Rates].[PlannedManHour] * [Rates].[Rate] * @ReceiveBudgetVATRate, 2) / (1 + @ReceiveBudgetVATRate)
					WHEN @ReceiveBudgetVATRate IS NOT NULL AND @ReceiveBudgetRatesWithVAT = 0 THEN
						[Rates].[PlannedManHour] * [Rates].[Rate]
					WHEN @ReceiveBudgetVATRate IS NULL THEN
						[Rates].[PlannedManHour] * [Rates].[Rate]
				END AS [TotalPCPlannedManHour],
				CASE WHEN @ReceiveBudgetVATRate IS NOT NULL AND @ReceiveBudgetRatesWithVAT = 1 THEN
						[Rates].[PlannedManHour] * [Rates].[Rate]
					WHEN @ReceiveBudgetVATRate IS NOT NULL AND @ReceiveBudgetRatesWithVAT = 0 THEN
						[Rates].[PlannedManHour] * [Rates].[Rate] + ROUND([Rates].[PlannedManHour] * [Rates].[Rate] * @ReceiveBudgetVATRate, 2)
					WHEN @ReceiveBudgetVATRate IS NULL THEN
						[Rates].[PlannedManHour] * [Rates].[Rate]
				END AS [TotalWithVATPCPlannedManHour]
			FROM
				[BudgetLineWork]
			INNER JOIN @RateTable AS [Rates]
				ON [Rates].[ID] = [BudgetLineWork].[ID]
			LEFT OUTER JOIN [ProjectActivityType]
				ON [ProjectActivityType].[ActivityTypeID] = [BudgetLineWork].[ActivityTypeID] AND [ProjectActivityType].[ProjectID] = @ReceiveDocumentID
			WHERE
				[BudgetID] = @SourceBudgetID AND [State] = 1 AND 
				((@BudgetGroupID IS NOT NULL AND [BudgetLineGroupID] = @BudgetGroupID) OR (@BudgetGroupID IS NULL AND [BudgetLineGroupID] IS NULL))
			IF @@ERROR != 0
				RETURN 1

		END
		ELSE IF @BudgetGroupType = 2 AND @SourceBudgetUseExpensePlanning = 1
		BEGIN
			DECLARE
				@AmountTable TABLE ([ID] TIdentifier, [PlannedAmount] TAmount)

			INSERT INTO @AmountTable
				([ID], [PlannedAmount])
			SELECT
				[ID],
				(CASE WHEN @CopyActualAsPlan = 0 THEN [PlannedAmount]
					WHEN @CopyActualAsPlan = 1 THEN [ActualAmount]
				END) AS [PlannedAmount]
			FROM
				[BudgetLineExpense]
			WHERE
				[BudgetID] = @SourceBudgetID AND [State] = 1 AND 
				((@BudgetGroupID IS NOT NULL AND [BudgetLineGroupID] = @BudgetGroupID) OR (@BudgetGroupID IS NULL AND [BudgetLineGroupID] IS NULL))
			IF @@ERROR != 0
				RETURN 1

			INSERT INTO [BudgetLineExpense]
				([State],[FileAs],[BudgetID], [DocumentClass], [DocumentID], [EmployeeID], [ExpenseCodeID], [ExpenseID],
				[CurrencyCode], [UOMID], [BudgetLineGroupID], [Order], [Price], [PlannedAmount], [Comments],
				[VATIsIncluded], [CurrencyRate], [VATRate], [VATPlannedExpense],
				[TotalPCPlannedExpense], [TotalWithVATPCPlannedExpense])	
			SELECT
				@BudgetWorkExpenseInitialState, [FileAs], @ReceiveBudgetID, [DocumentClass], [DocumentID], [EmployeeID], [ProjectExpenseCode].[ExpenseCodeID], [ExpenseID],
				[CurrencyCode], [UOMID], @NewBudgetGroupID, [Order], [Price], [Amounts].[PlannedAmount], [Comments],
				[VATIsIncluded], [CurrencyRate], [VATRate], [VATPlannedExpense],
				[TotalPCPlannedExpense], [TotalWithVATPCPlannedExpense]
			FROM
				[BudgetLineExpense]
			INNER JOIN @AmountTable AS [Amounts]
				ON [Amounts].[ID] = [BudgetLineExpense].[ID]
				LEFT OUTER JOIN [ProjectExpenseCode]
				ON [ProjectExpenseCode].[ExpenseCodeID] = [BudgetLineExpense].[ExpenseCodeID] AND [ProjectExpenseCode].[ProjectID] = @ReceiveDocumentID
			WHERE
				[BudgetID] = @SourceBudgetID AND [State] = 1 AND 
				((@BudgetGroupID IS NOT NULL AND [BudgetLineGroupID] = @BudgetGroupID) OR (@BudgetGroupID IS NULL AND [BudgetLineGroupID] IS NULL))
			IF @@ERROR != 0
				RETURN 1

		END
		FETCH NEXT FROM SourceBudgetGroupCursor INTO @BudgetGroupID, @BudgetGroupType
	END
	CLOSE SourceBudgetGroupCursor
	DEALLOCATE SourceBudgetGroupCursor

	COMMIT TRANSACTION

	RETURN 0
GO

GRANT EXECUTE ON pjm6BudgetLineAndGroupCopy TO PUBLIC
GO