IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'bugfixLongTaskDelete')
	BEGIN
		PRINT 'Dropping Procedure bugfixLongTaskDelete'
		DROP  Procedure  bugfixLongTaskDelete
	END

GO

PRINT 'Creating Procedure bugfixLongTaskDelete'
GO
/******************************************************************************
**		File: 
**		Name: bugfixLongTaskDelete
**		Desc: 
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE Procedure dbo.bugfixLongTaskDelete
	@TaskID TIdentifier
AS
	SET NOCOUNT ON
	DECLARE @employee TABLE ([EmployeeID] int, [Date] datetime)
	
	INSERT INTO @employee ([EmployeeID], [Date])
	SELECT DISTINCT
		[EmployeeID],
		CAST(CONVERT(varchar(8), [StartTime], 112) as datetime)
	FROM
		[TimeEntry]
	WHERE
		[TaskID] = @TaskID
	
	ALTER TABLE [TimeEntry] DISABLE TRIGGER ALL
	UPDATE [TimeEntry] SET [TaskID] = NULL WHERE [TaskID] = @TaskID
	ALTER TABLE [TimeEntry] ENABLE TRIGGER ALL
	
	BEGIN TRANSACTION
	DELETE [BusyEntry] WHERE [TaskID] = @TaskID
	IF @@error != 0
	BEGIN
		RAISERROR('Cannot delete [BusyEntry]', 18, -1)
		ROLLBACK TRANSACTION
		RETURN 1
	END

	DELETE [Task] WHERE [ID] = @TaskID	
	IF @@error != 0
	BEGIN
		RAISERROR('Cannot delete [Task]', 18, -1)
		ROLLBACK TRANSACTION
		RETURN 1
	END

	;WITH [DateBusyEntry] ([EmployeeID], [Date], [Planned], [Approved]) AS
	(
		SELECT
			employee.[EmployeeID],
			employee.[Date],
			SUM(CASE 
					WHEN [BusyEntry].[Planned] > [BusyEntry].[Canceled] 
						THEN [BusyEntry].[Planned] - [BusyEntry].[Canceled]
					ELSE 0
				END), 
			SUM(CASE 
				WHEN [Task].[State] IN (2, 3, 5, 6) AND [BusyEntry].[Planned] > [BusyEntry].[Canceled]
					THEN ([BusyEntry].[Planned] - [BusyEntry].[Canceled])
				ELSE 0
			END)
		FROM
			@employee AS employee
			INNER JOIN [BusyEntry]
				ON [BusyEntry].[EmployeeID] = employee.[EmployeeID] AND
					[BusyEntry].[Date] = employee.[Date]
			INNER JOIN [Task]
				ON [Task].[ID] = [BusyEntry].[TaskID]
		GROUP BY
			employee.[EmployeeID],
			employee.[Date]
	)
	UPDATE
		[EmployeeCalendar]
	SET
		[Planned] = ISNULL([DateBusyEntry].[Planned], 0),
		[Approved] = ISNULL([DateBusyEntry].[Approved], 0)
	FROM
		[EmployeeCalendar]
		INNER JOIN [DateBusyEntry]
			ON ([EmployeeCalendar].[EmployeeID] = [DateBusyEntry].[EmployeeID] AND 
				[EmployeeCalendar].[Date] = [DateBusyEntry].[Date])
	IF @@error != 0
	BEGIN
		RAISERROR('Cannot change [EmployeeCalendar]', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END

	COMMIT TRANSACTION
	RETURN 0
GO

 