IF EXISTS (SELECT * FROM sysobjects WHERE type = 'TR' AND name = 'pjm5trCalculationUpdate')
BEGIN
	PRINT 'Dropping Trigger pjm5trCalculationUpdate'
	DROP  Trigger pjm5trCalculationUpdate
END
GO

/******************************************************************************
**		File: 
**		Name: pjm5trCalculationUpdate
**		Desc: 
**
**		This template can be customized:
**              
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:				Description:
**	  --------		--------			-------------------------------------------
**    12.03.10			SYV				    
**    31.05.11			SYV				        
*******************************************************************************/

PRINT 'Creating Trigger pjm5trCalculationUpdate'
GO
CREATE Trigger pjm5trCalculationUpdate 
ON [Calculation] FOR UPDATE
AS
BEGIN
	IF @@ROWCOUNT = 0
		RETURN
	IF EXISTS(
		SELECT * 
		FROM
			deleted
			INNER JOIN inserted
				ON deleted.[ID] = inserted.[ID] AND 
					deleted.[State] IN (2, 4) AND 
					inserted.[State] = 1
			INNER JOIN [InvoiceLine]
				ON [InvoiceLine].[DocumentClass] = inserted.[Class] AND
					[InvoiceLine].[DocumentID] = inserted.[ID]
			INNER JOIN [Invoice]
				ON [Invoice].[ID] = [InvoiceLine].[InvoiceID] AND
					[Invoice].[State] IN (2, 4, 5)
			)
	BEGIN
		RAISERROR('#CannotRecommitCalculationIncludedInApprovedInvoice', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END

	IF EXISTS(
		SELECT * 
		FROM
			deleted
			INNER JOIN inserted
				ON deleted.[ID] = inserted.[ID] AND 
					deleted.[State] IN (2, 4) AND 
					inserted.[State] = 1
			INNER JOIN [StatementLine]
				ON [StatementLine].[DocumentClass] = inserted.[Class] AND
					[StatementLine].[DocumentID] = inserted.[ID]
			INNER JOIN [Statement]
				ON [Statement].[ID] = [StatementLine].[StatementID] AND
					[Statement].[State] IN (2, 3)
			)
	BEGIN
		RAISERROR('#CannotRecommitCalculationIncludedInApprovedStatement', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END

	IF EXISTS(
		SELECT * 
		FROM
			deleted
			INNER JOIN inserted
				ON deleted.[ID] = inserted.[ID] AND 
					deleted.[State] = 1 AND 
					inserted.[State] = 2
			INNER JOIN [CalculationLine]
				ON [CalculationLine].[CalculationID] = inserted.[ID]
			LEFT OUTER JOIN [TimeEntry]
				ON [TimeEntry].[Class] = [CalculationLine].[DocumentClass] AND 
					[TimeEntry].[ID] = [CalculationLine].[DocumentID]
			LEFT OUTER JOIN [Expense]
				ON [Expense].[Class] = [CalculationLine].[DocumentClass] AND 
					[Expense].[ID] = [CalculationLine].[DocumentID]
			LEFT OUTER JOIN [ServiceRequest]
				ON [ServiceRequest].[Class] = [CalculationLine].[DocumentClass] AND 
					[ServiceRequest].[ID] = [CalculationLine].[DocumentID]
		WHERE
			(ISNULL(CAST([TimeEntry].[Billable] AS int), 0) + 
				ISNULL(CAST([Expense].[Billable] AS int), 0) +
				ISNULL(CAST([ServiceRequest].[Billable] AS int), 0)) = 0
		)
	BEGIN
		RAISERROR('#CannotApproveNotBillableRecords', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END
	
--- REJECT CALCULATION
	DELETE [Attachment]
	FROM
		[Attachment]
		INNER JOIN [CalculationLine]
			ON ([CalculationLine].[DocumentClass] = [Attachment].[DocumentClass] AND 
				[CalculationLine].[DocumentID] = [Attachment].[DocumentID])
		INNER JOIN [inserted]
			ON ([inserted].[ID] = [CalculationLine].[CalculationID] AND
				[inserted].[Class] = [Attachment].[LinkDocumentClass] AND 
				[inserted].[ID] = [Attachment].[LinkDocumentID])
		INNER JOIN [deleted]
			ON [deleted].[ID] = [inserted].[ID]
	WHERE
		[inserted].[State] = 4 AND
		[deleted].[State] != 4 AND
		[Attachment].[AttachmentTypeID] = 3
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotRejectCalculation', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END

	UPDATE
		[TimeEntry]
	SET
		[TimeEntry].[State] = 3,
		[TimeEntry].[Modified] = DEFAULT,
		[TimeEntry].[ModifiedBy] = DEFAULT
	FROM
		[TimeEntry]
		INNER JOIN [CalculationLine]
			ON [TimeEntry].[Class] = [CalculationLine].[DocumentClass] AND 
				[TimeEntry].[ID] = [CalculationLine].[DocumentID]
		INNER JOIN inserted
			ON [CalculationLine].[CalculationID] = inserted.[ID]
		INNER JOIN deleted
			ON deleted.[ID] = inserted.[ID] AND 
				deleted.[State] != 4 AND inserted.[State] = 4
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotRecommitCalculationTimeEntry', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END
	
	UPDATE
		[Expense]
	SET
		[Expense].[State] = 3,
		[Expense].[Modified] = DEFAULT,
		[Expense].[ModifiedBy] = DEFAULT
	FROM
		[Expense]
		INNER JOIN [CalculationLine]
			ON [Expense].[Class] = [CalculationLine].[DocumentClass] AND 
				[Expense].[ID] = [CalculationLine].[DocumentID]
		INNER JOIN inserted
			ON [CalculationLine].[CalculationID] = inserted.[ID]
		INNER JOIN deleted
			ON deleted.[ID] = inserted.[ID] AND 
				deleted.[State] != 4 AND inserted.[State] = 4
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotRecommitCalculationExpense', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END

	UPDATE
		[ServiceRequest]
	SET
		[ServiceRequest].[State] = 4,
		[ServiceRequest].[Modified] = DEFAULT,
		[ServiceRequest].[ModifiedBy] = DEFAULT
	FROM
		[ServiceRequest]
		INNER JOIN [CalculationLine]
			ON [ServiceRequest].[Class] = [CalculationLine].[DocumentClass] AND 
				[ServiceRequest].[ID] = [CalculationLine].[DocumentID]
		INNER JOIN inserted
			ON [CalculationLine].[CalculationID] = inserted.[ID]
		INNER JOIN deleted
			ON deleted.[ID] = inserted.[ID] AND 
				deleted.[State] != 4 AND inserted.[State] = 4
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotRecommitCalculationServiceRequest', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END

	UPDATE
		[EntryAmount]
	SET
		[Amount] = ROUND([TimeEntry].[RoundedDuration] / 60.0, 2),
		[Price] = ISNULL([TimeEntry].[Rate], 0)
	FROM 
		[EntryAmount]
		INNER JOIN [TimeEntry]
			ON [TimeEntry].[ID] = [EntryAmount].[ID]
		INNER JOIN [CalculationLine]
			ON [TimeEntry].[Class] = [CalculationLine].[DocumentClass] AND 
				[TimeEntry].[ID] = [CalculationLine].[DocumentID]
		INNER JOIN inserted
			ON [CalculationLine].[CalculationID] = inserted.[ID]
		INNER JOIN deleted
			ON deleted.[ID] = inserted.[ID] AND 
				deleted.[State] != 4 AND inserted.[State] = 4
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN
	END
	
	/*DELETE 
		[CalculationLine]
	FROM
		[CalculationLine]
	INNER JOIN inserted
		ON [CalculationLine].[CalculationID] = inserted.[ID]
	INNER JOIN deleted
		ON deleted.[ID] = inserted.[ID] AND 
			deleted.[State] != 4 AND inserted.[State] = 4
	IF @@ERROR != 0
	BEGIN
		RAISERROR('#CannotDeleteCalculationLine', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END*/
	
	UPDATE
		[Calculation]
	SET
		[Calculation].[State] = 2,
		[Calculation].[Modified] = DEFAULT,
		[Calculation].[ModifiedBy] = DEFAULT
	FROM
		[Calculation]
		INNER JOIN [CalculationAdvance]
			ON [CalculationAdvance].[AdvanceCalculationID] = [Calculation].[ID] 
		INNER JOIN inserted
			ON [CalculationAdvance].[CalculationID] = inserted.[ID]
		INNER JOIN deleted
			ON deleted.[ID] = inserted.[ID] AND 
				deleted.[State] != 4 AND inserted.[State] = 4
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotRecommitCalculationAdvance', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END
		
	/*DELETE
		[CalculationAdvance]
	FROM
		[CalculationAdvance]
	INNER JOIN inserted
		ON [CalculationAdvance].[CalculationID] = inserted.[ID]
	INNER JOIN deleted
		ON deleted.[ID] = inserted.[ID] AND 
			deleted.[State] != 4 AND inserted.[State] = 4
	IF @@ERROR != 0
	BEGIN
		RAISERROR('#CannotDeleteCalculationAdvance', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END*/
	
	DELETE
		[Attachment]
	FROM 
		[Attachment]
	INNER JOIN inserted
		ON [Attachment].[LinkDocumentID] = inserted.[ID] AND
			[Attachment].[LinkDocumentClass] = inserted.[Class]
	INNER JOIN deleted
		ON deleted.[ID] = inserted.[ID] AND 
			deleted.[State] != 4 AND inserted.[State] = 4
	IF @@ERROR != 0
	BEGIN
		RAISERROR('#CannotDeleteCalculationAdvance', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END	
	
END

GO
