/******************************************************************************
**		Name: pjm6ExchangeSyncCompanyCreate
**		Auth: pavel.svintsov
**		Date: 08/02/2011 12:32:25
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		08.02.11	SPV				first version
*******************************************************************************/
IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm6ExchangeSyncCompanyCreate]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm6ExchangeSyncCompanyCreate'
		DROP PROCEDURE [dbo].[pjm6ExchangeSyncCompanyCreate]
	END
GO
PRINT 'Creating procedure pjm6ExchangeSyncCompanyCreate'
GO

SET QUOTED_IDENTIFIER ON
GO
-------------------------------------------------------------------------------
CREATE PROCEDURE [pjm6ExchangeSyncCompanyCreate]
	@FileAs TName,
	@UserID TIdentifier,
	@ID TIdentifier OUT
AS
	DECLARE 
			@State TState,
			@LegalName TName,
			@LegalCode TCode,
			@Comments TNotes,
			@Class TClass,
			@Result int
			
			
	SET NOCOUNT ON
	
	SET @State = dbo.adfwfGetInitialState('5206f98c-4e57-44ea-8dc9-0ab6b81fd9c2')
	IF @State IS NULL
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END

	SET @LegalName = @FileAs
	SET @Comments = 'from Exchange'
	SET @Class = dbo.adfGetClassByName('Adf.Company')
		
	BEGIN TRANSACTION
	
		INSERT INTO [Company]
			([State], [FileAs], [LegalName], [Own], [Comments])
		VALUES
			(@State, @FileAs, @LegalName, 0, @Comments)

		SET @ID = SCOPE_IDENTITY()

		INSERT INTO [ExtendedProperties] ([ID], [Class], [ExtendedProperties])
		VALUES(@ID, @Class, NULL)	

		IF @@ERROR != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END
		
		INSERT INTO [BusinessCard] ([ID], [Class], [State], [FileAs], [Flag])
		VALUES (@ID, @Class, @State, @FileAs, 0)
		
		IF @@error != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END
		
		INSERT INTO UserContact ([UserID], [BusinessCardClass], [BusinessCardID])
			VALUES(@UserID, @Class, @ID)
		IF @@ERROR != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END
	
	COMMIT TRANSACTION	

	RETURN 0
GO

GRANT EXECUTE ON pjm6ExchangeSyncCompanyCreate TO PUBLIC
GO

/******************************************************************************
**		Name: pjm6ExchangeSyncContactCreate
**		Auth: pavel.svintsov
**		Date: 08/02/2011 12:32:25
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:		Description:
**		08.02.11	SPV			first version
**		15.06.11	SPV			    
**		22.06.11	SPV			     (fix)	
*******************************************************************************/
IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm6ExchangeSyncContactCreate]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm6ExchangeSyncContactCreate'
		DROP PROCEDURE [dbo].[pjm6ExchangeSyncContactCreate]
	END
GO
PRINT 'Creating procedure pjm6ExchangeSyncContactCreate'
GO
-------------------------------------------------------------------------------
CREATE PROCEDURE [pjm6ExchangeSyncContactCreate]
	@Title			TCode,
	@FirstName		TPersonName,
	@MiddleName		TPersonName,
	@LastName		TPersonName,
	@FileAs			TName,
	@Suffix			TCode,
	@Comments		TNotes,
	@Initials		TCode,
	@NextContact	TDate,
	@BirthDate		TDate,
	@Email1			TName,
	@Email2			TName,
	@Email3			TName,
	@MobilePhone	TName,
	@UserID			TIdentifier,
	@ID				TIdentifier OUT
AS
	DECLARE 
		@State	TState,
		@Class	TClass
	
	SET NOCOUNT ON
	
	SET @State = dbo.adfwfGetInitialState('219e9b7e-153a-4e93-ab63-0b3785d67c8a')
	
	BEGIN TRANSACTION
	
	SELECT
		@ID = [Employee].[ID]
	FROM
		[Employee]
		INNER JOIN [Email]
			ON [Email].[BusinessCardClass] = [Employee].[Class] AND [Email].[BusinessCardID] = [Employee].[ID]
	WHERE
		ISNULL([Employee].[FirstName], -1) = ISNULL(@FirstName, -1) AND
		ISNULL([Employee].[LastName], -1) = ISNULL(@LastName, -1) AND
		ISNULL([Employee].[MiddleName], -1) = ISNULL(MiddleName, -1) AND
		(
			[Email].[Email] IN (@Email1, @Email2, @Email3) OR
			[Email].[Email] IS NULL OR
			@Email1 IS NULL AND @Email2 IS NULL AND @Email3 IS NULL
		)

	SET @Class = dbo.adfGetClassByName('Adf.Employee')

	IF @ID IS NULL
	SELECT
		@ID = [Employee].[ID]
	FROM
		[Employee]
		INNER JOIN [Phone]
			ON [Phone].[BusinessCardClass] = [Employee].[Class] AND [Phone].[BusinessCardID] = [Employee].[ID] AND [Phone].[PhoneTypeID] = 3
	WHERE
		ISNULL([Employee].[FirstName], -1) = ISNULL(@FirstName, -1) AND
		ISNULL([Employee].[LastName], -1) = ISNULL(@LastName, -1) AND
		ISNULL([Employee].[MiddleName], -1) = ISNULL(MiddleName, -1) AND
		(
			[Phone].[Phone] = @MobilePhone OR
			[Phone].[Phone] IS NULL OR
			@MobilePhone IS NULL
		)

	--    
	IF EXISTS 
	(
		SELECT * 
		FROM [Employee]
		INNER JOIN [Company] ON [Company].[ID] = [Employee].[CompanyID]
		WHERE [Employee].[ID] = @ID AND [Company].[Own] = 1
	)
	BEGIN
		ROLLBACK TRANSACTION
		SET @ID = NULL
		RETURN 0
	END
	
	DECLARE @IsNew TBool
	IF @ID IS NULL
		SET @IsNew = 1

	IF @ID IS NULL	--  
	BEGIN
		INSERT INTO [Employee]
			([State], [FileAs], [Comments], [NextContact],
			[Title], [FirstName], [MiddleName], [LastName], [Suffix], [BirthDate], [Initials])
		VALUES
			(@State, @FileAs, @Comments, @NextContact,
			@Title, @FirstName, @MiddleName, @LastName, @Suffix, @BirthDate, @Initials)
		IF @@ERROR != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END

		SET @ID = SCOPE_IDENTITY()
			
		INSERT INTO [ExtendedProperties] 
			([ID], [Class], [ExtendedProperties])
		VALUES
			(@ID, @Class, NULL)	
		IF @@ERROR != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END

		INSERT INTO [BusinessCard] ([ID], [Class], [State], [FileAs], [Flag])
			VALUES (@ID, @Class, @State, @FileAs, 0)
		IF @@error != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END
	END
	ELSE --  
	BEGIN
		UPDATE [Employee]
		SET
			[FileAs] = @FileAs,
			[Comments] = @Comments,
			[NextContact] = @NextContact,
			[Title] = @Title,
			[FirstName] = @FirstName,
			[MiddleName] = @MiddleName,
			[LastName] = @LastName,
			[Suffix] = @Suffix,
			[BirthDate] = @BirthDate,
			[Initials] = @Initials
		WHERE
			[Employee].[ID] = @ID

		UPDATE [ExtendedProperties] 
		SET [ExtendedProperties] = NULL
		WHERE
			[ID] = @ID AND
			[Class] = @Class
		
		IF @@ERROR != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END

		UPDATE [BusinessCard] 
		SET [FileAs] = @FileAs
		WHERE 
			[Class] = @Class AND
			[ID] = @ID
		IF @@error != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END
	END

	IF NOT EXISTS (SELECT * FROM [UserContact] WHERE [UserID] = @UserID AND [BusinessCardClass] = @Class AND [BusinessCardID] = @ID)
		INSERT INTO [UserContact] ([UserID], [BusinessCardClass], [BusinessCardID])
			VALUES(@UserID, @Class, @ID)
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	
	COMMIT TRANSACTION	
	
	RETURN 0
GO



GRANT EXECUTE ON pjm6ExchangeSyncContactCreate TO PUBLIC
GO
