IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5ExpenseCreateInternal]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5ExpenseCreateInternal'
		DROP PROCEDURE [dbo].[pjm5ExpenseCreateInternal]
	END
GO

PRINT 'Creating procedure pjm5ExpenseCreateInternal'
GO

/******************************************************************************
**		File: pjm5ExpenseCreateInternal.sql
**		Name: pjm5ExpenseCreateInternal
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: pavel.boruroev
**		Date: 01/20/2005 16:11:01
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**      30.07.10	MAN				 ,     
**		13.09.12	MAB				   Amount c TCount  TAmount
*******************************************************************************/
CREATE PROCEDURE [pjm5ExpenseCreateInternal]
	@ID TIdentifier OUTPUT,
	@FileAs TName,
	@EmployeeID TIdentifier,
	@ProjectID TIdentifier,
	@DocumentClass TClass,
	@DocumentID TIdentifier,
	@TaskID TIdentifier,
	@ExpenseCodeID TIdentifier,
	@Date TDateTime,
	@UOMID TIdentifier,
	@Amount TAmount,
	@Billable TBool,
	@Price TMoney,
	@FromCurrencyCode TCode3,
	@ToCurrencyCode TCode3,
	@CurrencyRate TAmount,
	@VATRate TPercent,
	@VATIsIncluded TBool,
	@Vat TMoney,
	@Comments TNotes
AS
	DECLARE 
		@State TState,
		@rv int,
		@value TVariant,
		@CurrentEmployeeID TIdentifier,
		@ExpenseSecretary TBool
	
	SET NOCOUNT ON
	IF @ProjectID IS NULL
	BEGIN
		RAISERROR('#ProjectIsNotDefined', 18, -1)
		RETURN 1
	END

	IF (@DocumentID IS NOT NULL 
		AND @DocumentClass IS NOT NULL
		AND NOT EXISTS(SELECT TOP(1) [ID] FROM [Document] WHERE [Class] = @DocumentClass AND [ID] = @DocumentID))
	BEGIN
		RAISERROR('#CannotRetrieveDeletedDocument', 18, -1)
		RETURN 1
	END

	SET @CurrentEmployeeID = dbo.adfGetCurrentEmployeeID()
	IF @EmployeeID IS NULL
		SET @EmployeeID = @CurrentEmployeeID

	IF @EmployeeID IS NULL
	BEGIN
		RAISERROR('#assignmentnotfound', 18, -1)
		RETURN 1
	END

	IF NOT EXISTS(SELECT * FROM [vwAssignment] WHERE [ProjectID] = @ProjectID AND [EmployeeID] = @EmployeeID AND [State]=1)
	BEGIN
		RAISERROR('#notassignedtospecifiedproject', 18, -1)
		RETURN 1
	END

	SET @ExpenseSecretary = dbo.adfHasAccessRightByName('ManageExpenseWithoutAssignment')
	IF dbo.fnPjm5AllowCreateProjectEntry(@ProjectID, @EmployeeID) = 0 AND @ExpenseSecretary = 0
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END

	IF @Amount IS NULL OR @Amount < 0
	BEGIN
		RAISERROR('#AmountCannotBeNull', 18, -1)
		RETURN 1
	END
	IF @CurrencyRate = 0
	BEGIN
		RAISERROR('#CurrencyRateCannotBeNull', 18, -1)
		RETURN 1
	END

	IF @ExpenseCodeID IS NULL
	BEGIN
		EXEC adfParameterGet 'ExpenseCodeIsMandatory', 'Pjm5', @value OUTPUT
		IF @value IS NULL OR CAST(@value as BIT) = 1
		BEGIN
			RAISERROR('#expensecodecannotbenull', 18, -1)
			RETURN 1
		END
	END

	SET @State = dbo.adfwfGetInitialState('5370b541-f4f5-45da-a99c-bd1ff91344b6')
	IF @State IS NULL
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END
	
	IF NOT EXISTS (SELECT * FROM [Project] WHERE [ID] = @ProjectID AND [State] IN (2, 3, 4))
	BEGIN
		RAISERROR('#ProjectIsNotActive', 18, -1)
		RETURN 1
	END

	IF @TaskID IS NOT NULL 
	BEGIN
		IF NOT EXISTS (SELECT * FROM [Task] WHERE [ID] = @TaskID AND [ProjectID] = @ProjectID)
		BEGIN
			RAISERROR('#TaskFromAnotherProject', 18, -1)
			RETURN 1
		END

		IF NOT EXISTS (SELECT * FROM [Task] WHERE [ID] = @TaskID AND [State] IN (2, 3, 5))
		BEGIN
			RAISERROR('#TaskIsDraft', 18, -1)
			RETURN 1
		END
		
		DECLARE @AssignmentID TIdentifier
		SET @AssignmentID = dbo.fnPjm5GetProjectAssignment(@ProjectID, @EmployeeID)
		IF EXISTS(SELECT * FROM [TaskAssignment] 
						WHERE [TaskID] = @TaskID AND [AssignmentID] = @AssignmentID AND [TaskAssignment].[MsAvailable] = 0)
		BEGIN
			RAISERROR('#taskassignmentnotfound', 18, -1)
			RETURN 1
		END		
	END

	DECLARE @nationalCurrency TCode3
	EXEC adfParameterGet 'NationalCurrency', 'CommonBusiness', @value OUTPUT
	SET @nationalCurrency = CAST(@value as varchar(3))

	DECLARE @TotalWithVATPC TMoney, @TotalPC TMoney
	IF @VATIsIncluded = 1
	BEGIN
		SET @TotalPC = @Amount * @Price - @VAT
		SET @TotalWithVATPC = @Amount * @Price
	END
	ELSE
	BEGIN
		SET @TotalPC = @Amount * @Price
		SET @TotalWithVATPC = @Amount * @Price + @VAT
	END
	
	IF @FromCurrencyCode != @ToCurrencyCode
	BEGIN
		IF @FromCurrencyCode = @nationalCurrency
		BEGIN
			SET @TotalPC = ROUND(@TotalPC / @CurrencyRate, 2)
			SET @TotalWithVATPC = ROUND(@TotalWithVATPC / @CurrencyRate, 2)
		END
		ELSE
		BEGIN
			SET @TotalPC = ROUND(@TotalPC * @CurrencyRate, 2)
			SET @TotalWithVATPC = ROUND(@TotalWithVATPC * @CurrencyRate, 2)
		END
		 
		IF @Amount != 0
		BEGIN
			IF @VATIsIncluded = 1
			BEGIN
				SET @TotalWithVATPC = ROUND(@TotalWithVATPC / @Amount, 2) * @Amount
				SET @TotalPC = ROUND(@TotalWithVATPC / (1.0 + @VATRate), 2)
			END
			ELSE
			BEGIN
				SET @TotalPC = ROUND(@TotalPC / @Amount, 2) * @Amount
				SET @TotalWithVATPC = ROUND(@TotalPC * (1.0 + @VATRate), 2)
			END
		END
	END

	INSERT INTO [Expense]
		([Flag], [State], [FileAs], [ProjectID], [DocumentClass], [DocumentID], [TaskID], [ExpenseCodeID], 
		[Date], [Amount], [Billable], [Price], [FromCurrencyCode], [ToCurrencyCode], [CurrencyRate], 
		[VATRate], [VATIsIncluded], [VAT], [Comments], [EmployeeID],[TotalWithVATPC],[TotalPC], [UOMID])
	VALUES
		(0,	@State, @FileAs, @ProjectID, @DocumentClass, @DocumentID, @TaskID, @ExpenseCodeID, 
		@Date, @Amount, @Billable,	ROUND(@Price, 2), @FromCurrencyCode, @ToCurrencyCode,	@CurrencyRate, 
		@VATRate, @VATIsIncluded, ROUND(@Vat, 2), @Comments, @EmployeeID,@TotalWithVATPC,@TotalPC,@UOMID)
			
	IF @@ERROR != 0
	BEGIN
		RETURN 1
	END
	SET @ID = SCOPE_IDENTITY()

	DECLARE @sendToApprove bit, @approve bit, @userID int
	SET @userID = dbo.adfGetCurrentUserID()
	SET @value = NULL
	SELECT @value = [Value] FROM [UserParameter] WHERE [Name] = 'ExpenseSendForApproving' AND [UserID] = @userID
	SET @sendToApprove = ISNULL(CAST(@value as bit), 1)

	SET @approve = 0
	IF @CurrentEmployeeID = @EmployeeID AND dbo.fnPjm5IsProjectManager(@ProjectID, @CurrentEmployeeID) = 1
	BEGIN
		SET @value = NULL
		SELECT @value = [Value] FROM [UserParameter] WHERE [Name] = 'ExpenseEntryApprove' AND [UserID] = @userID
		SET @approve = ISNULL(CAST(@value as bit), 1)
	END

	IF @sendToApprove = 1 OR @approve = 1
	BEGIN
		EXEC @rv = pjm5ExpenseChangeState @ID, 2
		IF @rv != 0
		BEGIN
			RETURN @rv
		END
	END

	IF @approve = 1
	BEGIN
		EXEC @rv = pjm5ExpenseChangeState @ID, 3
		IF @rv != 0
		BEGIN
			RETURN @rv
		END
	END

	RETURN 0
GO

GRANT EXECUTE ON pjm5ExpenseCreateInternal TO PUBLIC
GO
  