IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'pjm5GroupCreate')
	BEGIN
		PRINT 'Dropping Procedure pjm5GroupCreate'
		DROP  Procedure  pjm5GroupCreate
	END

GO

PRINT 'Creating Procedure pjm5GroupCreate'
GO
/******************************************************************************
**		File: 
**		Name: pjm5GroupCreate
**		Desc: 
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE PROCEDURE pjm5GroupCreate
	@Name TSysname,
	@DisplayName TName,
	@Comments TNotes
AS
	DECLARE @ID TIdentifier,
			@result INT
	
	SET NOCOUNT ON

	EXEC @result = adfAccessRightCheck 'ManageGroups'
	IF @result != 0
		RETURN @result

	BEGIN TRANSACTION
	
	INSERT INTO [Trustee] 
		([Name], [DisplayName], [Comments]) 
	VALUES
		(@Name, @DisplayName, @Comments)
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	
	SET @ID = SCOPE_IDENTITY()
	
	INSERT INTO [Role] ([ID], [IsGroup]) VALUES(@ID, 1)
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	
	COMMIT TRANSACTION
	
	EXEC pjm5GroupGet @ID

	RETURN 0
GO

GRANT EXEC ON pjm5GroupCreate TO PUBLIC
GO

IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'pjm5GroupUpdate')
	BEGIN
		PRINT 'Dropping Procedure pjm5GroupUpdate'
		DROP  Procedure  pjm5GroupUpdate
	END

GO

PRINT 'Creating Procedure pjm5GroupUpdate'
GO
/******************************************************************************
**		File: 
**		Name: pjm5GroupUpdate
**		Desc: 
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE Procedure pjm5GroupUpdate
	@ID TIdentifier,
	@Name TSysname,
	@DisplayName TName,
	@Comments TNotes
AS
	SET NOCOUNT ON
	
	DECLARE @result INT
	
	EXEC @result = adfAccessRightCheck 'ManageGroups'
	IF @result != 0
		RETURN @result
	
	UPDATE [Trustee]
	SET
		[Trustee].[Name] = @Name,
		[Trustee].[DisplayName] = @DisplayName,
		[Trustee].[Comments] = @Comments
	WHERE
		[Trustee].[ID] = @ID

	EXEC pjm5GroupGet @ID
	
	RETURN 0
GO

GRANT EXEC ON pjm5GroupUpdate TO PUBLIC
GO

 
IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'pjm5GroupGet')
	BEGIN
		PRINT 'Dropping Procedure pjm5GroupGet'
		DROP  Procedure  pjm5GroupGet
	END

GO

PRINT 'Creating Procedure pjm5GroupGet'
GO
/******************************************************************************
**		File: 
**		Name: pjm5GroupGet
**		Desc: 
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE Procedure pjm5GroupGet
	@ID TIdentifier
AS
	SET NOCOUNT ON

	SELECT     
		[Trustee].[ID], 
		1 as [State],
		[Trustee].[Name], 
		[Trustee].[DisplayName], 
		[Trustee].[Created], 
		[Trustee].[CreatedBy], 
		[Trustee].[Modified], 
		[Trustee].[ModifiedBy], 
		[Trustee].[Comments]
	FROM         
		[Role] INNER JOIN [Trustee] 
			ON ([Role].[ID] = [Trustee].[ID])
	WHERE
		[Role].[ID] = @ID AND [IsGroup] = 1

	RETURN 0
GO

GRANT EXEC ON pjm5GroupGet TO PUBLIC
GO

IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'pjm5GroupBrowse')
	BEGIN
		PRINT 'Dropping Procedure pjm5GroupBrowse'
		DROP  Procedure  pjm5GroupBrowse
	END

GO

PRINT 'Creating Procedure pjm5GroupBrowse'
GO
/******************************************************************************
**		File: 
**		Name: pjm5GroupBrowse
**		Desc: 
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE Procedure pjm5GroupBrowse
AS
	SET NOCOUNT ON

	SELECT     
		[Trustee].[ID], 
		1 as [State],
		[Trustee].[Name], 
		[Trustee].[DisplayName], 
		[Trustee].[Created], 
		[Trustee].[CreatedBy], 
		[Trustee].[Modified], 
		[Trustee].[ModifiedBy], 
		[Trustee].[Comments]
	FROM         
		[Role] INNER JOIN [Trustee] 
			ON ([Role].[ID] = [Trustee].[ID])
	WHERE
		[IsGroup] = 1

	RETURN 0
GO

GRANT EXEC ON pjm5GroupBrowse TO PUBLIC
GO

IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'pjm5GroupDelete')
	BEGIN
		PRINT 'Dropping Procedure pjm5GroupDelete'
		DROP  Procedure  pjm5GroupDelete
	END

GO

PRINT 'Creating Procedure pjm5GroupDelete'
GO
/******************************************************************************
**		File: 
**		Name: pjm5GroupDelete
**		Desc: 
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE PROCEDURE pjm5GroupDelete
	@ID TIdentifier
AS
	DECLARE @result INT 
	
	SET NOCOUNT ON

	EXEC @result = adfAccessRightCheck 'ManageGroups'
	IF @result != 0
		RETURN @result

	BEGIN TRANSACTION
	
	DELETE [UserRole] WHERE [RoleID] = @ID
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	
	DELETE [Trustee] WHERE [Trustee].[ID] = @ID
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	
	COMMIT TRANSACTION
	
	RETURN 0
GO

GRANT EXEC ON pjm5GroupDelete TO PUBLIC
GO
