IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'InvoicePlannedBrowse')
	BEGIN
		PRINT 'Dropping Procedure InvoicePlannedBrowse'
		DROP  Procedure  InvoicePlannedBrowse
	END

GO

PRINT 'Creating Procedure InvoicePlannedBrowse'
GO

--------------------------------------------------------------------------------------
-- Copyright (c) 2003 by Avicom
--------------------------------------------------------------------------------------
-- $Archive: $
-- $Author: $
-- $Revision: $
-- $Modtime: $
-- $Date: $
--
-- Description: this stored procedure ...........
-- Input:	.........
-- Output:      0 - success, negative number - otherwise
--
-- Notes:       no
--
--
/* $Log: $ 
   $NoKeywords: $ 
--------------------------------------------------------------------------------------*/
CREATE Procedure InvoicePlannedBrowse
	@ProjectCategoryID TIdentifier	
AS
	SET NOCOUNT ON
	DECLARE
		@CurrentEmployeeID TIdentifier,
		@ViewAllProjects TBool,
		@ViewAllFinance TBool,
		@ViewFinance TBool

	SET @ViewAllProjects = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllProjects'))
	SET @ViewAllFinance = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllFinance'))
	SET @ViewFinance = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewFinance'))
	SET @CurrentEmployeeID = dbo.adfGetCurrentEmployeeID()
		
	DECLARE 
		@MonthStart		datetime,
		@MonthEnd		datetime,
		@NextMonthStart	datetime,
		@NextMonthEnd	datetime,
		@QuartStart		datetime,
		@QuartEnd		datetime,
		@NextQuartStart	datetime,
		@NextQuartEnd	datetime,
		@YearStart		datetime,
		@YearEnd		datetime,
		@NextYearStart	datetime,
		@NextYearEnd	datetime,
	    @Date			datetime,
		@DayCount		int,
	    @MonthCount		int,
	    @QuarterCount	int,
	    @value TVariant,
	    @NationalCurrency varchar(8)
		
	EXEC adfParameterGet 'NationalCurrency', 'CommonBusiness', @value OUTPUT	
	SET @NationalCurrency = CAST(@value AS varchar(8))
	
	SELECT 
		@Date = CAST(CONVERT(varchar(8), GETDATE(), 112) AS DATETIME),
		@DayCount = DATEPART(day,@Date),
		@MonthCount = DATEPART(month,@Date),
		@QuarterCount = DATEPART(quarter,@Date),
			
	    @MonthStart = DATEADD(day, 1 - @DayCount, @Date),
		@MonthEnd = DATEADD(month, 1, @MonthStart),
	
		@NextMonthStart = @MonthEnd,
		@NextMonthEnd = DATEADD(month, 1, @NextMonthStart),
		
		@QuartStart	= DATEADD(quarter,@QuarterCount-1,DATEADD(month, 1 - @MonthCount, @MonthStart)),
		@QuartEnd = DATEADD(quarter, 1, @QuartStart),
		@QuartStart	= @MonthStart,
	
		@NextQuartStart	= @QuartEnd,
		@NextQuartEnd = DATEADD(quarter, 1, @NextQuartStart),
		
		@YearStart = DATEADD(month, 1 - @MonthCount, @MonthStart),
		@YearEnd = DATEADD(year, 1, @YearStart),
		@YearStart = @MonthStart,
		
		@NextYearStart = @YearEnd,
		@NextYearEnd = DATEADD(year, 1, @NextYearStart)
		
		
	SELECT DISTINCT
		[Project].[Class],
		[Project].[ID],
		-1 AS [State],
		[Project].[FileAs],
		[Project].[SupplierCompanyID],
		[Project].[CustomerCompanyID],
		[Project].[CurrencyCode],
		[Project].[PaymentCurrencyPoint],
		dbo.fnPjm5GetInvoicePlanned([Project].[ID],@MonthStart,@MonthEnd, @Date, @NationalCurrency) AS [MonthSum],
		dbo.fnPjm5GetInvoicePlanned([Project].[ID],@NextMonthStart,@NextMonthEnd, @Date, @NationalCurrency) AS [NextMonthSum],
		dbo.fnPjm5GetInvoicePlanned([Project].[ID],@QuartStart,@QuartEnd, @Date, @NationalCurrency) AS [QuartSum],
		dbo.fnPjm5GetInvoicePlanned([Project].[ID],@NextQuartStart,@NextQuartEnd, @Date, @NationalCurrency) AS [NextQuartSum],
		dbo.fnPjm5GetInvoicePlanned([Project].[ID],@YearStart,@YearEnd, @Date, @NationalCurrency) AS [YearSum],
		dbo.fnPjm5GetInvoicePlanned([Project].[ID],@NextYearStart,@NextYearEnd, @Date, @NationalCurrency) AS [NextYearSum],
		dbo.fnPjm5GetInvoicePlanned([Project].[ID],@MonthStart,NULL, @Date, @NationalCurrency) AS [Sum],
		[Company].[ManagerEmployeeID],
		[Project].[ProjectManagerEmployeeID],
		[Project].[CostCenterID],
		[Project].[CreatedBy],
		[Project].[Created],
		[Project].[ModifiedBy],
		[Project].[Modified],
		[Project].[Comments]
	FROM
		[Project]
			INNER JOIN [Company]
				ON [Project].[CustomerCompanyID] = [Company].[ID]
			LEFT OUTER JOIN [adfvwDocumentCategory]
				ON ([Project].[Class] = [adfvwDocumentCategory].[DocumentClass] AND [Project].[ID] = [adfvwDocumentCategory].[DocumentID])
	WHERE 
		(
			(@ViewAllFinance = 1) OR
			(
				@ViewFinance = 1 AND
				(
					@ViewAllProjects = 1 OR
					[Company].[ManagerEmployeeID] = @CurrentEmployeeID OR 
					[Project].[ProjectManagerEmployeeID] = @CurrentEmployeeID OR
					dbo.fnPjm5HasFinansDataAccess([Project].[ID], @CurrentEmployeeID, NULL, NULL) = 1
				)
			)
		) AND
		dbo.fnPjm5GetInvoicePlanned([Project].[ID],@MonthStart,NULL, @Date, @NationalCurrency) IS NOT NULL AND 
		[Project].[State] IN (1,2,3,4)
		AND
		(
			@ProjectCategoryID is NULL OR
			ISNULL([adfvwDocumentCategory].[CategoryID], 0) = ISNULL(@ProjectCategoryID, 0)
		)			
	
RETURN 0
GO

GRANT EXEC ON InvoicePlannedBrowse TO PUBLIC

GO
