 IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'lmCalendarEmployees')
	BEGIN
		PRINT 'Dropping Procedure lmCalendarEmployees'
		DROP  Procedure  lmCalendarEmployees
	END

GO

PRINT 'Creating Procedure lmCalendarEmployees'
GO
/******************************************************************************
**		File: 
**		Name: lmCalendarEmployees
**		Desc: 
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE Procedure lmCalendarEmployees
AS
	SET NOCOUNT ON
	
	DECLARE @UserID TIdentifier
	SET @UserID = dbo.adfGetCurrentUserID()
	
	CREATE TABLE #accessible ( [ID] INT, [FileAs] nvarchar(256), [CompanyID] INT, [State] INT, [UserID] INT, [Own] BIT, [Initials] varchar(32), [Strong] INT)
	
	INSERT INTO #accessible
	EXEC lmCalendarEmployeesAccessibleInternal
	
	SELECT
		[ID],
		[FileAs] as [Name],
		CAST((CASE WHEN [CalendarEmployee].[UserID] IS NULL THEN 0 ELSE 1 END) as BIT) as [Selected]
	FROM
		[#accessible] LEFT OUTER JOIN [CalendarEmployee]
			ON ([#accessible].[ID] = [CalendarEmployee].[EmployeeID] AND [CalendarEmployee].[UserID] = @UserID)
	WHERE
		[#accessible].[State] = 1 AND [#accessible].[Own] = 1
	
	RETURN 0
GO

GRANT EXEC ON lmCalendarEmployees TO PUBLIC
GO
 
 IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'lmCalendarEmployeesAccessibleInternal')
	BEGIN
		PRINT 'Dropping Procedure lmCalendarEmployeesAccessibleInternal'
		DROP  Procedure  lmCalendarEmployeesAccessibleInternal
	END

GO
 
PRINT 'Creating Procedure lmCalendarEmployeesAccessibleInternal'
GO
/******************************************************************************
**		File: 
**		Name: lmCalendarEmployeesAccessibleInternal
**		Desc: 
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE Procedure lmCalendarEmployeesAccessibleInternal
AS
	SET NOCOUNT ON
	IF dbo.adfHasAccessRightByName('ViewAllProjects') = 1 OR 
		dbo.adfHasAccessRightByName('ViewAllEmployees') = 1
			
			SELECT
			[Employee].[ID],
			[Employee].[FileAs] as [Name],
			[Employee].[CompanyID],
			[Employee].[State],
			[Employee].[UserID],
			[Company].[Own],
			[Employee].[Initials] as [Code],
			1 AS [Strong] 
		FROM
			[Employee] 
			INNER JOIN [Company]
				ON ([Employee].[CompanyID] = [Company].[ID])
		WHERE [Company].[State] = 1	AND [Company].[Own] = 1  AND 
			[Employee].[State] != 2
		
	ELSE
	BEGIN
		DECLARE
			@EmployeeID int,
			@ManageProject		TBOOL
		SET @EmployeeID = dbo.adfGetCurrentEmployeeID()	
		SET @ManageProject = dbo.adfHasAccessRightByName('ManageProject')
			
		SELECT
			[Employee].[ID],
			[Employee].[FileAs] as [Name],
			[Employee].[CompanyID],
			[Employee].[State],
			[Employee].[UserID],
			[Company].[Own],
			[Employee].[Initials] as [Code],
			CASE [Employee].[ID] 
				WHEN @EmployeeID THEN 1
				ELSE @ManageProject
			END AS [Strong]
		FROM
			[Employee]
			INNER JOIN [Company]
				ON ([Employee].[CompanyID] = [Company].[ID])
			INNER JOIN fnPjm6GetAvailableProjectsAssignment() AS APA
				ON ([Employee].[ID] = [APA].[ID])
		WHERE
			[Company].[State] = 1 AND
			[Employee].[State] != 2 
	END
	RETURN 0
GO

GRANT EXEC ON lmCalendarEmployeesAccessibleInternal TO PUBLIC
GO