IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'lmIssueProjects')
	BEGIN
		PRINT 'Dropping Procedure lmIssueProjects'
		DROP  Procedure  lmIssueProjects
	END

GO

PRINT 'Creating Procedure lmIssueProjects'
GO
/******************************************************************************
**		File: 
**		Name: lmIssueProjects
**		Desc: 
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		21.04.11	SPV				     
**									   
*******************************************************************************/
CREATE Procedure lmIssueProjects
AS
	SET NOCOUNT ON

	DECLARE @EmployeeID TIdentifier,
			@UserID TIdentifier
	SET @EmployeeID = dbo.adfGetCurrentEmployeeID()
	SET @UserID = dbo.adfGetCurrentUserID()
	DECLARE @IsAssistant TBool
	SET @IsAssistant = dbo.fnPjm5IsAssistant()	
	
	DECLARE @v1 TCode,
			@v2 TCode
			
	IF dbo.adfGetLanguage() = 'ru'
		SELECT @v1 = '(  )', @v2 = '(  )'
	ELSE
		SELECT @v1 = '(All Selected Projects)', @v2 = '(All My Projects)'
	
	IF EXISTS(SELECT *
	FROM
		[Project] INNER JOIN [IssueProject]
			ON ([Project].[ID] = [IssueProject].[ProjectID] AND [IssueProject].[UserID] = @UserID)
	WHERE
		[State] = 2 AND [Project].[SupportsRequestManagement] != 0 AND 
		([Project].[ID] IN (SELECT [ID] FROM dbo.fnPjm6GetAvailableProjectsForProjectMemberAndManager()) OR @IsAssistant = 1))
	BEGIN
		SELECT
			[ID],
			[Number] as [Code],
			[FileAs] as [Name],
			CAST((CASE WHEN [IssueProject].[ProjectID] IS NULL THEN 0 ELSE 1 END) AS BIT) as [Selected]
		FROM
			[Project] LEFT OUTER JOIN [IssueProject]
				ON ([Project].[ID] = [IssueProject].[ProjectID] AND [IssueProject].[UserID] = @UserID)
		WHERE
			[State] = 2 AND [Project].[SupportsRequestManagement] != 0 AND 
			([Project].[ID] IN (SELECT [ID] FROM dbo.fnPjm6GetAvailableProjectsForProjectMemberAndManager()) OR @IsAssistant = 1)
		UNION ALL
		SELECT
			-1,
			@v1,
			@v1,
			1
		UNION ALL
		SELECT
			-2,
			@v2,
			@v2,
			1
	END
	ELSE
	BEGIN
		SELECT
			[ID],
			[Number] as [Code],
			[FileAs] as [Name],
			CAST((CASE WHEN [IssueProject].[ProjectID] IS NULL THEN 0 ELSE 1 END) AS BIT) as [Selected]
		FROM
			[Project] LEFT OUTER JOIN [IssueProject]
				ON ([Project].[ID] = [IssueProject].[ProjectID] AND [IssueProject].[UserID] = @UserID)
		WHERE
			[State] = 2 AND [Project].[SupportsRequestManagement] != 0 AND 
			([Project].[ID] IN (SELECT [ID] FROM dbo.fnPjm6GetAvailableProjectsForProjectMemberAndManager()) OR @IsAssistant = 1)
		UNION ALL
		SELECT
			-2,
			@v2,
			@v2,
			1
	END	
	
	RETURN 0
GO

GRANT EXEC ON lmIssueProjects TO PUBLIC
GO
   