IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'lmProject')
	BEGIN
		PRINT 'Dropping Procedure lmProject'
		DROP  Procedure  lmProject
	END

GO

PRINT 'Creating Procedure lmProject'
GO
/******************************************************************************
**		File: 
**		Name: lmProject
**		Desc: 
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		1.10.10		MAN				     [SupplierCompany], [CostCenter], [ProjectManagerEmployee]
**		1.11.10		MAN				     [ProjectType]
*******************************************************************************/
CREATE Procedure lmProject
AS
	SET NOCOUNT ON
		
	IF dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllProjects')) = 1 OR
		dbo.adfHasAccessRightByName('ManageExpenseWithoutAssignment') = 1
		SELECT
			[Project].[ID],
			[Number] as [Code],
			[FileAs] as [Name],
			[State],
			[ProjectTypeID] as [Type],
			[SupplierCompanyID] as [SupplierCompany],
			[CustomerCompanyID] as [CustomerCompany],
			[CostCenterID] as [CostCenter],
			[ProjectManagerEmployeeID] as [ProjectManagerEmployee],
			[ProjectTypeID] as [ProjectType],
			[SubProjects].[ProjectID] AS [ParentProjectID]
		FROM
			[Project]
			LEFT OUTER JOIN fnpjm6GetSubprojectsForBrowse() AS [SubProjects]
				ON [SubProjects].[SubprojectID] = [Project].[ID]
		WHERE
			[State] IN (1, 2, 3, 4)
	ELSE
	BEGIN
		DECLARE @EmployeeID TIdentifier
		SET @EmployeeID = dbo.adfGetCurrentEmployeeID()
		SELECT
			[ID],
			[Number] as [Code],
			[FileAs] as [Name],
			[State],
			[ProjectTypeID] as [Type],
			[SupplierCompanyID] as [SupplierCompany],
			[CustomerCompanyID] as [CustomerCompany],
			[CostCenterID] as [CostCenter],
			[ProjectManagerEmployeeID] as [ProjectManagerEmployee],
			[ProjectTypeID] as [ProjectType]
		FROM
			[Project]
		WHERE
			[State] IN (1, 2, 3, 4) AND
			([ProjectManagerEmployeeID] = @EmployeeID OR dbo.fnPjm5IsProjectMember([Project].[ID], @EmployeeID) = 1)
	END
	
	RETURN 0
GO

GRANT EXEC ON lmProject TO PUBLIC
GO
