IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5SubscriptionRuleGet]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5SubscriptionRuleGet'
		DROP PROCEDURE [dbo].[pjm5SubscriptionRuleGet]
	END
GO

PRINT 'Creating procedure pjm5SubscriptionRuleGet'
GO

/******************************************************************************
**		File: pjm5SubscriptionRuleGet.sql
**		Name: pjm5SubscriptionRuleGet
**		Desc: 
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: 
**		Date: 20/12/2005 13:00:00
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE PROCEDURE [pjm5SubscriptionRuleGet]
	@UserID TIdentifier
AS
	SET NOCOUNT ON
	
	DECLARE @IsDBOwner bit	
	IF IS_MEMBER('db_owner') = 1
		SET @IsDBOwner = 1
	ELSE
		SET @IsDBOwner = 0
	
	IF @UserID IS NULL
	BEGIN
		SET @UserID = dbo.adfGetCurrentUserID()
	END
	
	IF @UserID IS NULL
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END
	
	DECLARE @ViewAllProjects TBool
	SET @ViewAllProjects = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllProjects')) 
	
	DECLARE @Lang TLanguage
	SET @Lang = dbo.adfGetLanguage()
	
	DECLARE @EmployeeID TIdentifier
	SELECT @EmployeeID = [ID] FROM [Employee] WHERE [UserID] = @UserID
	
	-- select available employee's documents
	SELECT
		[Project].[Class],
		[Project].[ID],
		[Project].[Number],
		[Project].[FileAs]
	FROM
		[Project]
	WHERE
		([Project].[ProjectManagerEmployeeID] = @EmployeeID
		OR (dbo.fnPjm5IsProjectMember([Project].[ID], @EmployeeID) = 1)
		OR @ViewAllProjects = 1) AND
		([Project].[State] IN (1, 2))
		
	SELECT
		[SubscriptionType].[ID],
		ISNULL([SubscriptionTypeGlobal].[FileAs], [SubscriptionType].[FileAs]) AS [FileAs],
		[SubscriptionType].[DocumentClass]
	FROM
		[SubscriptionType]
		INNER JOIN [SubscriptionTypeRight]
			ON [SubscriptionType].[ID] = [SubscriptionTypeRight].[SubscriptionTypeID]
		INNER JOIN [Right]
			ON [Right].[ID] = [SubscriptionTypeRight].[RightID]
		INNER JOIN [AccessRight]
			ON [AccessRight].[RightID] = [Right].[ID]
		LEFT OUTER JOIN [SubscriptionTypeGlobal]
				ON ([SubscriptionType].[ID] = [SubscriptionTypeGlobal].[ID]
					AND [SubscriptionTypeGlobal].[Language] = @Lang)
	WHERE
		[SubscriptionType].[Code] NOT LIKE '%TaskRequest' AND
		(
			[SubscriptionType].[ExternalInitiator] = 0 AND([AccessRight].[TrusteeID] = @UserID) OR (@IsDBOwner = 1) 
			OR
			([AccessRight].[TrusteeID] IN (SELECT [UserRole].[RoleID] FROM [UserRole] WHERE [UserRole].[UserID] = @UserID))
		)
	GROUP BY
		[SubscriptionType].[ID],
		[SubscriptionType].[FileAs],
		[SubscriptionTypeGlobal].[FileAs],
		[SubscriptionType].[DocumentClass]
		
	-- select employee's rules
	SELECT
		[ID],
		[State],
		[FileAs]
	FROM
		[SubscriptionRule]
	WHERE
		[UserID] = @UserID AND [SubscriptionRule].[ExternalInitiator] = 0
	
	-- select all rule' subscriptions
	SELECT
		[Subscription].[SubscriptionTypeID],
		[SubscriptionRule].[ID] AS [SubscriptionRuleID]
	FROM
		[SubscriptionRule]
		INNER JOIN [Subscription]
			ON [Subscription].[SubscriptionRuleID] = [SubscriptionRule].[ID]
	WHERE
		[SubscriptionRule].[UserID] = @UserID AND [SubscriptionRule].[ExternalInitiator] = 0
		
	-- select all rule' documents
	SELECT
		[DocumentSubscriptionRule].[DocumentClass],
		[DocumentSubscriptionRule].[DocumentID],
		[SubscriptionRule].[ID] AS [SubscriptionRuleID]
	FROM
		[SubscriptionRule]
		INNER JOIN [DocumentSubscriptionRule]
			ON [DocumentSubscriptionRule].[SubscriptionRuleID] = [SubscriptionRule].[ID]
	WHERE
		[SubscriptionRule].[UserID] = @UserID AND [SubscriptionRule].[ExternalInitiator] = 0
		
	-- select all rule' notifications
	SELECT
		[SubscriptionRuleNotificationWay].[NotificationWayID],
		[SubscriptionRuleNotificationWay].[SubscriptionRecurrencePatternID],
		[SubscriptionRule].[ID] AS [SubscriptionRuleID]
	FROM
		[SubscriptionRule]
		INNER JOIN [SubscriptionRuleNotificationWay]
			ON [SubscriptionRuleNotificationWay].[SubscriptionRuleID] = [SubscriptionRule].[ID]
	WHERE
		[SubscriptionRule].[UserID] = @UserID AND [SubscriptionRule].[ExternalInitiator] = 0
	
	RETURN 0
GO

GRANT EXECUTE ON [pjm5SubscriptionRuleGet] TO PUBLIC
GO
 