IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5PaymentCreateFromInvoice]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5PaymentCreateFromInvoice'
		DROP PROCEDURE [dbo].[pjm5PaymentCreateFromInvoice]
	END
GO

PRINT 'Creating procedure pjm5PaymentCreateFromInvoice'
GO

/******************************************************************************
**		File: pjm5PaymentCreateFromInvoice.sql
**		Name: pjm5PaymentCreateFromInvoice
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: vladislav.dremin
**		Date: 01/21/2005 17:11:09
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE PROCEDURE [pjm5PaymentCreateFromInvoice]
	@InvoiceID TIdentifier,
	@Number TName,
	@Date TDate,
	@FileAs TName,
	@PaymentTypeID TIdentifier,
	@PaymentValue TMoney,
	@PaymentVAT TMoney,
	@CurrencyRate TAmount,
	@BaseCurrencyRate TAmount,
	@Value TMoney,
	@VAT TMoney,
	@Description TDescription
AS
	DECLARE @State TState,
			@PayeeCompanyID TIdentifier,
			@PayeeBankAccountID TIdentifier,
			@PayerCompanyID TIdentifier,
			@CurrencyCode TCode3,
			@Comments TNotes,
			@ID TIdentifier,
			@doc int,
			@rv int,
			@InvoiceValue TMoney,
			@InvoiceVAT TMoney,
			@InvoiceState TState,
			@val TVariant
	
	SET NOCOUNT ON
	
	SELECT
		@InvoiceValue = [Invoice].[TotalWithVAT],
		@InvoiceVAT = [Invoice].[VAT],
		@InvoiceState = [Invoice].[State],
		@PayeeCompanyID = [BankAccount].[CompanyID],
		@PayeeBankAccountID = [BankAccount].[ID]
	FROM
		[Invoice]
		LEFT OUTER JOIN [BankAccount]
			ON [BankAccount].[ID] = [Invoice].[SupplierBankAccountID]
	WHERE
		[Invoice].[ID] = @InvoiceID
	
	IF @PayeeBankAccountID IS NULL
	BEGIN
		RAISERROR('#PayeeBankAccountIDIsNotDefined', 18, -1)
		RETURN 1
	END

	SELECT 
		@InvoiceValue = @InvoiceValue - ISNULL(SUM([PaymentDetail].[PaymentValue]), 0),
		@InvoiceVAT = @InvoiceVAT - ISNULL(SUM([PaymentDetail].[PaymentVAT]), 0)
	FROM
		[PaymentDetail]
		INNER JOIN [Payment]
			ON [Payment].[ID] = [PaymentDetail].[PaymentID]
	WHERE
		[PaymentDetail].[InvoiceID] = @InvoiceID AND
		[Payment].[State] IN (2, 3)
		
	SELECT
		@InvoiceValue = @InvoiceValue - ISNULL(SUM([Invoice].[TotalWithVAT]), 0.0),
		@InvoiceVAT = @InvoiceVAT - ISNULL(SUM([Invoice].[VAT]), 0.0)
	FROM
		[AdvanceInvoice] 
		INNER JOIN [Invoice]
			ON [Invoice].[ID] = [AdvanceInvoice].[AdvanceInvoiceID]
	WHERE
		[AdvanceInvoice].[InvoiceID] = @InvoiceID

	SET @State = dbo.adfwfGetInitialState('93c2d727-32db-4dda-9bf5-a52f35ccd952')
	IF @State IS NULL
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END
	
	DECLARE @BaseCurrencyCode TCode3
	EXEC adfParameterGet @Name='BaseCurrency', @Group='CommonBusiness', @Value = @val OUTPUT
	SET @BaseCurrencyCode = CAST(@val as varchar(3))

	SELECT
		@BaseCurrencyRate = ISNULL(@BaseCurrencyRate, CASE 
			WHEN [Project].[CurrencyCode] = @BaseCurrencyCode
				THEN @CurrencyRate
			WHEN [Project].[CurrencyCode] = [Invoice].[CurrencyCode]
				THEN [Invoice].[BaseCurrencyRate]
			WHEN [Invoice].[CurrencyCode] = @BaseCurrencyCode 
				THEN 1.0
			ELSE NULL 
		END),
		@CurrencyCode = [Invoice].[CurrencyCode],
		@PayerCompanyID = [Project].[CustomerCompanyID]
	FROM
		[Invoice]
		INNER JOIN [Project]
			ON [Project].[ID] = [Invoice].[ProjectID]
	WHERE
		[Invoice].[ID] = @InvoiceID
		
	IF @BaseCurrencyRate IS NULL
	BEGIN

		IF @BaseCurrencyCode = @CurrencyCode
			SET @BaseCurrencyRate = 1.0
		ELSE
			SELECT 
				@BaseCurrencyRate = [Rate]
			FROM
				[CurrencyRate]
			WHERE
				[FromCurrencyCode] = @CurrencyCode AND
				[ToCurrencyCode] = @BaseCurrencyCode AND
				(@Date BETWEEN [ValidFrom] AND [ValidTo])
	END
	BEGIN TRANSACTION
	INSERT INTO [Payment]
		([Flag], [State], 
		[FileAs], [Date], [Number], 
		[PaymentTypeID], [CurrencyCode],
		[PayeeCompanyID], [PayeeBankAccountID], [PayerCompanyID],
		[Value], [VAT], [BaseCurrencyRate],
		[Comments])
	VALUES
		(0, @State,
		@FileAs, @Date, @Number,
		@PaymentTypeID, @CurrencyCode,
		@PayeeCompanyID, @PayeeBankAccountID, @PayerCompanyID, 
		@PaymentValue, @PaymentVAT, @BaseCurrencyRate,
		@Comments)
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	SET @ID = SCOPE_IDENTITY()
	
	EXEC @rv = adfPaymentChangeState @ID, 2
	IF @rv != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 2
	END
	
	INSERT INTO [PaymentDetail]
		(
		[InvoiceID],
		[PaymentID],
		[Value],
		[VAT],
		[CurrencyRate],
		[PaymentValue],
		[PaymentVAT],
		[Description]
		)
	VALUES
		(
		@InvoiceID,
		@ID,
		@Value,
		@VAT,
		@CurrencyRate,
		@PaymentValue,
		@PaymentVAT,
		@Description
		)
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END

	UPDATE
		[Invoice]
	SET
		[CurrencyRate] = @CurrencyRate
	WHERE
		[ID] = @InvoiceID AND
		[CurrencyRate] IS NULL
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	COMMIT TRANSACTION

	IF @BaseCurrencyRate IS NOT NULL
	BEGIN
		EXEC @rv = adfPaymentChangeState @ID, 3
	END
	SELECT 
		dbo.adfGetClassByName('Adf.Payment') AS [Class],
		@ID AS [ID],
		@State AS [State],
		@FileAs AS [FileAs]
	RETURN 0
GO

GRANT EXECUTE ON pjm5PaymentCreateFromInvoice TO PUBLIC
GO
  