IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5ProjectGet]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5ProjectGet'
		DROP PROCEDURE [dbo].[pjm5ProjectGet]
	END
GO

PRINT 'Creating procedure pjm5ProjectGet'
GO

/******************************************************************************
**		File: pjm5ProjectGet.sql
**		Name: pjm5ProjectGet
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Andrew.Maklakov
**		Date: 01/20/2005 11:01:32
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		17.09.09	syv				  BankAccountID
**		14.10.09	syv				  BankAccountDefault
**		13.11.10	SYV				  [GroupingAdvanceCalculations]
**		24.11.10	SYV				  [StatementCurrencyPoint]
**		23.12.10	PAM				  
**		14.02.11	SPV				   ""
**		16.02.11	PAM				  
**		18.04.11	SYV				    
**		26.04.11	PAM				  BudgetAccess
**		03.08.11	SPV				 PM   
*******************************************************************************/
CREATE PROCEDURE [pjm5ProjectGet]
	@ID TIdentifier
AS
	SET NOCOUNT ON
	
	DECLARE 
			@date datetime,
			@IsFinanceEnable	bit,
			@ViewAllFinance TBool,
			@ViewFinance TBool,
			@CurrentEmployeeID TIdentifier,
			@CurrentUserID TIdentifier,
			@IsPM TBool,
			@IsMember TBool,
			--@DueDate TDate,
			@PercentComplete TPercent,
			@EstimatedManHour TAmount,
			@EstimatedBudget TMoney,
			@ManHour TAmount,
			@Budget TMoney,
			@RealManHour TAmount,
			@ExpenseRealBudget TMoney,
			@TimeRealBudget TMoney,
			@ExpenseBudget TMoney,
			@TimeBudget TMoney,
			@Instance TGuid,
			@val TVariant,
			@BankAccountID TIdentifier,
			@BankAccountDefault TIdentifier,
			@ViewPriceList TBool,
			@SyncEnabled TBool,
			@BudgetAccess TBool

	SET @CurrentUserID = dbo.adfGetCurrentUserID()
	SET @CurrentEmployeeID = dbo.adfGetCurrentEmployeeID()
	SET @ViewAllFinance = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllFinance'))
	SET @ViewFinance = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewFinance'))
	SET @IsPM = dbo.fnPjm5IsProjectManager(@ID, @CurrentEmployeeID)
	SET @IsMember = @IsPM | dbo.fnPjm5IsProjectMember(@ID, @CurrentEmployeeID)
	SET @ViewPriceList = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewServiceAssignment'))

	SET @SyncEnabled = dbo.adfHasAccessRightByName('1CIntegration')
	IF EXISTS
	(
		SELECT *
		FROM
			[Project]
			LEFT OUTER JOIN [Company]
				ON [Project].[SupplierCompanyID] = [Company].[ID] 
		WHERE
			[Project].[ID] = @ID AND (
				[Project].[MsProjectID] IS NOT NULL OR
				[Project].[ProjectTypeID] = 1 AND ISNULL([Company].[ExchangeBanned], 1) = 0 AND @SyncEnabled = 1)
	)
		SET @SyncEnabled = 1
	ELSE
		SET @SyncEnabled = 0
	
	SET @IsFinanceEnable = @IsMember & @ViewFinance
	SET @IsFinanceEnable = @IsFinanceEnable | @ViewAllFinance | @IsPM
	SET @date = GETDATE()

	DECLARE @IsTemplate bit
	SELECT @IsTemplate = (SELECT COUNT(*) FROM [ProjectTemplate] WHERE [ID] = @ID)
		
	IF @IsTemplate = 0 AND dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllProjects')) = 0
	BEGIN
		IF @IsMember = 0
		BEGIN
			RAISERROR('#NotEnoughPermissions', 18, -1)
			RETURN 1
		END
	END
	
	DECLARE @projects TABLE([ID] int);
	WITH [Projects] ([ID]) AS
	(
		SELECT 
			[ID]
		FROM
			[Project]
		WHERE
			[ID] = @ID
		UNION ALL
		SELECT
			[Project].[ID]
		FROM
			[Project]
			INNER JOIN [Task]
				ON [Task].[SubprojectID] = [Project].[ID]
			INNER JOIN [Projects]
				ON [Projects].[ID] = [Task].[ProjectID]
	)	
	INSERT INTO @projects ([ID]) SELECT [ID] FROM [Projects]
	
	SELECT 
		@RealManHour = ISNULL(SUM([TimeEntry].[Duration]), 0) / 60.0,
		@TimeRealBudget = ISNULL(SUM([TimeEntry].[Billable] * [TimeEntry].[BillableHour] * [TimeEntry].[Rate]), 0),
		@TimeBudget = ISNULL(SUM([TimeEntry].[BillableHour] * [TimeEntry].[Rate]), 0)
	FROM
		@projects AS [Projects]
		INNER JOIN [vwTimeEntry] AS [TimeEntry]
			ON [Projects].[ID] = [TimeEntry].[ProjectID]
	WHERE
		[TimeEntry].[State] IN (2,3,6)

	SELECT 
		@ExpenseRealBudget = SUM([Expense].[Billable] * ISNULL(CASE 
			WHEN [Project].[RatesWithVAT] = 0
				THEN [Expense].[TotalPC]
			ELSE [Expense].[TotalWithVATPC]
		END, 0)),
		@ExpenseBudget = SUM(ISNULL(CASE 
			WHEN [Project].[RatesWithVAT] = 0
				THEN [Expense].[TotalPC]
			ELSE [Expense].[TotalWithVATPC]
		END, 0))
	FROM 
		@projects AS [Projects]
		INNER JOIN [Expense]
			ON [Expense].[ProjectID] = [Projects].[ID]
		INNER JOIN [Project]
			ON [Project].[ID] = [Expense].[ProjectID]
	WHERE
		[Expense].[State] IN (2,3,6)

	SELECT 
		@EstimatedManHour = ISNULL(SUM([BusyEntry].[Planned]), 0) / 60.0,
		@EstimatedBudget = ISNULL(SUM([BusyEntry].[Planned] * [Assignment].[StandardRate]), 0) / 60.0
	FROM
		@projects AS [Projects]
		INNER JOIN [BusyEntry]
			ON [BusyEntry].[ProjectID] = [Projects].[ID]
		INNER JOIN [Task]
			ON [BusyEntry].[TaskID] = [Task].[ID] AND [Task].[State] IN (2, 3, 5)
		INNER JOIN [Assignment]
			ON [BusyEntry].[AssignmentID] = [Assignment].[ID]
	WHERE 
		[BusyEntry].[Date] <= GETDATE()
	
	SELECT
		@BankAccountID = [BankAccountID]
	FROM
		[Project]
	WHERE
		[ID] = @ID
	
	SET @BankAccountDefault = @BankAccountID
	
	IF (@BankAccountID IS NULL)
	BEGIN
		SELECT
			@BankAccountID = [Company].[BankAccountID]
		FROM
			[Company], [Project]
		WHERE
			[Project].[ID] = @ID AND
			[Company].[ID] = [Project].[SupplierCompanyID]
	END

	DECLARE
		@BudgetID TIdentifier,
		@MaxStartDate TDate,
		@ExistsTasks	TBool
	--         MS Project
	SET @ExistsTasks = 0
	IF (SELECT [MsProjectID] FROM [Project] WHERE [ID] = @ID) IS NOT NULL 
		OR 
		(EXISTS(SELECT *FROM [Task] WHERE [ProjectID] = @ID AND [SubprojectID] IS NULL AND [State] = 2))
		SET @ExistsTasks = 1

	--   
	SET @BudgetID = (SELECT TOP 1 [ID] FROM [Budget] WHERE [Budget].[DocumentID] = @ID AND [State] IN (2))
	IF @BudgetID IS NULL
	BEGIN
		SET @BudgetID = (SELECT TOP 1 [ID] FROM [Budget] WHERE [Budget].[DocumentID] = @ID AND [State] IN (1))
		IF @BudgetID IS NULL
		BEGIN
			SET @MaxStartDate = (SELECT MAX([StartDate]) FROM [Budget] WHERE [Budget].[DocumentID] = @ID AND [State] = 3)
			SELECT
				@BudgetID = [ID]
			FROM
				[Budget]
			WHERE
				[Budget].[DocumentID] = @ID AND [StartDate] = @MaxStartDate
		END
	END
	SET @BudgetAccess = dbo.fnPjm6CanEditBudgetForProject(@ID) | dbo.fnPjm6CanViewBudget(@BudgetID)

	SELECT
		[Project].[Class],
		[Project].[ID],
		[Project].[State],
		[Project].[Flag],
		[Project].[Date],
		[Project].[Number],
		[Project].[NumerationCode],
		[Project].[FileAs],
		[Project].[ProjectTypeID],
		[Project].[SupplierCompanyID],
		[Project].[ProjectManagerEmployeeID],
		[Project].[CustomerCompanyID],
		[Project].[CustomerFinanceManagerID],
		[Project].[ResponsiblePersonEmployeeID],
		[Project].[PriorityID],
		[Project].[ProjectLanguageCode],
		[Project].[CurrencyCode],
		[Project].[CostCenterID],
		[ProjectDetail].[DueDate],
		[Project].[EndDate],
		CASE
			WHEN dbo.fnPjm5GetWorkingDays([Project].[Date], 
				CASE
				WHEN [ProjectDetail].[DueDate] IS NULL THEN [Project].[Date]
				WHEN [ProjectDetail].[DueDate] IS NOT NULL AND [ProjectDetail].[DueDate] < [Project].[Date] THEN [Project].[Date]
				ELSE [ProjectDetail].[DueDate]
				END) > 0
				THEN dbo.fnPjm5GetWorkingDays([Project].[Date], 
					CASE
					WHEN [ProjectDetail].[DueDate] IS NULL THEN [Project].[Date]
					WHEN [ProjectDetail].[DueDate] IS NOT NULL AND [ProjectDetail].[DueDate] < [Project].[Date] THEN [Project].[Date]
					ELSE [ProjectDetail].[DueDate]
					END)
			ELSE 1
		END AS [Duration],
		[ProjectDetail].[PercentComplete],
		[ProjectDetail].[PlannedManHour]/ 60.0 AS [ManHour],
		[Project].[Budget],
		[ProjectDetail].[PlannedManHour]/ 60.0 AS [PlannedManHour],
		[ProjectDetail].[PlannedBudget],
		@RealManHour AS [RealManHour],
		ISNULL(@ExpenseRealBudget, 0.0) + ISNULL(@TimeRealBudget, 0.0) AS [RealBudget],
		ISNULL(@ExpenseBudget, 0.0) + ISNULL(@TimeBudget, 0.0) AS [CompleteRealBudget],
		@EstimatedManHour AS [EstimatedManHour],
		@EstimatedBudget AS [EstimatedBudget],
		[Project].[Billable],
		[Project].[RoundingInterval],
		[Project].[RoundingMode],
		[Project].[ContractNumber],
		[Project].[ContractDate],
		[Project].[ContractEndDate],
		[Project].[ContractSubject],
		[Project].[ServiceLevelID],
		[Project].[ApplyVAT],
		[Project].[InvoiceExpirationPeriod],
		[Project].[InvoiceExpirationPeriodType],
		[Project].[WSSDocumentsURL],
		[Project].[SupportsRequestManagement],
		[Project].[Comments],
		[Project].[Created],
		[Project].[CreatedBy],
		[Project].[Modified],
		[Project].[ModifiedBy],
		[Project].[Timestamp],
		@IsPM AS [ProjectPM],
		@IsFinanceEnable AS [FinanceAccess],
		[Project].[RatesWithVAT],
		[Project].[PaymentCurrencyPoint],
		[Project].[InitialBalance],
		[Project].[BaseInitialBalance],
		[Project].[InvoiceCurrency],
		[Project].[StatementCurrency],
		[Project].[FactureCurrency],
		[Project].[Scale],
		[Project].[FolderID],
		[Project].[GroupCalculationLines],
		dbo.fnPjm5GetExternalSubscription([Project].[Class], [Project].[ID],
			'ExternalOpenIssue') AS [ExternalNotificationOpenIssue],
		dbo.fnPjm5GetExternalSubscription([Project].[Class], [Project].[ID],
			'ExternalResolveIssue') AS [ExternalNotificationResolveIssue],
		dbo.fnPjm5GetExternalSubscription([Project].[Class], [Project].[ID],
			'ExternalPostponeIssue') AS [ExternalNotificationPostponeIssue],
		dbo.fnPjm5GetExternalSubscription([Project].[Class], [Project].[ID],
			'ExternalCloseIssue') AS [ExternalNotificationCloseIssue],
		dbo.fnFolderHasRightAccess([Project].[FolderID], @CurrentUserID, 'FOLDERVISIBLE') AS [FolderVisible],
		[PaymentPeriod].[InvoicePeriodType],
		[PaymentPeriod].[InvoiceDayType],
		[PaymentPeriod].[InvoiceNextPaymentDate],
		[PaymentPeriod].[StatementPeriodType],
		[PaymentPeriod].[StatementDayType],
		[PaymentPeriod].[StatementNextPaymentDate],
		[PaymentPeriod].[CalculationPeriodType],
		[PaymentPeriod].[CalculationDayType],
		[PaymentPeriod].[CalculationNextPaymentDate],
		[Project].[CalculationRecurrencePatternID],
		[Project].[StatementRecurrencePatternID],
		[Project].[InvoiceRecurrencePatternID],
		[Project].[CheckTaskWorkOverdraft],
		[Project].[ContractComments],
		[Project].[ShowActivityTypes],
		[Project].[ShowPrice],
		@BankAccountID AS [BankAccountID],
		@BankAccountDefault AS [BankAccountDefault],
		@ViewPriceList AS [ViewPriceList],
		[Project].[ExchangeSystemName],
		[Project].[GroupingAdvanceCalculations],
		[Project].[StatementCurrencyPoint],
		CASE [Project].[StatementCurrencyPoint] WHEN 0 THEN [Project].[CurrencyCode] ELSE dbo.fnPjm6GetProjectBankAccountCurrency([Project].[ID]) END AS [StatementCurrencyCode],
		[Project].[MsProjectID],
		[Budget].[ID] AS [BudgetID],
		[Budget].[State] AS [BudgetState],
		[Budget].[BudgetTypeID],
		[Budget].[StartDate] AS [BudgetStartDate],
		[Budget].[EndDate] AS [BudgetEndDate],
		[Budget].[UseWorkPlanning],
		[Budget].[UseExpensePlanning], 
		[Budget].[WorkBudgetHigh],
		[Budget].[WorkBudgetBottom],
		[Budget].[ExpenseBudgetHigh],
		[Budget].[ExpenseBudgetBottom], 
		[Budget].[LastCalculationDate],
		dbo.fnPjm6GetDurationFormatted([Budget].[CalculationDuration]) AS [CalculationDuration],
		[Budget].[NextCalculationDate],
		ISNULL([UserReminder].[State], CAST(0 as int)) AS [ReminderState],
		[Budget].[CalculatedEmployeeID],
		[Budget].[CalculateBudgetPatternID],
		dbo.fnPjm6GetBudgetTotalWithDiscount([VATRate], [VATIsIncluded], [DiscountViewWork], [DiscountPercentWork], [DiscountTotalWork], [TotalPCPlannedManHour], [TotalWithVATPCPlannedManHour])
			AS [TotalPlannedManHour],
		dbo.fnPjm6GetBudgetTotalWithDiscount([VATRate], [VATIsIncluded], [DiscountViewWork], [DiscountPercentWork], [DiscountTotalWork], [TotalPCActualManHour], [TotalWithVATPCActualManHour]) 
			AS [TotalActualManHour],
		dbo.fnPjm6GetBudgetTotalWithVATWD([VATRate], [VATIsIncluded], [DiscountViewExpense], [DiscountPercentExpense], [DiscountTotalExpense], [TotalPCPlannedExpense], [TotalPCPlannedExpense] + dbo.fnPjm6GetVATForTotal([TotalPCPlannedExpense], [VATRate], 0, 1))
			AS [TotalPlannedExpense],
		dbo.fnPjm6GetBudgetTotalWithVATWD([VATRate], [VATIsIncluded], [DiscountViewExpense], [DiscountPercentExpense], [DiscountTotalExpense], [TotalPCActualExpense], [TotalPCActualExpense] + dbo.fnPjm6GetVATForTotal([TotalPCActualExpense], [VATRate], 0, 1))
			AS [TotalActualExpense],		
		(CASE WHEN [VATRate] IS NOT NULL AND [VATIsIncluded] = 1 THEN
			[Budget].[TotalWithVATPCWDPlannedManHourWithSub]
			ELSE
			[Budget].[TotalPCWDPlannedManHourWithSub]
		END) AS [TotalPlannedManHourWithSub],
		(CASE WHEN [VATRate] IS NOT NULL AND [VATIsIncluded] = 1 THEN
			[Budget].[TotalWithVATPCWDActualManHourWithSub]
			ELSE
			[Budget].[TotalPCWDActualManHourWithSub]
		END) AS [TotalActualManHourWithSub],
		(CASE WHEN [VATRate] IS NOT NULL THEN
			[Budget].[TotalWithVATPCWDPlannedExpenseWithSub]
			ELSE
			[Budget].[TotalPCWDPlannedExpenseWithSub]
		END) AS [TotalPlannedExpenseWithSub],
		(CASE WHEN [VATRate] IS NOT NULL THEN
			[Budget].[TotalWithVATPCWDActualExpenseWithSub]
			ELSE
			[Budget].[TotalPCWDActualExpenseWithSub]
		END) AS [TotalActualExpenseWithSub],
		@BudgetAccess AS [BudgetAccess],
		@ExistsTasks AS [ExistsTasks],
		[Project].[IsConsignor],
		[Project].[ConsignorID],
		[Project].[ConsignorClass],
		[Project].[ConsignorContract],
		[Project].[UseSubProjects],
		@SyncEnabled AS [SyncEnabled],

		[ProjectDetail].[DiscountTypeByTime],
		[ProjectDetail].[DiscountViewByTime],
		[ProjectDetail].[DiscountByTime],
		[ProjectDetail].[DiscountByTime] AS [DiscountPercentByTime],
		
		[ProjectDetail].[DiscountTypeByExpense],
		[ProjectDetail].[DiscountViewByExpense],
		[ProjectDetail].[DiscountByExpense],
		[ProjectDetail].[DiscountByExpense] AS [DiscountPercentByExpense],

		[ProjectDetail].[DiscountTypeByPhone],
		[ProjectDetail].[DiscountViewByPhone],
		[ProjectDetail].[DiscountByPhone],
		[ProjectDetail].[DiscountByPhone] AS [DiscountPercentByPhone],

		[ProjectDetail].[DiscountTypeByServiceRequest],
		[ProjectDetail].[DiscountViewByServiceRequest],
		[ProjectDetail].[DiscountByServiceRequest],
		[ProjectDetail].[DiscountByServiceRequest] AS [DiscountPercentByServiceRequest]
	FROM
		[Project]
		INNER JOIN [PaymentPeriod]
			ON [PaymentPeriod].[ProjectID] = [Project].[ID]
		INNER JOIN [ProjectDetail]
			ON [ProjectDetail].[ID] = [Project].[ID]
		LEFT JOIN [Budget]
			ON [Budget].[DocumentID] = [Project].[ID] AND [Budget].[ID] = @BudgetID
		LEFT OUTER JOIN [Reminder]
			ON ([Reminder].[DocumentClass] = [Budget].[Class] AND
				[Reminder].[DocumentID] = [Budget].[ID] AND
				[Reminder].[Subtype] = 'BC')
		LEFT OUTER JOIN [UserReminder]
			ON ([Reminder].[ID] = [UserReminder].[ReminderID] AND
				[UserReminder].[UserID] = @CurrentUserID)
	WHERE
		[Project].[ID] = @ID
		
	SELECT
		[ProjectActivityType].[ActivityTypeID] AS [ID],
		[ActivityType].[FileAs] AS [Name],
		[ProjectActivityType].[Billable],
		[ProjectActivityType].[Actively]
	FROM
		[ProjectActivityType]
		INNER JOIN [ActivityType]
			ON [ActivityType].[ID] = [ProjectActivityType].[ActivityTypeID] 
	WHERE
		[ProjectActivityType].[ProjectID] = @ID

		
	SELECT
		[ProjectExpenseCode].[ExpenseCodeID] AS [ID],
		[ExpenseCode].[FileAs] AS [Name],
		[ProjectExpenseCode].[Billable],
		[ProjectExpenseCode].[Actively]
	FROM
		[ProjectExpenseCode]
		INNER JOIN [ExpenseCode]
			ON [ExpenseCode].[ID] = [ProjectExpenseCode].[ExpenseCodeID] 
	WHERE
		[ProjectExpenseCode].[ProjectID] = @ID
		
	EXEC adfParameterGet @Name='Instance', @Group='Instance', @Value = @val OUTPUT
		SET @Instance = CAST(@val as uniqueidentifier)
	
	SELECT
		[MsProject].[ID],
		[MsProject].[FullName],
		[MsProject].[DocumentItemID],
		@Instance as [DatabaseGuid],
		CASE WHEN [DocumentItem].[State] = 3 THEN [DocumentVersion].[Created] ELSE [MsProject].[Modified] END as [Modified],
		CASE WHEN [DocumentItem].[State] = 3 THEN [DocumentItem].[CheckedOutBy] ELSE [MsProject].[ModifiedBy] END as [ModifiedBy],
		[DocumentItem].[State] as [DocumentItemState],
		[MsProject].[FileVersion] 
	FROM
		[MsProject]
			INNER JOIN [Project]
				ON [MsProject].[ID] = [Project].[MsProjectID]
			INNER JOIN [DocumentItem]
				ON [DocumentItem].[ID] = [MsProject].[DocumentItemID]
			INNER JOIN [DocumentVersion]
				ON [DocumentItem].[ID] = [DocumentVersion].[DocumentItemID]
				AND [DocumentItem].[LatestVersion] = [DocumentVersion].[Version]
	WHERE 
		[Project].[ID] = @ID

	RETURN 0
GO

GRANT EXECUTE ON [pjm5ProjectGet] TO PUBLIC
GO



IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5ProjectDelete]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5ProjectDelete'
		DROP PROCEDURE [dbo].[pjm5ProjectDelete]
	END
GO

PRINT 'Creating procedure pjm5ProjectDelete'
GO

/******************************************************************************
**		File: pjm5ProjectDelete.sql
**		Name: pjm5ProjectDelete
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Andrew.Maklakov
**		Date: 01/20/2005 11:01:32
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    28.06.10		KOV				    
*******************************************************************************/
CREATE PROCEDURE pjm5ProjectDelete
	@ID TIdentifier
AS
	SET NOCOUNT ON
	IF EXISTS(SELECT * FROM [SuperTimer] 
					WHERE [SuperTimer].[DocumentClass] = dbo.adfGetClassByName('Pjm5.Project') AND [SuperTimer].[DocumentID] = @ID AND 
					([SuperTimer].[State] in (1,2) OR ([SuperTimer].[State] = 3 AND [SuperTimer].[Persistent] = 1)))
	BEGIN
		RAISERROR('#CannotDeleteDocumentWithActiveTimer', 18, -1)
		RETURN 1
	END
	BEGIN TRANSACTION
	DELETE FROM [BusyEntry] WHERE [ProjectID] = @ID
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END

	-- 
	DELETE FROM [Budget] WHERE [DocumentID] = @ID
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END

	DELETE FROM [Project] WHERE [Project].[ID] = @ID
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END


	DELETE [MsProject]
	FROM
		[MsProject]
			INNER JOIN [Project]
			ON [Project].[MsProjectID] = [MsProject].[ID]
	WHERE [Project].[ID]=@ID
	
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END
	
	COMMIT TRANSACTION
	
	RETURN 0
GO

GRANT EXECUTE ON pjm5ProjectDelete TO PUBLIC
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5ProjectChangeState]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5ProjectChangeState'
		DROP PROCEDURE [dbo].[pjm5ProjectChangeState]
	END
GO

PRINT 'Creating procedure pjm5ProjectChangeState'
GO

/******************************************************************************
**		File: pjm5ProjectChangeState.sql
**		Name: pjm5ProjectChangeState
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Andrew.Maklakov
**		Date: 01/20/2005 11:01:32
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		14.05.10	SYV				  pjm6DismissEventsOnObject    
**		24.08.10	SYV				  pjm6DismissEventsOnObject .. 
**									   
**		28.07.11	SPV				    
*******************************************************************************/
CREATE PROCEDURE pjm5ProjectChangeState
	@ID TIdentifier,
	@ToState TState
	
AS
	DECLARE @FromState TState,
			@TransitionTemplateID TIdentifier,
			@RightID TIdentifier,
			@Class TClass,
			@result INT
	
	SET NOCOUNT ON
	
	SELECT
		@Class = [Project].[Class],
		@FromState = [Project].[State]
	FROM
		[Project]
	WHERE
		[Project].[ID] = @ID
		
	IF @FromState = @ToState
	BEGIN
		RAISERROR('#invalidargument', 18, -1)
		RETURN 1
	END
	
	SELECT
		@TransitionTemplateID = [ID],
		@RightID = [RightID]
	FROM
		[TransitionTemplate]
	WHERE
		[TransitionTemplate].[FromState] = @FromState AND [TransitionTemplate].[ToState] = @ToState
	AND
		[TransitionTemplate].[Class] = @Class
		
	IF @TransitionTemplateID IS NULL
	BEGIN
		RAISERROR('#invalidoperation', 18, -1)
		RETURN 1
	END
	
	SET @TransitionTemplateID = dbo.adfCheckTransitionRights(@TransitionTemplateID, @RightID, dbo.adfGetCurrentUserID())
	
	IF @TransitionTemplateID IS NULL
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END
	
	IF @ToState IN (2, 3, 4) -- ,   
	BEGIN
		DECLARE @CurrentEmployeeID TIdentifier
		SET @CurrentEmployeeID = dbo.adfGetCurrentEmployeeID()
		IF dbo.fnPjm5IsProjectManager(@ID, @CurrentEmployeeID) = 0
		BEGIN
			RAISERROR('#accessdenied', 18, -1)
			RETURN 1
		END
	END
	
	DECLARE @EndDate TDate
	SET @EndDate = CONVERT(datetime, CONVERT(varchar(8), GETDATE(), 112), 112)
	
	BEGIN TRANSACTION
	IF @ToState = 4
	BEGIN
		DECLARE @TaskID TIdentifier, @SubProjectID TIdentifier
		DECLARE tasks CURSOR LOCAL FAST_FORWARD 
		FOR SELECT 
			[Task].[ID],
			[Task].[SubProjectID]
		FROM 
			[Task]
			INNER JOIN [Project]
				ON [Project].[ID] = [Task].[SubProjectID]
		WHERE 
			[ProjectID] = @ID AND ISNULL([Project].[State], [Task].[State]) = 2
		OPEN tasks
		FETCH NEXT FROM tasks INTO @TaskID, @SubProjectID
		WHILE @@FETCH_STATUS = 0
		BEGIN
			IF @SubProjectID IS NULL
				EXEC @result = pjm5TaskChangeState @TaskID, 3
			ELSE
				EXEC @result = pjm5ProjectChangeState @SubProjectID, 4
			IF @result != 0
			BEGIN
				CLOSE tasks
				DEALLOCATE tasks
				
				ROLLBACK TRANSACTION
				RETURN 1
			END
			
			FETCH NEXT FROM tasks INTO @TaskID, @SubProjectID
		END
		CLOSE tasks
		DEALLOCATE tasks
	END

	UPDATE
		[Project]
	SET
		[Project].[EndDate] = (CASE WHEN @ToState = 4 AND [Project].[EndDate] IS NULL THEN @EndDate ELSE [Project].[EndDate] END),
		[Project].[State] = @ToState,
		[Project].[Modified] = DEFAULT,
		[Project].[ModifiedBy] = DEFAULT
	WHERE
		[Project].[ID] = @ID
	AND
		[Project].[State] = @FromState

	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN 1
	END

	IF @FromState = 1 AND @ToState = 2
	BEGIN
		UPDATE [ContractAddendum]
		SET
			[State] = 2
		WHERE
			[ProjectID] = @ID AND
			[State] = 1
		IF @@ERROR != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END
		EXEC @result = pjm5ApproveProjectTasks @ID
		IF @@error != 0 OR @result != 0
		BEGIN
			ROLLBACK TRANSACTION
			RETURN 1
		END
	END

	--   ,   
	DECLARE
		@BudgetID		TIdentifier,
		@MaxStartDate	TDate,
		@rv				int
		

	IF @FromState = 1 AND @ToState = 2
	BEGIN
		SET @BudgetID = (SELECT [ID] FROM [Budget] WHERE [DocumentID] = @ID AND [State] = 1)

		IF @BudgetID IS NOT NULL
		BEGIN
			EXEC @rv =  pjm6BudgetChangeState @BudgetID, 2, 1	
			IF @rv != 0
			BEGIN
				ROLLBACK TRANSACTION
				RETURN 1
			END
		END
	END
	IF @FromState = 2 AND @ToState = 4
	BEGIN
		SET @BudgetID = (SELECT [ID] FROM [Budget] WHERE [DocumentID] = @ID AND [State] = 2)

		IF @BudgetID IS NOT NULL
		BEGIN
			EXEC @rv = pjm6BudgetChangeState @BudgetID, 3, 1	
			IF @rv != 0
			BEGIN
				ROLLBACK TRANSACTION
				RETURN 1
			END
		END
	END
	IF @FromState = 3 AND @ToState = 2
	BEGIN
		SET @BudgetID = (SELECT [ID] FROM [Budget] WHERE [DocumentID] = @ID AND [State] = 1)
		IF @BudgetID IS NULL
		BEGIN
			SET @BudgetID = (SELECT [ID] FROM [Budget] WHERE [DocumentID] = @ID AND [State] = 2)
			IF @BudgetID IS NULL
			BEGIN
				SET @BudgetID = (SELECT [ID] FROM [Budget] WHERE [DocumentID] = @ID AND [State] = 3 AND [BudgetTypeID] = 1)
				IF @BudgetID IS NULL
				BEGIN
					SET @MaxStartDate = (SELECT MAX([StartDate]) FROM [Budget] WHERE [Budget].[DocumentID] = @ID 
											AND [BudgetTypeID] >= 2  AND [State] = 3)

					SET @BudgetID = (SELECT [ID] FROM [Budget] WHERE [DocumentID] = @ID AND [State] = 3 
											AND [BudgetTypeID] >= 2 AND [StartDate] = @MaxStartDate )
				END

				IF @BudgetID IS NOT NULL
				BEGIN
					EXEC @rv = pjm6BudgetChangeState @BudgetID, 2, 1	
					IF @rv != 0
					BEGIN
						ROLLBACK TRANSACTION
						RETURN 1
					END
				END
			END
		END
	END
	IF @FromState = 3 AND @ToState = 4
	BEGIN
		SET @BudgetID = (SELECT [ID] FROM [Budget] WHERE [DocumentID] = @ID AND [State] = 1)
		IF @BudgetID IS NULL
		BEGIN
			SET @BudgetID = (SELECT [ID] FROM [Budget] WHERE [DocumentID] = @ID AND [State] = 2)
			IF @BudgetID IS NOT NULL
			BEGIN
				EXEC @rv = pjm6BudgetChangeState @BudgetID, 3, 1	
				IF @rv != 0
				BEGIN
					ROLLBACK TRANSACTION
					RETURN 1
				END
			END
		END
	END
	IF @FromState = 4 AND @ToState = 2
	BEGIN
		SET @BudgetID = (SELECT [ID] FROM [Budget] WHERE [DocumentID] = @ID AND [State] = 3 AND [BudgetTypeID] = 1)
		IF @BudgetID IS NULL
		BEGIN
			SET @MaxStartDate = (SELECT MAX([StartDate]) FROM [Budget] WHERE [Budget].[DocumentID] = @ID 
									AND [BudgetTypeID] >= 2  AND [State] = 3)

			SET @BudgetID = (SELECT [ID] FROM [Budget] WHERE [DocumentID] = @ID AND [State] = 3 
									AND [BudgetTypeID] >= 2 AND [StartDate] = @MaxStartDate )
		END
		IF @BudgetID IS NOT NULL
		BEGIN
			EXEC @rv = pjm6BudgetChangeState @BudgetID, 2, 1	
			IF @rv != 0
			BEGIN
				ROLLBACK TRANSACTION
				RETURN 1
			END
		END
	END


	/*IF (@ToState = 3 OR @ToState = 4)
	BEGIN
		EXEC pjm6DismissEventsOnObject @Class, @ID	
	END*/

	COMMIT TRANSACTION
	RETURN 0
GO

GRANT EXECUTE ON pjm5ProjectChangeState TO PUBLIC
GO
 
