IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5ProjectBrowseByEmployee]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5ProjectBrowseByEmployee'
		DROP PROCEDURE [dbo].[pjm5ProjectBrowseByEmployee]
	END
GO

PRINT 'Creating procedure pjm5ProjectBrowseByEmployee'
GO

/******************************************************************************
**		File: pjm5ProjectBrowseByEmployee.sql
**		Name: pjm5ProjectBrowseByEmployee
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Andrew.Maklakov
**		Date: 01/20/2005 11:01:32
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		03.08.12					    
*******************************************************************************/
CREATE PROCEDURE [pjm5ProjectBrowseByEmployee]
	@StateSelector INT,
	@PartyStateSelector INT,
	@EmployeeID TIdentifier
AS
	SET NOCOUNT ON
	DECLARE
		@ViewAllFinance TBool,
		@ViewAllProjects TBool,
		@CurrentEmployeeID TIdentifier,
		@HasManageProject TBool;
	DECLARE 
		@Table table (ProjectID int,SumState int)
		
	SET @HasManageProject = dbo.adfHasAccessRight(dbo.adfGetRightID('ManageProject'))
	SET @CurrentEmployeeID = dbo.adfGetCurrentEmployeeID()
	SET @ViewAllFinance = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllFinance')) |
		dbo.adfHasAccessRight(dbo.adfGetRightID('ViewFinance'))
	SET @ViewAllProjects = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllProjects'))
		
	IF @EmployeeID IS NULL
		SELECT @EmployeeID = @CurrentEmployeeID
	
	INSERT INTO
		@Table(ProjectID,SumState)
	(
		SELECT 
			[ProjectID],SUM([State]) AS SumState
		FROM 
			[vwAssignment]
		WHERE [EmployeeID] = @EmployeeID
		GROUP BY [ProjectID]
	)	
			
	SELECT DISTINCT
		[Project].[Class],
		[Project].[ID],
		[Project].[State],
		[Project].[Flag],
		[Project].[Date],
		[Project].[Number],
		[Project].[FileAs],
		[Project].[ProjectTypeID],
		[Project].[SupplierCompanyID],
		[Project].[ProjectManagerEmployeeID],
		[Project].[CustomerCompanyID],
		[Project].[CustomerFinanceManagerID],
		[Project].[ResponsiblePersonEmployeeID],
		[Project].[PriorityID],
		[ProjectDetail].[DueDate],
		[Project].[EndDate],
		[Project].[CurrencyCode],
		[Project].[CostCenterID],
		[ProjectDetail].[PlannedManHour] / 60.0 AS [ManHour],
		CASE
			WHEN @ViewAllFinance = 1 OR 
				(@HasManageProject = 1 AND [Project].[ProjectManagerEmployeeID] = @CurrentEmployeeID)
				THEN [Project].[Budget]
			ELSE -1
		END AS [Budget],
		[ProjectDetail].[PlannedManHour],
		CASE
			WHEN @ViewAllFinance = 1 OR 
				(@HasManageProject = 1 AND [Project].[ProjectManagerEmployeeID] = @CurrentEmployeeID)
				THEN [ProjectDetail].[PlannedBudget]
			ELSE -1
		END AS [PlannedBudget],
		[Project].[Billable],
		[Project].[RoundingInterval],
		[Project].[RoundingMode],
		[Project].[ContractNumber],
		[Project].[ContractDate],
		[Project].[ContractSubject],
		[Project].[ServiceLevelID],
		[Project].[ApplyVAT],
		[Project].[InvoiceExpirationPeriod],
		[Project].[InvoiceExpirationPeriodType],
		[Project].[Comments],
		[Project].[Created],
		[Project].[CreatedBy],
		[Project].[Modified],
		[Project].[ModifiedBy],
		[Project].[Timestamp],
		[Project].[ExchangeSystemName],
		[Project].[PaymentCurrencyPoint],
		[PaymentPeriod].[InvoiceNextPaymentDate],
		[PaymentPeriod].[StatementNextPaymentDate],
		[PaymentPeriod].[CalculationNextPaymentDate],
		[Project].[IsConsignor],
		[BusinessCard].[FileAs] as 'Consignor',
		[Project].[ConsignorContract],
		CASE 
			WHEN NOT EXISTS(SELECT *FROM [Project] 
								WHERE 
									([ID] = [SubProjects].[ProjectID] AND [SubProjects].[ProjectID] IS NOT NULL) AND
									(
										(@StateSelector = 0 AND [Project].[State] NOT IN (5, 6)) OR 
										(@StateSelector != 0 AND [Project].[State] = @StateSelector)
									) AND
									(
										[Project].[ProjectManagerEmployeeID] = @EmployeeID OR
										dbo.fnPjm5IsProjectMember([Project].[ID], @EmployeeID) = 1
									) AND
									(
										@ViewAllProjects = 1 OR
										dbo.fnPjm5AllowCreateProjectEntry([Project].[ID], NULL) = 1 OR
										dbo.fnPjm5IsProjectMember([Project].[ID], @CurrentEmployeeID) = 1
									))
		THEN NULL
			ELSE [SubProjects].[ProjectID]
		END AS [ParentProjectID]
	FROM
		[Project]
		INNER JOIN [PaymentPeriod]
			ON [PaymentPeriod].[ProjectID] = [Project].[ID]
		INNER JOIN [ProjectDetail]
			ON [ProjectDetail].[ID] = [Project].[ID]
		LEFT OUTER JOIN [BusinessCard]
			ON [BusinessCard].[Class] = [Project].[ConsignorClass] AND [BusinessCard].[ID] = [Project].[ConsignorID]
		LEFT OUTER JOIN fnpjm6GetSubprojectsForBrowse() AS [SubProjects]
			ON [SubProjects].[SubprojectID] = [Project].[ID]
		INNER JOIN  @Table t  
			ON [Project].[ID] = t.ProjectID
	WHERE
		(
			(@StateSelector = 0 AND [Project].[State] NOT IN (5, 6)) OR 
			(@StateSelector != 0 AND [Project].[State] = @StateSelector)
		) AND
		(
			(@PartyStateSelector = 0) OR
			(@PartyStateSelector = 1 AND (t.SumState % 2 != 0)) OR
			(@PartyStateSelector = 2 AND (t.SumState % 2 = 0))		
		) AND
		(
			@ViewAllProjects = 1 OR
			dbo.fnPjm5AllowCreateProjectEntry([Project].[ID], NULL) = 1 OR
			dbo.fnPjm5IsProjectMember([Project].[ID], @CurrentEmployeeID) = 1
		)
		
	RETURN 0
GO

GRANT EXECUTE ON [pjm5ProjectBrowseByEmployee] TO PUBLIC
GO

 