IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'pjm5ProjectBrowseMineByCategory')
	BEGIN
		PRINT 'Dropping Procedure pjm5ProjectBrowseMineByCategory'
		DROP  Procedure  pjm5ProjectBrowseMineByCategory
	END

GO

PRINT 'Creating Procedure pjm5ProjectBrowseMineByCategory'
GO
/******************************************************************************
**		File: ProjectBrowseMineByCategory.sql
**		Name: pjm5ProjectBrowseMineByCategory
**		Desc:       / 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**      31.03.09	ENB				 ,    
**									:     .
**									        
*******************************************************************************/
CREATE Procedure pjm5ProjectBrowseMineByCategory
	@StateSelector INT,
	@CustomerStateSelector INT,
	@DateSelector	INT,
	@PeriodStart	datetime,
	@PeriodEnd		datetime
AS

	SET NOCOUNT ON

--        
	IF dbo.adfHasAccessRight(dbo.adfGetRightID('ManageProject')) = 0 BEGIN
	    RAISERROR('#NotEnoughPermissions', 18, -1)
		RETURN 1
	END
	
	DECLARE 
		@date datetime,
		@CurrentEmployeeID TIdentifier
		
	DECLARE @none nvarchar(6)
	IF dbo.adfGetLanguage() = 'ru'
		SET @none = '()'
	ELSE
		SET @none = '(none)'
		
	SET @CurrentEmployeeID = dbo.adfGetCurrentEmployeeID()
	SET @date = GETDATE()

	IF @DateSelector = 1
		SELECT
			@PeriodStart = CAST(CAST(YEAR(@date) AS varchar(4)) + '0101' AS datetime),
			@PeriodEnd = @date
	IF @DateSelector = 2
		SELECT
			@PeriodStart = CAST(CAST(YEAR(@date)-1 AS varchar(4)) + '0101' AS datetime),
			@PeriodEnd = DATEADD(year, 1, @PeriodStart)
	IF @DateSelector = 3
		SELECT
			@PeriodStart = CAST(CONVERT(varchar(8), @PeriodStart, 112) AS datetime),
			@PeriodEnd = DATEADD(day, 1, CAST(CONVERT(varchar(8), @PeriodEnd, 112) AS datetime))

	SELECT
		[Project].[Class],
		[Project].[ID],
		[Project].[State],
		[Project].[Flag],
		[Project].[Date],
		[Project].[Number],
		[Project].[FileAs],
		[Project].[ProjectTypeID],
		[Project].[SupplierCompanyID],
		[Project].[ProjectManagerEmployeeID],
		[Project].[CustomerCompanyID],
		[Project].[CustomerFinanceManagerID],
		[Project].[ResponsiblePersonEmployeeID],
		[Project].[PriorityID],
		[ProjectDetail].[DueDate],
		[Project].[EndDate],
		[Project].[CurrencyCode],
		[Project].[CostCenterID],
		[ProjectDetail].[PlannedManHour] / 60.0 AS [ManHour],
		CASE
			WHEN [Projects].[ViewFinance] = 1 
			THEN [Project].[Budget]
			ELSE -1
		END AS [Budget],
		[ProjectDetail].[PlannedManHour],
		CASE
			WHEN [Projects].[ViewFinance] = 1
			THEN [ProjectDetail].[PlannedBudget]
			ELSE -1
		END AS [PlannedBudget],
		[Project].[Billable],
		[Project].[RoundingInterval],
		[Project].[RoundingMode],
		[Project].[ContractNumber],
		[Project].[ContractDate],
		[Project].[ContractEndDate],
		[Project].[ContractSubject],
		[Project].[ServiceLevelID],
		[Project].[ApplyVAT],
		[Project].[InvoiceExpirationPeriod],
		[Project].[InvoiceExpirationPeriodType],
		[Project].[Comments],
		[Project].[Created],
		[Project].[CreatedBy],
		[Project].[Modified],
		[Project].[ModifiedBy],
		[Project].[Timestamp],
		[Project].[ExchangeSystemName],
		[ProjectDetail].[PercentComplete],
		(CAST([ProjectDetail].[PercentComplete] * 100 as int) / 25) * 25 as PC,
		[Project].[PaymentCurrencyPoint],
		ISNULL([Category].[FileAs], @none) as [Category],
		[Project].[IsConsignor],
		[BusinessCard].[FileAs] as 'Consignor',
		[Project].[ConsignorContract]
	FROM
		[Project]
		INNER JOIN pjm6GetAvailableProjectsForBrowse (
			@CurrentEmployeeID,	-- ID  
			@StateSelector		--  
		) AS [Projects]
			ON [Project].[ID] = [Projects].[ID]
		INNER JOIN [ProjectDetail]
			ON [ProjectDetail].[ID] = [Project].[ID]
		LEFT OUTER JOIN [DocumentCategory]
			ON ([Project].[Class] = [DocumentCategory].[DocumentClass] AND [Project].[ID] = [DocumentCategory].[DocumentID])
		LEFT OUTER JOIN [Category]
			ON ([DocumentCategory].[CategoryID] = [Category].[ID])
		LEFT OUTER JOIN [BusinessCard]
			ON [BusinessCard].[Class] = [Project].[ConsignorClass] AND [BusinessCard].[ID] = [Project].[ConsignorID]

	WHERE
		( 
			(@CustomerStateSelector = 0) OR 
			(@CustomerStateSelector = 1 AND [Project].[ProjectTypeID] = 1) OR
			(@CustomerStateSelector = 2 AND [Project].[ProjectTypeID] = 2) OR
			([Project].[ProjectTypeID] NOT IN (1, 2) AND @CustomerStateSelector = 3)
		) 
		AND
		(
			@DateSelector = 0 OR
			([Project].[Date] < @PeriodEnd AND ISNULL([Project].[EndDate], @date) > @PeriodStart)
		)
		
	RETURN 0
GO

GRANT EXEC ON pjm5ProjectBrowseMineByCategory TO PUBLIC
GO
  