IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'pjm6ProjectBrowseBudgetOverdraft')
	BEGIN
		PRINT 'Dropping Procedure pjm6ProjectBrowseBudgetOverdraft'
		DROP  Procedure  pjm6ProjectBrowseBudgetOverdraft
	END

GO

PRINT 'Creating Procedure pjm6ProjectBrowseBudgetOverdraft'
GO
/******************************************************************************
**		File: pjm6ProjectBrowseBudgetOverdraft.sql
**		Name: pjm6ProjectBrowseBudgetOverdraft
**		Desc:       
**			    
**			  //    
**
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**      30.03.09	ENB				 ,    
**									:     ,   
**									   
**									     	
**    
*******************************************************************************/
CREATE Procedure pjm6ProjectBrowseBudgetOverdraft

AS

	SET NOCOUNT ON

--         
	IF dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllProjects')) = 0 BEGIN
		RAISERROR('#NotEnoughPermissions', 18, -1)
		RETURN 1
	END

	SET NOCOUNT ON

	SELECT
		[Project].[Class],
		[Project].[ID],
		[Project].[State],
		[Project].[Flag],
		[Project].[Date],
		[Project].[Number],
		[Project].[FileAs],
		[Project].[ProjectTypeID],
		[Project].[SupplierCompanyID],
		[Project].[ProjectManagerEmployeeID],
		[Project].[CustomerCompanyID],
		[Project].[CustomerFinanceManagerID],
		[Project].[ResponsiblePersonEmployeeID],
		[Project].[PriorityID],
		[ProjectDetail].[DueDate],
		[Project].[EndDate],
		[Project].[CurrencyCode],
		[Project].[CostCenterID],
		[Project].[ContractNumber],
		[Project].[ContractDate],
		[Project].[ContractEndDate],
		[Project].[ContractSubject],
		[ProjectDetail].[PlannedManHour],
		[ProjectDetail].[PlannedManHour] / 60.0 AS [ManHour],
		[Projects].[RealManHour],
		[Project].[ExchangeSystemName],
		CASE
			WHEN [Projects].[ViewFinance] = 1 
				THEN [ProjectDetail].[PlannedBudget]
				ELSE -1
		END AS [PlannedBudget],
		CASE
			WHEN [Projects].[ViewFinance] = 1 
				THEN [Project].[Budget]
				ELSE -1
		END AS [Budget],
		[Projects].[EstimatedBudget],
		[Projects].[RealBudget],
		CASE
			WHEN [ProjectDetail].[PlannedBudget] != 0 THEN
				CAST([Projects].[EstimatedBudget] as decimal(18,2))/[ProjectDetail].[PlannedBudget]
			ELSE 0
		END AS [EstimatedBudgetPercent],
		CASE
			WHEN [ProjectDetail].[PlannedBudget] != 0 THEN
				CAST([Projects].[RealBudget] as decimal(18,2))/[ProjectDetail].[PlannedBudget]
			ELSE 0
		END AS [RealBudgetPercent],
		[Project].[Comments],
		[Project].[Created],
		[Project].[CreatedBy],
		[Project].[Modified],
		[Project].[ModifiedBy],
		[Project].[Timestamp],
		[ProjectDetail].[PercentComplete],
		(CAST([ProjectDetail].[PercentComplete] * 100 as int) / 25) * 25 as PC,
		[Project].[IsConsignor],
		[BusinessCard].[FileAs] as 'Consignor',
		[Project].[ConsignorContract],
		[Projects].[ParentProjectID] AS [ParentProjectID]
	FROM
		[Project]
		INNER JOIN pjm6GetAvailableProjectsForOverdraft (NULL) AS [Projects]
			ON [Projects].[ID] = [Project].[ID]
		INNER JOIN [ProjectDetail]
			ON [ProjectDetail].[ID] = [Project].[ID]
		LEFT OUTER JOIN [BusinessCard]
			ON [BusinessCard].[Class] = [Project].[ConsignorClass] AND [BusinessCard].[ID] = [Project].[ConsignorID]
		
	RETURN 0
GO

GRANT EXEC ON pjm6ProjectBrowseBudgetOverdraft TO PUBLIC
GO

