IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportRateByEmployee')
	BEGIN
		PRINT 'Dropping Procedure ReportRateByEmployee'
		DROP  Procedure ReportRateByEmployee
	END

GO

PRINT 'Creating Procedure ReportRateByEmployee'
GO

CREATE Procedure ReportRateByEmployee
		@EmployeeID TIdentifier,
		@DateSelector int,
		@PeriodStart TDate,
		@PeriodEnd TDate
				
AS
	SET NOCOUNT ON
	
	SELECT 
		@EmployeeID = [ID]
	FROM 
		[Employee] 
	WHERE 
		([Employee].[ID] = @EmployeeID) OR
		(@EmployeeID IS NULL AND [UserID] = dbo.adfGetCurrentUserID())	
	DECLARE
		@UserID TIdentifier,
		@UserName TName		
		
	IF @DateSelector = 0
		BEGIN
			SELECT
				@PeriodStart = [StartDate],
				@PeriodEnd = [EndDate]
			FROM	
				dbo.adfGetDateInterval(3, GETDATE(), GETDATE(), GETDATE())
		END
	IF @DateSelector = 1
		BEGIN
			SELECT
				@PeriodStart = [StartDate],
				@PeriodEnd = [EndDate]
			FROM	
				dbo.adfGetDateInterval(4, GETDATE(), GETDATE(), GETDATE())
		END
		ELSE
		BEGIN
			SET @PeriodEnd = DATEADD(day, 1, @PeriodEnd)
		END			
					
		SET @UserID = dbo.adfGetCurrentUserID()
	SELECT
		@UserName = [Trustee].[DisplayName]
	FROM
		[Trustee]
	WHERE
		[Trustee].[ID] = @UserID
		
	SELECT 
		@UserName AS [UserName],
		GETDATE() AS [Date],
		[Company].[FileAs] AS [CompanyName],
		[Employee].[FileAs] AS [EmployeeName],
		ISNULL([Division].[FileAs],'( )') AS [DivisionName],
		@PeriodStart AS [PeriodStart],
		DATEADD(day,-1,@PeriodEnd) AS [PeriodEnd]				
	FROM [Employee]
		  INNER JOIN [Company]
				ON [Employee].[CompanyID] = [Company].[ID]
		  LEFT OUTER JOIN [Division]
				ON [Employee].[DivisionID] = [Division].[ID]
   WHERE [Employee].[ID] = @EmployeeID	

	
	DECLARE @SumProffit TABLE ([ProjectID] TIdentifier, [SumProffit] money)
	INSERT INTO @SumProffit ([ProjectID], [SumProffit])
		SELECT 
		[Project].[ID],
		ISNULL(SUM([InvoiceLine].[PricePC] * [InvoiceLine].[Amount] - [InvoiceLine].[VATIsIncluded] * [InvoiceLine].[VATPC]), 0)
	FROM 
		[Invoice]
		INNER JOIN [InvoiceLine]
			ON [Invoice].[ID] = [InvoiceLine].[InvoiceID]
		INNER JOIN [Project]
			ON [Invoice].[ProjectID] = [Project].[ID]
		INNER JOIN [vwAssignment]
			ON [vwAssignment].[ProjectID] = [Project].[ID]
		INNER JOIN [ServiceType]		
			ON [ServiceType].[ID] = [InvoiceLine].[ServiceTypeID]
		LEFT OUTER JOIN [AdvanceInvoice]
			ON [AdvanceInvoice].[AdvanceInvoiceID] = [Invoice].[ID]
		LEFT OUTER JOIN [Invoice] AS [Base]
			ON [AdvanceInvoice].[InvoiceID] = [Base].[ID]
	WHERE
		([Base].[State] NOT IN (2,5) OR [Base].[State] IS NULL) AND	
		[Invoice].[Date] >= @PeriodStart AND [Invoice].[Date] < @PeriodEnd AND
		[ServiceType].[RatesDepended] = 1 AND
		[Invoice].[State] IN (2,5) AND
		[vwAssignment].[EmployeeID] = @EmployeeID
	GROUP BY [Project].[ID]

	DECLARE @Loss TABLE ([ProjectID] TIdentifier, [Loss] money, [BillableLoss] money)
	INSERT INTO @Loss ([ProjectID], [Loss], [BillableLoss])
		SELECT 
			[Project].[ID],
			SUM(([EntryAmount].[Price] / (1 + [VATRate]*[Project].[RatesWithVAT]))*[EntryAmount].[Amount]),
			SUM(CASE [TimeEntry].[State] WHEN 4 THEN 0 ELSE ([Price] / (1 + [VATRate]*[Project].[RatesWithVAT]))*[EntryAmount].[Amount]*[TimeEntry].[Billable] END)
		FROM
			[TimeEntry]
			INNER JOIN [Project]
				ON [TimeEntry].[ProjectID] = [Project].[ID]
			INNER JOIN [EntryAmount]
				ON [EntryAmount].[ID] = [TimeEntry].[ID]
			INNER JOIN [vwAssignment]
				ON [vwAssignment].[ProjectID] = [Project].[ID]
		WHERE		 
			[TimeEntry].[State] IN (3,4,6) AND
			[vwAssignment].[EmployeeID] = @EmployeeID AND
			[TimeEntry].[StartTime] >= @PeriodStart AND [TimeEntry].[StartTime] < @PeriodEnd
	GROUP BY [Project].[ID] 
	DECLARE @Multiplier TABLE( [ProjectID] TIdentifier,[Multiplier] decimal(18,8),[BillableMultiplier] decimal(18,8) ) 
	INSERT INTO @Multiplier ([ProjectID],[Multiplier],[BillableMultiplier])	
	SELECT
			[Loss].[ProjectID],
			CASE [Loss].[Loss] WHEN 0 THEN 0 ELSE CAST([SumProffit].[SumProffit] AS decimal(18,8))/CAST([Loss].[Loss] AS decimal(18,8)) END,
			CASE [Loss].[BillableLoss] WHEN 0 THEN 0 ELSE CAST([SumProffit].[SumProffit] AS decimal(18,8))/CAST([Loss].[BillableLoss] AS decimal(18,8)) END
		FROM
			@Loss AS [Loss]
		INNER JOIN @SumProffit AS [SumProffit]
			ON [Loss].[ProjectID] = [SumProffit].[ProjectID]
		
	DECLARE @Table TABLE ([QualificationID] TIdentifier,[ProjectID] TIdentifier, [CurrentRate] TMoney, [TimeRate] money, [SumDuration] decimal(18), [TimeRateBillable] money, [SumDurationBillable] decimal(18))
	INSERT INTO @Table 
		SELECT 
			[vwAssignment].[QualificationID],
			[vwAssignment].[ProjectID],
			[vwAssignment].[StandardRate], 
			SUM(CASE [TimeEntry].[State] WHEN 4 THEN 0 ELSE [Rate]*[TimeEntry].[Duration] END),
			SUM([TimeEntry].[Duration]),
			SUM(CASE [TimeEntry].[State] WHEN 4 THEN 0 ELSE [Rate] * [TimeEntry].[Duration] * [TimeEntry].[Billable] END),
			SUM(CASE [TimeEntry].[State] WHEN 4 THEN 0 ELSE [TimeEntry].[Duration]* [TimeEntry].[Billable] END)	
		FROM
			[TimeEntry]
			INNER JOIN [vwAssignment]
				ON [TimeEntry].[AssignmentID] = [vwAssignment].[ID] AND
				[TimeEntry].[ProjectID] = [vwAssignment].[ProjectID]
			INNER JOIN [Project]
				ON [Project].[ID] = [TimeEntry].[ProjectID]		
		WHERE 
			[TimeEntry].[EmployeeID] = @EmployeeID AND
			[TimeEntry].[State] IN (3,4,6) AND
			[TimeEntry].[StartTime] >= @PeriodStart AND [TimeEntry].[StartTime] < @PeriodEnd
		GROUP BY 
			[vwAssignment].[ProjectID],
			[vwAssignment].[QualificationID],
			[vwAssignment].[StandardRate]
	
	SELECT 
		[Project].[Number] AS [ProjectCode],
		[Project].[CurrencyCode],
		ISNULL([Qualification].[FileAs],'( )') AS [QualificationFileAs],
		[Table].[CurrentRate],  
		ISNULL([Qualification].[FileAs],'( )') AS [QualificationFileAs],
		CASE WHEN [Multiplier] = 0 OR [SumDuration] = 0  THEN 0 ELSE [Multiplier]*[TimeRate]/[SumDuration] END AS [Rate],
		CASE WHEN [BillableMultiplier] = 0 OR [SumDurationBillable] = 0 THEN 0 ELSE [BillableMultiplier]*[TimeRateBillable]/[SumDurationBillable] END AS [BillableRate]        
	FROM 
		@Table AS [Table]
		INNER JOIN @Multiplier AS [Multiplier]
			ON	[Multiplier].[ProjectID] = [Table].[ProjectID]
		INNER JOIN [Project]
				ON	[Project].[ID] = [Table].[ProjectID]
		LEFT OUTER JOIN [Qualification]
			ON [Qualification].[ID] = [Table].[QualificationID]	
			
	ORDER BY 
		[CurrentRate] DESC

RETURN 0

GO

GRANT EXEC ON ReportRateByEmployee TO PUBLIC

GO
