IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportProjectByManager')
	BEGIN
		PRINT 'Dropping Procedure ReportProjectByManager'
		DROP  Procedure  ReportProjectByManager
	END

GO

PRINT 'Creating Procedure ReportProjectByManager'
GO

--------------------------------------------------------------------------------------
CREATE Procedure ReportProjectByManager
			@DateSelector int,
			@StartDate TDate,
			@EndDate TDate,
			@CompanyID TIdentifier,
			@DivisionID TIdentifier,
			@ManagerID TIdentifier,
			@CostCenterSelector int,
			@CostCenterID TIdentifier
 
AS
	SET NOCOUNT ON

------------------------------------------------
	IF @CompanyID IS NULL
	BEGIN
		RAISERROR('#CompanyIsNotSelected', 16, -1)
		RETURN 1
	END
	
	IF @DivisionID IS NULL
	BEGIN
		RAISERROR('#DivisionIsNotSelected', 16, -1)
		RETURN 1
	END

	DECLARE
		@UserID TIdentifier,
		@UserName TName,
		@DivisionFileAs TName,
		@CostCenterCode TCode,
		@EmployeeFileAs TName

		SET @UserID = dbo.adfGetCurrentUserID()
	SELECT
		@UserName = [Trustee].[DisplayName]
	FROM
		[Trustee]
	WHERE
		[Trustee].[ID] = @UserID
	
	SET DATEFIRST 1
	DECLARE 
		@Date		TDate
		
	SET @Date = CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime)
	
	SET @StartDate = CASE @DateSelector
			WHEN 1 THEN DATEADD(day, 1 - DATEPART(weekday, @Date), @Date)
			WHEN 0 THEN DATEADD(week, -1, DATEADD(day, 1 - DATEPART(weekday, @Date), @Date))
			ELSE CAST(CONVERT(varchar(8), @StartDate, 112) AS datetime)
		END
		
	IF(@DateSelector = 0 OR @DateSelector = 1)
		SET @EndDate = CAST(CONVERT(varchar(8), DATEADD(second, -1, DATEADD(week, 1, @StartDate)), 112) AS datetime)
	
	IF @DateSelector = 2 --last month
		BEGIN
			SELECT
				@StartDate = CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime),
				@StartDate = DATEADD(day, 1-DATEPART(day, @StartDate), @StartDate),
				@StartDate = DATEADD(month, -1, @StartDate),
				@EndDate = DATEADD(day, -1, DATEADD(month, 1, @StartDate))
		END
		ELSE IF @DateSelector = 3 -- current month
			BEGIN
			SELECT
				@StartDate = CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime),
				@StartDate = DATEADD(day, 1-DATEPART(day, @StartDate), @StartDate),
				@EndDate = DATEADD(day, -1, DATEADD(month, 1, @StartDate))
			END
	
	SELECT
		@DivisionFileAs = [Division].[FileAs]
	FROM
		[Division]
	WHERE
		[Division].[ID] = @DivisionID
	
	SELECT
		@CostCenterCode = [CostCenter].[Code]
	FROM
		[CostCenter]
	WHERE 
		[CostCenter].[ID] = @CostCenterID  AND @CostCenterSelector != 0
	
	SELECT
		@EmployeeFileAs = [Employee].[FileAs]
	FROM
		[Employee]
	WHERE
		[Employee].[ID] = @ManagerID
		

	SELECT 
		@UserName AS [UserName],
		GETDATE() AS [Date],
		@StartDate AS [PeriodStart],
		@EndDate AS [PeriodEnd],
		[Company].[FileAs] AS [CompanyFileAs],
		@DivisionFileAs AS [DivisionFileAs],
		ISNULL(@CostCenterCode, '( )') AS [CostCenterFileAs],
		ISNULL(@EmployeeFileAs, '()') AS [ManagerFileAs]
	FROM [Company]
	WHERE [Company].[ID]= @CompanyID	

	DECLARE @t TABLE
	(
		[ManagerID] TIdentifier,
		[ManagerFileAs] TName,
		[CostCenterID] TIdentifier,
		[CostCenterFileAs] TCode,
		[ProjectID] TIdentifier,
		[TimeEntryID] TIdentifier,
		[ServiceTypeID] TIdentifier
	)
	
	INSERT INTO @t
	(
		[ManagerID],
		[ManagerFileAs],
		[CostCenterID],
		[CostCenterFileAs],
		[ProjectID],	
		[TimeEntryID],
		[ServiceTypeID]
	)
	SELECT 
		[Employee].[ID],
		[Employee].[FileAs],
		[CostCenter].[ID],
		[CostCenter].[Code],
		[Project].[ID],
		[TimeEntry].[ID],
		NULL AS [ServiceTypeID]
	FROM 
		[Project] 
		INNER JOIN [CostCenter]
			ON [Project].[CostCenterID] = [CostCenter].[ID]
		INNER JOIN [TimeEntry]
			ON [TimeEntry].[ProjectID] = [Project].[ID]
		INNER JOIN [ActivityType]
			ON [TimeEntry].[ActivityTypeID] = [ActivityType].[ID]
		INNER JOIN [Employee]
			ON [Employee].[ID] = [TimeEntry].[EmployeeID]
	WHERE
		[Project].[State] IN (2, 3, 4)
		AND [TimeEntry].[State] IN (2, 3, 6) 
		AND [ActivityType].[PhoneCallAccessible] = 1
		AND CAST(CONVERT(varchar(8), [TimeEntry].[StartTime], 112) AS datetime) BETWEEN @StartDate AND @EndDate
		AND (@CostCenterSelector = 0 OR [CostCenter].[ID] = @CostCenterID)
		AND	[Employee].[DivisionID] = @DivisionID
		AND (@ManagerID IS NULL OR [Employee].[ID] = @ManagerID)
	
	UNION ALL
	
	SELECT
		[Employee].[ID],
		[Employee].[FileAs],
		[CostCenter].[ID],
		[CostCenter].[Code],
		[Project].[ID],
		NULL AS [TimeEntryID],
		[ServiceType].[ID] 
	FROM
		[Project]
			INNER JOIN [CostCenter]
				ON [CostCenter].[ID] = [Project].[CostCenterID]
			INNER JOIN [Invoice]
				ON [Project].[ID] = [Invoice].[ProjectID]
			INNER JOIN [InvoiceLine]
				ON [InvoiceLine].[InvoiceID] = [Invoice].[ID]
			INNER JOIN [ServiceType]
				ON [InvoiceLine].[ServiceTypeID] = [ServiceType].[ID]
			INNER JOIN [vwEmployeeWithEP] as [Employee]
				ON [Project].[CreatedBy] = [Employee].[UserID]
	WHERE
		[Project].[State] IN (2, 3, 4) 
		AND CAST(CONVERT(varchar(8),[Project].[Date], 112) AS datetime) BETWEEN @StartDate AND @EndDate
		AND (@CostCenterSelector = 0 OR [Project].[CostCenterID] = @CostCenterID)
		AND	[Employee].[DivisionID] = @DivisionID
		AND (@ManagerID IS NULL OR [Employee].[ID] = @ManagerID)

	
	SELECT 
		COUNT (DISTINCT 
			CASE WHEN [ServiceType].[ID] IS NOT NULL THEN [table].[ProjectID] 
				ELSE NULL END) AS [ProjectCount],
		[table].[CostCenterFileAs],
		[ServiceType].[FileAs] AS [ServiceTypeFileAs],
		[ServiceType].[ID] AS [ServiceTypeID]
	FROM
		@t AS [table] 
			LEFT OUTER JOIN [ServiceType]
				ON [ServiceType].[ID] = [table].[ServiceTypeID]
	GROUP BY 
		[ServiceType].[FileAs],
		[ServiceType].[ID],
		[table].[CostCenterFileAs]
	ORDER BY
		[table].[CostCenterFileAs],
		[ServiceType].[ID]	

	SELECT
		COUNT(DISTINCT [table].[TimeEntryID]) AS [TimeEntryCount],
		[table].[CostCenterFileAs]
	FROM
		@t AS [table]
	GROUP BY
		[table].[CostCenterFileAs]
	ORDER BY 
		[table].[CostCenterFileAs]
		
	RETURN 0
GO

GRANT EXEC ON ReportProjectByManager TO PUBLIC
GO   