IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportActivityTypeByDivision')
	BEGIN
		PRINT 'Dropping Procedure ReportActivityTypeByDivision'
		DROP  Procedure  ReportActivityTypeByDivision
	END

GO

PRINT 'Creating Procedure ReportActivityTypeByDivision'
GO
--------------------------------------------------------------------------------------
-- Copyright (c) 2003 by Avicom
--------------------------------------------------------------------------------------
-- $Archive: $
-- $Author: $
-- $Revision: $
-- $Modtime: $
-- $Date: $
--
-- Description: this stored procedure ...........
-- Input:	.........
-- Output:      0 - success, negative number - otherwise
--
-- Notes:       no
--
--
/* $Log: $ 
   $NoKeywords: $ 
--------------------------------------------------------------------------------------*/

CREATE Procedure ReportActivityTypeByDivision
	@StartDate	TDateTime,
	@EndDate	TDateTime,
	@DateSelector	int,
	@CompanyID		TIdentifier,
	@DivisionID		TIdentifier,
	@DivisionSelector int,
	@ProjectTypeSelector int
AS
	SET NOCOUNT ON

	DECLARE @SumDuration TAmount,
			@UserID TIdentifier,
			@UserName TName,
			@DivisionFileAs TName,
			@ProjectTypeFileAs TName,
			@CompanyFileAs TName,
			@value TVariant,
			@WorkTime decimal(18,2),
			@Date TDate

	SET @Date = CAST(CONVERT(varchar(8), GETDATE(), 112) AS DATETIME)
	IF @DateSelector = 0 -- month
		SELECT
			@StartDate = DATEADD(day, 1-DATEPART(day, @Date), @Date),
			@EndDate = DATEADD(day, 1, @Date)
	ELSE
	IF @DateSelector = 1 -- prev month
		SELECT
			@StartDate = DATEADD(day, 1-DATEPART(day, @Date), @Date),
			@StartDate = DATEADD(month, -1, @StartDate),
			@EndDate = DATEADD(month, 1, @StartDate)
	ELSE
	IF @DateSelector = 3 -- quart
		SELECT
			@StartDate = [StartDate],
			@EndDate = [EndDate]
		FROM	
			dbo.adfGetDateInterval(3, @Date, @Date, @Date)
	ELSE 
	IF @DateSelector = 2 -- prev quart
		SELECT
			@StartDate = [StartDate],
			@EndDate = [EndDate]
		FROM	
			dbo.adfGetDateInterval(4, @Date, @Date, @Date)
	ELSE
		SELECT
			@StartDate = CAST(CONVERT(varchar(8), @StartDate, 112) AS datetime),
			@EndDate = DATEADD(day, 1, CAST(CONVERT(varchar(8), @EndDate, 112) AS datetime))
	
	EXEC adfParameterGet 'WorkTime', 'Pjm5', @value OUTPUT  
	SET @WorkTime = CAST(@value AS decimal(18,2))
	SET @WorkTime = @WorkTime / 60.00	
	
	SET @DivisionFileAs = CASE @DivisionSelector
         WHEN 0 THEN '()'
         WHEN 1 THEN ' '
         WHEN 2 THEN '()'
    END
    SET @ProjectTypeFileAs = CASE @ProjectTypeSelector
         WHEN 0 THEN '()'
         WHEN 1 THEN '  '
         WHEN 2 THEN ' '
         WHEN 3 THEN ''
    END
         
    SELECT
		@DivisionFileAs = [Division].[FileAs]
	FROM
		[Division]
	WHERE
		[Division].[ID] = @DivisionID		
    
	SET @CompanyFileAs = '()'
    SELECT
		@CompanyFileAs = [Company].[FileAs]
	FROM
		[Company]
	WHERE
		[Company].[ID] = @CompanyID			
	
	SET @UserID = dbo.adfGetCurrentUserID()
	SELECT
		@UserName = [Trustee].[DisplayName]
	FROM
		[Trustee]
	WHERE
		[Trustee].[ID] = @UserID
	
	
	SELECT @SumDuration = SUM([TimeEntry].[Duration])
	FROM
		[Division]	
		INNER JOIN [TimeEntry]
			ON [Division].[ID] = [TimeEntry].[DivisionID]
		INNER JOIN [Project]
			ON [Project].[ID] = [TimeEntry].[ProjectID]
	WHERE
		([Project].[SupplierCompanyID] = @CompanyID OR @CompanyID IS NULL) 
		AND
		(
			@DivisionSelector = 0 OR 
			(@DivisionSelector = 2 AND (@DivisionID IS NULL  OR [Division].[ID] = @DivisionID ))
		)
		AND
		(
			@ProjectTypeSelector = 0 OR 
			(@ProjectTypeSelector = 1 AND [Project].[ProjectTypeID] = 1) OR 
			(@ProjectTypeSelector = 2 AND [Project].[ProjectTypeID] = 2) OR 
			(@ProjectTypeSelector = 3 AND [Project].[ProjectTypeID] NOT IN (1, 2))
		)
		 AND
		[TimeEntry].[StartTime] >= @StartDate AND [TimeEntry].[StartTime] <= @EndDate	
		AND [TimeEntry].[State] IN (3, 6)

	IF (@SumDuration = 0) SET @SumDuration = 1	
	SELECT 
		[Division].[FileAs] as [DivisionFileAs],
		[ProjectType].[FileAs] as [ProjectTypeFileAs],
		ISNULL([ActivityType].[FileAs],'( )') as [ActivityTypeFileAs],
		SUM(ISNULL([BillableTime].[Duration], 0)) / 60.0 as [BillableDuration],
		SUM(ISNULL([UnbillableTime].[Duration], 0)) / 60.0 as [UnbillableDuration],
		SUM(ISNULL([TimeEntry].[Duration], 0)) / 60.0 as [CommonDuration],
		SUM(ISNULL([TimeEntry].[Duration], 0)) / @SumDuration  as [Percent]
	FROM
		[Division]
			INNER JOIN [TimeEntry]
				ON [Division].[ID] = [TimeEntry].[DivisionID]
			LEFT OUTER JOIN [ActivityType]
				ON [ActivityType].[ID] = [TimeEntry].[ActivityTypeID]
			INNER JOIN [Project]
				ON [Project].[ID] = [TimeEntry].[ProjectID]
			INNER JOIN [ProjectType]
				ON [Project].[ProjectTypeID] = [ProjectType].[ID]
			LEFT OUTER JOIN [TimeEntry] as [BillableTime]
				ON [TimeEntry].[ID] = [BillableTime].[ID]
					AND [BillableTime].[Billable] = 1
			LEFT OUTER JOIN [TimeEntry] as [UnbillableTime]
				ON [TimeEntry].[ID] = [UnbillableTime].[ID]
					AND [UnbillableTime].[Billable] = 0
	WHERE
		([Project].[SupplierCompanyID] = @CompanyID OR @CompanyID IS NULL) 
		AND
			(
				@DivisionSelector = 0 OR 
				(@DivisionSelector = 2 AND (@DivisionID IS NULL  OR [Division].[ID] = @DivisionID ))
			)
		AND
			(
				@ProjectTypeSelector = 0 OR 
				(@ProjectTypeSelector = 1 AND [Project].[ProjectTypeID] = 1) OR 
				(@ProjectTypeSelector = 2 AND [Project].[ProjectTypeID] = 2) OR 
				(@ProjectTypeSelector = 3 AND [Project].[ProjectTypeID] NOT IN (1, 2))
			)
		AND
		[TimeEntry].[StartTime] >= @StartDate AND [TimeEntry].[StartTime] <= @EndDate
		AND [TimeEntry].[State] IN (3, 6)
	GROUP BY
		[Division].[FileAs],
		[ProjectType].[FileAs],
		[ActivityType].[FileAs]
	
	SELECT
		@StartDate as [StartDate],
		DATEADD(day, -1, @EndDate) as [EndDate],
		ISNULL(@DivisionFileAs, '( )') as [DivisionFileAs],
		ISNULL(@ProjectTypeFileAs, '( )') as [ProjectType],
		@UserName as [UserName],
		dbo.fnPjm5GetWorkingDays(@StartDate, DATEADD(day, -1, @EndDate)) as [WorkingDays],
		@WorkTime as [WorkingHours],
		ISNULL(@CompanyFileAs, '()') as [CompanyFileAs]
RETURN 0
GO

GRANT EXEC ON ReportActivityTypeByDivision TO PUBLIC

GO
 