IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportEmployeeTimeAllocationByPeriod')
	BEGIN
		PRINT 'Dropping Procedure ReportEmployeeTimeAllocationByPeriod'
		DROP  Procedure  ReportEmployeeTimeAllocationByPeriod
	END

GO

PRINT 'Creating Procedure ReportEmployeeTimeAllocationByPeriod'
GO
/******************************************************************************
**		File: ReportEmployeeTimeAllocationByPeriod.sql
**		Name: ReportEmployeeTimeAllocationByPeriod
**
**         
**		Return values:
**
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		13.12.2011	ASA				First Version
*******************************************************************************/
CREATE PROCEDURE [dbo].[ReportEmployeeTimeAllocationByPeriod]
        @DateSelector int,
        @StartDate TDateTime,
        @EndDate TDateTime,
        @EmployeeTypeSelector int,
        @WorkingEmployeeID TIdentifier,
        @DismissedEmployeeID TIdentifier
AS

SET NOCOUNT ON

DECLARE 
		@EmployeeID TIdentifier,
        @CompanyFileAs TName,
        @DivisionFileAs TName,
        @EmployeeFileAs TName,
        @EmployeeNumber TName,
        @EmployeePosition TName,
        @Date TDate,
        @WorkingDays decimal(18,2),
        @Value TVariant,
        @UserID TIdentifier,
        @UserName TName,
        @BaseCurrency TCode3,
        @NationalCurrency TCode3,
        @num int,
		@CalculationClass TClass,
		@StatementClass TClass,
		@InvoiceClass TClass,
		@TimeEntryClass TClass,
		@ExpenseClass TClass 
		
SET	@CalculationClass = dbo.adfGetClassByName('Pjm5.Calculation')
SET	@StatementClass = dbo.adfGetClassByName('Pjm5.Statement')
SET	@InvoiceClass = dbo.adfGetClassByName('Pjm5.Invoice')
SET	@TimeEntryClass = dbo.adfGetClassByName('Pjm5.TimeEntry')
SET	@ExpenseClass = dbo.adfGetClassByName('Pjm5.Expense')

EXEC adfParameterGet 'BaseCurrency', 'CommonBusiness', @Value = @Value OUTPUT   
   SET @BaseCurrency = CAST(@Value AS nvarchar(32))
   
EXEC adfParameterGet 'NationalCurrency', 'CommonBusiness', @Value = @Value OUTPUT   
   SET @NationalCurrency = CAST(@Value AS nvarchar(32))

IF (@EmployeeTypeSelector = 0)
	BEGIN
		IF (@WorkingEmployeeID IS NULL) 
		BEGIN
				RAISERROR('#EmployeeIsNotSelected', 16, -1)
				RETURN 2
		END
		ELSE
		BEGIN
			SET @EmployeeID = @WorkingEmployeeID
		END
	END
ELSE
	BEGIN
		IF (@DismissedEmployeeID IS NULL) 
		BEGIN
				RAISERROR('#EmployeeIsNotSelected', 16, -1)
				RETURN 2
		END
		ELSE
		BEGIN
			SET @EmployeeID = @DismissedEmployeeID
		END
	END

SELECT
    @CompanyFileAs = [Company].[FileAs],
    @DivisionFileAs = [Division].[FileAs],
    @EmployeeFileAs = [Employee].[FileAs],
    @EmployeeNumber =  [Employee].[Number],
    @EmployeePosition = [Position].[FileAs]
FROM
	[Employee]
	INNER JOIN [Company]
		ON  [Company].[ID] = [Employee].[CompanyID]
	LEFT OUTER JOIN [Division]
		ON [Division].[ID] = [Employee].[DivisionID]
	LEFT OUTER JOIN [Position]
		ON [Position].[ID] = [Employee].[PositionID]
WHERE 
	[Employee].[ID] = @EmployeeID

SET @Date = CAST(CONVERT(varchar(8), GETDATE(), 112) AS DATETIME)
IF @DateSelector = 0 -- current month
	SELECT
		@StartDate = DATEADD(day, 1-DATEPART(day, @Date), @Date),
		@EndDate = DATEADD(day, 1, @Date)
ELSE IF @DateSelector = 1 -- prev month
	SELECT
		@StartDate = DATEADD(day, 1-DATEPART(day, @Date), @Date),
		@StartDate = DATEADD(month, -1, @StartDate),
		@EndDate = DATEADD(month, 1, @StartDate)
ELSE IF @DateSelector = 2 -- quart
	SELECT
		@StartDate = [StartDate],
		@EndDate = DATEADD(day, 1, @Date)
	FROM	
		dbo.adfGetDateInterval(4, @Date, @Date, @Date)
ELSE IF @DateSelector = 3 -- prev quart
	SELECT
		@StartDate = [StartDate],
		@EndDate = [EndDate]
	FROM	
		dbo.adfGetDateInterval(3, @Date, @Date, @Date)
ELSE IF @DateSelector = 4 -- curr year
	SELECT
		@StartDate = CAST(Year(@Date) as varchar(4)),
		@EndDate = DATEADD(day, 1, @Date)
ELSE IF @DateSelector = 5 -- prev year
	SELECT
		@EndDate = CAST(Year(@Date) as varchar(4)),
		@StartDate = CAST(Year(@Date)-1 as varchar(4))
ELSE
	SELECT
		@StartDate = CAST(CONVERT(varchar(8), @StartDate, 112) AS datetime),
		@EndDate = DATEADD(day, 1, CAST(CONVERT(varchar(8), @EndDate, 112) AS datetime))

SET DATEFIRST 7
SET @WorkingDays = dbo.fnPjm5GetWorkingDays(@StartDate, DATEADD(day, -1, @EndDate))
SET DATEFIRST 1

--   ,    
DECLARE @TimeEntriesInFinance TABLE(DocumentID TIdentifier,LinkClass TClass, LinkDocumentID TIdentifier, State	TState, Date TDateTime, ThroughCalculation TFlag)
INSERT INTO @TimeEntriesInFinance(DocumentID, LinkClass, LinkDocumentID, State, ThroughCalculation)
SELECT 
[F].[DocumentID], [F].[LinkClass], [F].[LinkDocumentID], [F].[State], [F].[ThroughCalculation]
FROM
fnReportGetTimeEntriesInFinance(@StartDate, @EndDate, @EmployeeID) AS [F]

SET @UserID = dbo.adfGetCurrentUserID()
SELECT
    @UserName = [Trustee].[DisplayName]
FROM
	[Trustee]
WHERE
	[Trustee].[ID] = @UserID

EXEC adfParameterGet 'BaseCurrency', 'CommonBusiness', @Value = @Value OUTPUT   
SET @BaseCurrency = CAST(@Value AS nvarchar(32))

EXEC adfParameterGet 'NationalCurrency', 'CommonBusiness', @Value = @Value OUTPUT   
SET @NationalCurrency= CAST(@Value AS nvarchar(32))

DECLARE @TimeType TABLE(ID int)
SET @num = 1

WHILE (@num < 8)
BEGIN
	INSERT INTO @TimeType(ID) SELECT @num
	SET @num = @num + 1
END
;

WITH TimeEntryTypes ([State], [ProjectType], [Duration], [Value1],[Value2]) AS  
(
	SELECT
        [TimeType].[ID],
        [ProjectType].[ID],
        CASE
	        WHEN	[TimeType].[ID] = 1 
					AND [TimeEntry].[State] IN (3, 6) 
					AND [ProjectType].[ID] = [Project].[ProjectTypeId]
					THEN [TimeEntry].[RoundedDuration]/60.0
            WHEN	[TimeType].[ID] = 2 
					AND [TimeEntry].[State] IN (3, 6) 
					AND [TimeEntry].[Billable] = 1 
					AND [Project].[ProjectTypeID] = 1 
					AND [ProjectType].[ID] = [Project].[ProjectTypeId]
					THEN [TimeEntry].[RoundedDuration]/60.0
            WHEN	[TimeType].[ID] = 3								-- 
					AND [TimeEntry].[State] IN (6) 
					AND [Project].[ProjectTypeID] = 1  
					AND [ProjectType].[ID] = [Project].[ProjectTypeId]
					AND [TimeEntriesInFinance].[State] <> 1				--    
					AND NOT ([TimeEntriesInFinance].[LinkClass] = @InvoiceClass AND [TimeEntriesInFinance].[State] IN (6)) --   
					THEN [EntryAmount].[Amount] 
            WHEN	[TimeType].[ID] = 4								--  
					AND [TimeEntry].[State] IN (6) 
					AND [Project].[ProjectTypeID] = 1 
					AND [ProjectType].[ID] = [Project].[ProjectTypeId] 
					AND [EntryAmount].[Amount] > 0
					AND [TimeEntriesInFinance].[State] <> 1
					THEN [EntryAmount].[Amount] - [TimeEntry].[RoundedDuration]/60.0	--	!,    
            WHEN	[TimeType].[ID] = 5 
					AND [TimeEntry].[State] in (2) 
					AND [Project].[ProjectTypeID] NOT IN (5,6) 
					AND [ProjectType].[ID] = [Project].[ProjectTypeId]
					THEN [TimeEntry].[RoundedDuration]/60.0
            WHEN	[TimeType].[ID] = 6 
					AND [TimeEntry].[State] in (1, 5)
					AND [Project].[ProjectTypeID] NOT IN (5,6) 
					AND [ProjectType].[ID] = [Project].[ProjectTypeId]
					THEN [TimeEntry].[RoundedDuration]/60.0
            WHEN	[TimeType].[ID] = 7 
					AND [TimeEntry].[State] IN (4)
					AND [Project].[ProjectTypeID] NOT IN (5,6) 
					AND [ProjectType].[ID] = [Project].[ProjectTypeId]
					THEN [TimeEntry].[RoundedDuration]/60.0
            ELSE NULL END,
		-- .   1
        CASE WHEN	[TimeType].[ID] = 2								--   ( )	
					AND [TimeEntry].[State] IN (3, 6) 
					AND [TimeEntry].[Billable] = 1 
					AND [Project].[ProjectTypeID] = 1 
					AND [ProjectType].[ID] = [Project].[ProjectTypeId] 
					THEN ROUND( 
						[TimeEntry].[RoundedDuration]/60.0, 2) 
					*	
						[TimeEntry].[Rate]
					*
						(1 -	CASE [Project].[RatesWithVAT] 
								WHEN 1 THEN [TimeEntry].[VATRate]/(1 + [TimeEntry].[VATRate]) 
								ELSE 0 
								END)
					*
						CASE [Project].[CurrencyCode]  
						WHEN @BaseCurrency THEN 1 
						ELSE dbo.pjm6fnCurrencyGetRate([Project].[CurrencyCode], [TimeEntry].[StartTime], @BaseCurrency) 
						END 
			--   
            WHEN	[TimeType].[ID] = 3								-- . ,  
					AND [TimeEntry].[State] IN (6) 
					AND [Project].[ProjectTypeID] = 1 
					AND [ProjectType].[ID] = [Project].[ProjectTypeId] 
					AND [TimeEntriesInFinance].[State] <> 1				--  ,     
					AND NOT ([TimeEntriesInFinance].[LinkClass] = @InvoiceClass AND [TimeEntriesInFinance].[State] IN (6))	--   
					AND [TimeEntriesInFinance].[LinkClass] <> @CalculationClass
					THEN	
						[EntryAmount].[Amount]
					*	
						[EntryAmount].[Price]
					*   
						(1 -	CASE [Project].[RatesWithVAT]
								WHEN 1 THEN [TimeEntry].[VATRate]/(1 + [TimeEntry].[VATRate])
								ELSE 0 END)
					*   
						CASE [Project].[CurrencyCode]
						WHEN @BaseCurrency THEN 1 
						ELSE dbo.pjm6fnCurrencyGetRate([Project].[CurrencyCode], [TimeEntry].[StartTime], @BaseCurrency) 
						END 
			WHEN	[TimeType].[ID] = 3 								-- 
					AND [TimeEntry].[State] IN (6) 
					AND [Project].[ProjectTypeID] = 1 
					AND [ProjectType].[ID] = [Project].[ProjectTypeId] 
					AND [TimeEntriesInFinance].[State] <> 1				--  ,    
					AND [TimeEntriesInFinance].[LinkClass] = @CalculationClass
					THEN		
						[EntryAmount].[Amount]
					*	
						[EntryAmount].[Price]
					*
						CASE [Calculation].[DiscountType]
						WHEN 1 THEN (1 - [Calculation].[DiscountPercent])
						WHEN 2 THEN (1 +  [Calculation].[DiscountPercent])
						WHEN 3 THEN 
							CASE 
							WHEN [Calculation].[TotalWithoutDiscount] > [Calculation].[Discount] THEN [Calculation].[DiscountPercent]
							ELSE 1
							END
						ELSE 1
						END
					*   
						(1 -	CASE [Project].[RatesWithVAT] 
								WHEN 1  THEN	 [TimeEntry].[VATRate]/(1 + [TimeEntry].[VATRate]) 
								ELSE 0 END)
					*	
						CASE [Project].[CurrencyCode] 	
						WHEN @BaseCurrency THEN 1  
						ELSE dbo.pjm6fnCurrencyGetRate([Project].[CurrencyCode], [TimeEntry].[StartTime], @BaseCurrency)  
						END  
            WHEN	[TimeType].[ID] = 4 
					AND [TimeEntry].[State] IN (6) 
					AND [Project].[ProjectTypeID] = 1 
					AND [ProjectType].[ID] = [Project].[ProjectTypeId] 
					AND [TimeEntriesInFinance].[State] <> 1				--  ,    
					THEN ABS([EntryAmount].[Amount] - [TimeEntry].[RoundedDuration]/60.0) * [EntryAmount].[Price]
					*
						(1 -	CASE [Project].[RatesWithVAT] 
								WHEN 1 THEN [TimeEntry].[VATRate]/(1 + [TimeEntry].[VATRate]) 
								ELSE 0 
								END)
					*
						CASE [Project].[CurrencyCode]   
						WHEN @BaseCurrency THEN 1  
						ELSE dbo.pjm6fnCurrencyGetRate([Project].[CurrencyCode], [TimeEntry].[StartTime], @BaseCurrency)   
						END 
            ELSE NULL                  
        END,
		-- .   2
        CASE WHEN	[TimeType].[ID] = 2 
				AND [TimeEntry].[State] IN (3, 6) 
				AND [TimeEntry].[Billable] = 1 
				AND [Project].[ProjectTypeID] = 1 
				AND [ProjectType].[ID] = [Project].[ProjectTypeId] 
				THEN ROUND(
						[TimeEntry].[RoundedDuration]/60.0,2)
					*
						[TimeEntry].[Rate]
					*
						(1 -	CASE [Project].[RatesWithVAT] 
								WHEN 1 THEN [TimeEntry].[VATRate]/(1 + [TimeEntry].[VATRate]) 
								ELSE 0 
								END) 
					*
						CASE [Project].[CurrencyCode]  
						WHEN @NationalCurrency	THEN 1 
						ELSE dbo.pjm6fnCurrencyGetRate([Project].[CurrencyCode], [TimeEntry].[StartTime], @NationalCurrency) 
						END 
             WHEN	[TimeType].[ID] = 3				-- .   
				AND [TimeEntry].[State] IN (6) 
				AND [Project].[ProjectTypeID] = 1 
				AND [ProjectType].[ID] = [Project].[ProjectTypeId] 
				AND [TimeEntriesInFinance].[State] <> 1				--  ,     
				AND NOT ([TimeEntriesInFinance].[LinkClass] = @InvoiceClass AND [TimeEntriesInFinance].[State] IN (3,6))	--      
				AND [TimeEntriesInFinance].[LinkClass] <> @CalculationClass
				THEN	
					[EntryAmount].[Amount] 
				* 
					[EntryAmount].[Price] 
				* 
					(1 -	CASE [Project].[RatesWithVAT] 
							WHEN 1  THEN [TimeEntry].[VATRate]/(1 + [TimeEntry].[VATRate]) 
							ELSE 0 
							END)
				*
					CASE [Project].[CurrencyCode]   
					WHEN @NationalCurrency  THEN 1  
					ELSE dbo.pjm6fnCurrencyGetRate([Project].[CurrencyCode], [TimeEntry].[StartTime], @NationalCurrency)  
					END  
			----------------------
			 WHEN	[TimeType].[ID] = 3			-- 
				AND [TimeEntry].[State] IN (6) 
				AND [Project].[ProjectTypeID] = 1 
				AND [ProjectType].[ID] = [Project].[ProjectTypeId] 
				AND [TimeEntriesInFinance].[State] <> 1				--  ,    
				AND [TimeEntriesInFinance].[LinkClass] = @CalculationClass
				THEN	  
					[EntryAmount].[Amount]
				*	
					[EntryAmount].[Price]
				*
					CASE [Calculation].[DiscountType]
					WHEN 1 THEN (1 - [Calculation].[DiscountPercent])
					WHEN 2 THEN (1 + [Calculation].[DiscountPercent])
					WHEN 3 THEN 
							CASE 
							WHEN [Calculation].[TotalWithoutDiscount] > [Calculation].[Discount] THEN [Calculation].[DiscountPercent]
							ELSE 1
							END
					ELSE 1 
					END
				*
					(1 -	CASE [Project].[RatesWithVAT] 
							WHEN 1  THEN	 [TimeEntry].[VATRate]/(1 + [TimeEntry].[VATRate]) 
									ELSE 0 END)
				*	
					CASE [Project].[CurrencyCode]   
					WHEN @NationalCurrency  THEN 1  
					ELSE dbo.pjm6fnCurrencyGetRate([Project].[CurrencyCode], [TimeEntry].[StartTime], @NationalCurrency)  
					END  
			----------------------
             WHEN  [TimeType].[ID] = 4 
				AND [TimeEntry].[State] IN (6) 
				AND [Project].[ProjectTypeID] = 1
				AND [ProjectType].[ID] = [Project].[ProjectTypeId] 
				AND [EntryAmount].[Amount] > 0   
				AND [TimeEntriesInFinance].[State] <> 1				--  ,    
                THEN	
					ABS([EntryAmount].[Amount] - [TimeEntry].[RoundedDuration]/60.0)*[EntryAmount].[Price] 
				*
					(1 -	CASE [Project].[RatesWithVAT] 
							WHEN 1  THEN [TimeEntry].[VATRate]/(1 + [TimeEntry].[VATRate]) 
							ELSE 0 END)
				*
                    CASE [Project].[CurrencyCode]  
					WHEN @NationalCurrency THEN 1 
                    ELSE dbo.pjm6fnCurrencyGetRate([Project].[CurrencyCode], [TimeEntry].[StartTime], @NationalCurrency)  
					END                  
             ELSE NULL                  
        END
	FROM
        [ProjectType]
        CROSS JOIN @TimeType AS [TimeType]
        CROSS JOIN [TimeEntry] AS [TimeEntry]
        INNER JOIN [EntryAmount]
            ON [EntryAmount].[ID] = [TimeEntry].[ID]
        INNER JOIN [Project]
            ON [Project].[ID] = [TimeEntry].[ProjectID]
		LEFT OUTER JOIN										--    ,   
		@TimeEntriesInFinance AS [TimeEntriesInFinance] 	
			ON [TimeEntriesInFinance].[DocumentID] = [TimeEntry].[ID]
		LEFT OUTER JOIN 
		[Calculation] AS [Calculation]
			ON [Calculation].[ID] = [TimeEntriesInFinance].[LinkDocumentID]
	WHERE 
		[EmployeeID] = @EmployeeID AND
		[StartTime] >= @StartDate AND [StartTime] < @EndDate
		AND ([TimeEntriesInFinance].ThroughCalculation = 0 OR [TimeEntriesInFinance].ThroughCalculation IS NULL)
  )

SELECT [State],
       [ProjectType],
       ISNULL(SUM([Duration]),0) AS [Duration],
       ISNULL(SUM([Value1]),0) AS [Value1],
       ISNULL(SUM([Value2]),0) AS [Value2]

FROM [TimeEntryTypes]
--Where Round([Duration],0)>0
GROUP BY [ProjectType],[State]
HAVING SUM([Duration]) <> 0
ORDER BY [ProjectType],[State]

SELECT @CompanyFileAs AS [CompanyFileAs],
       @DivisionFileAs AS [DivisionFileAs],
       @EmployeeFileAs AS [EmployeeFileAS],
       @EmployeeNumber AS [EmployeeNumber],
       @EmployeePosition AS  [EmployeePosition],
       @WorkingDays AS [WorkingDays],
       @WorkingDays*8 AS [WorkingHours],
       @DateSelector AS [DateSelector],
       @StartDate AS [StartDate],
       DATEADD(day, -1, @EndDate) as [EndDate],
       @UserName AS [UserName],
       @BaseCurrency AS [BaseCurrency],
       @NationalCurrency AS [NationalCurrency]
GO

GRANT EXEC ON ReportEmployeeTimeAllocationByPeriod TO PUBLIC

GO

