IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportLoadOfProjects')
	BEGIN
		PRINT 'Dropping Procedure ReportLoadOfProjects'
		DROP  Procedure  ReportLoadOfProjects
	END

GO

PRINT 'Creating Procedure ReportLoadOfProjects'
GO

--------------------------------------------------------------------------------------
-- Copyright (c) 2003 by Avicom
--------------------------------------------------------------------------------------
-- $Archive: $
-- $Author: $
-- $Revision: $
-- $Modtime: $
-- $Date: $
--
-- Description: this stored procedure ...........
-- Input:	.........
-- Output:      0 - success, negative number - otherwise
--
-- Notes:       no
--
--
/* $Log: $ 
   $NoKeywords: $ 
--------------------------------------------------------------------------------------*/
CREATE Procedure ReportLoadOfProjects
	@DateSelector	int,
	@WeekStart		Tdatetime,
	@ManagerID		int,
	@DecimalSeparator varchar(1),
	@DivisionSelector int,
	@CompanyID		TIdentifier,
	@DivisionID		TIdentifier
AS

	IF @CompanyID IS NULL AND @DivisionSelector<>2
	BEGIN
		RAISERROR('#CompanyIsNotSelected', 16, -1)
		RETURN 1
	END
	
	IF @DivisionID IS NULL AND @DivisionSelector=2 
	BEGIN
		RAISERROR('#DivisionIsNotSelected', 16, -1)
		RETURN 2
	END
	
	SET NOCOUNT ON
	SET DATEFIRST 1
	DECLARE 
		@Date		TDate
		
		SET @Date = CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime)
	
		SET @WeekStart = CASE @DateSelector
			WHEN 0 THEN DATEADD(day, 1 - DATEPART(weekday, @Date), @Date)
			WHEN 1 THEN DATEADD(week, 1, DATEADD(day, 1 - DATEPART(weekday, @Date), @Date))
			ELSE CAST(CONVERT(varchar(8), @WeekStart, 112) AS datetime)
		END	
	
	
	IF @ManagerID IS NULL
		SET @ManagerID = dbo.adfGetCurrentEmployeeID()
		
	EXECUTE ReportLoadOfProjectsHeader @WeekStart, @CompanyID, @ManagerID, @DivisionID, @DivisionSelector
	
	SELECT
		[Project].[Number] AS [FileAs],
		dbo.fnPjm5GetEmployeeListProjectForDate([Project].[ID], @WeekStart, @DecimalSeparator,@DivisionID,@DivisionSelector) AS [Day1],
		dbo.fnPjm5GetEmployeeListProjectForDate([Project].[ID], DATEADD(day, 1, @WeekStart), @DecimalSeparator,@DivisionID,@DivisionSelector) AS [Day2],
		dbo.fnPjm5GetEmployeeListProjectForDate([Project].[ID], DATEADD(day, 2, @WeekStart), @DecimalSeparator,@DivisionID,@DivisionSelector) AS [Day3],
		dbo.fnPjm5GetEmployeeListProjectForDate([Project].[ID], DATEADD(day, 3, @WeekStart), @DecimalSeparator,@DivisionID,@DivisionSelector) AS [Day4],
		dbo.fnPjm5GetEmployeeListProjectForDate([Project].[ID], DATEADD(day, 4, @WeekStart), @DecimalSeparator,@DivisionID,@DivisionSelector) AS [Day5],
		dbo.fnPjm5GetEmployeeListProjectForDate([Project].[ID], DATEADD(day, 5, @WeekStart), @DecimalSeparator,@DivisionID,@DivisionSelector) AS [Day6],
		dbo.fnPjm5GetEmployeeListProjectForDate([Project].[ID], DATEADD(day, 6, @WeekStart), @DecimalSeparator,@DivisionID,@DivisionSelector) AS [Day7],
		SUM(CASE WHEN [Task].[State] in (2,5,8)
				Then (([BusyEntry].[Planned] - [BusyEntry].[Canceled]) / 60.00)
				ELSE 0
		END) AS [Total]
	FROM
		[Project]
		INNER JOIN [ProjectDetail]
			ON [ProjectDetail].[ID] = [Project].[ID]
		LEFT OUTER JOIN [BusyEntry]
			ON [Project].[ID]  = [BusyEntry].[ProjectID] AND
				[BusyEntry].[Date] >= @WeekStart AND [BusyEntry].[Date] < DATEADD(week, 1, @WeekStart)
		LEFT OUTER JOIN [Employee]
			ON [BusyEntry].[EmployeeID] = [Employee].[ID]
		LEFT OUTER JOIN [Division] 
			ON [Employee].[DivisionID] = [Division].[ID]
		LEFT OUTER JOIN [Task]
			ON [BusyEntry].[TaskID] = [Task].[ID]	
	WHERE
		[Project].[SupplierCompanyID] = @CompanyID AND
		(
			@DivisionSelector = 0 OR 
			(@DivisionSelector = 1 AND [Employee].[DivisionID] IS NULL) OR
			(@DivisionSelector = 2 AND ([Employee].[DivisionID] = @DivisionID OR (@DivisionID IS NULL AND [Employee].[DivisionID] IS NOT NULL)))
		)AND 
		[Project].[ProjectManagerEmployeeID] = @ManagerID AND
		[Project].[State] IN (1,2,3) AND
		[Employee].[State] = 1 AND 
		[Project].[Date] < DATEADD(week, 1, @WeekStart) AND 
		ISNULL([Project].[EndDate], [ProjectDetail].[DueDate]) >= @WeekStart
				
	GROUP BY 
		[Project].[Number],
		[Project].[ID]
	UNION ALL
	SELECT
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	0	

RETURN 0
GO

GRANT EXEC ON ReportLoadOfProjects TO PUBLIC

GO
