IF EXISTS (SELECT * FROM [dbo].[sysobjects] WHERE id = OBJECT_ID(N'[dbo].[ReportProjectCostOfServiceTimeExpense]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping Procedure ReportProjectCostOfServiceTimeExpense'
		DROP PROCEDURE ReportProjectCostOfServiceTimeExpense
	END 
GO
PRINT 'Creating Procedure ReportProjectCostOfServiceTimeExpense'
GO

--------------------------------------------------------------------------------------
-- Copyright (c) 2007 by Avicom
--------------------------------------------------------------------------------------
-- $Archive: $
-- $Author: denis.agarev
-- $Revision: $
-- $Modtime: $
-- $Date: $
--
-- Description: this stored procedure ...........
-- Input:	.........
-- Output:      0 - success, negative number - otherwise
--
-- Notes:       no
--
--
/* $Log: $ 
   $NoKeywords: $ 
--------------------------------------------------------------------------------------*/
CREATE PROCEDURE ReportProjectCostOfServiceTimeExpense
	@ProjectID TIdentifier,
	@DateSelector int,
	@PeriodStart TDate,
	@PeriodEnd TDate
As
	SET NOCOUNT ON
	SET DATEFIRST 1

	IF @ProjectID IS NULL
	BEGIN
		RAISERROR('#ProjectIsNotSelected', 16, -1)
		RETURN 1
	END
	
	DECLARE
		@UserName TName,
		@Date TDate
	DECLARE
		@Dates Table([Date] DateTime)
	
	IF @DateSelector = 0
		BEGIN
			SELECT
				@PeriodStart = [StartDate],
				@PeriodEnd = [EndDate]
			FROM	
				dbo.adfGetDateInterval(1, GETDATE(), GETDATE(), GETDATE())
		END
	ELSE IF @DateSelector = 1
		BEGIN
			SELECT
				@PeriodStart = [StartDate],
				@PeriodEnd = [EndDate]
			FROM	
				dbo.adfGetDateInterval(2, GETDATE(), GETDATE(), GETDATE())
		END
	ELSE IF @DateSelector = 2
		BEGIN
			SET @PeriodStart = CONVERT(datetime, CONVERT(varchar(8), GETDATE(), 112), 112)
			SET	@PeriodStart = DATEADD(day, -6-DATEPART(weekday, GETDATE()), @PeriodStart)
			SET	@PeriodEnd = DATEADD(week, 1, @PeriodStart)
		END
	ELSE IF @DateSelector = 3
		BEGIN
			SET @PeriodStart = CONVERT(datetime, CONVERT(varchar(8), GETDATE(), 112), 112)
			SET	@PeriodStart = DATEADD(day, 1-DATEPART(weekday, GETDATE()), @PeriodStart)
			SET	@PeriodEnd = DATEADD(week, 1, @PeriodStart)
		END	
	ELSE	SET	@PeriodEnd = DATEADD(day, 1, @PeriodEnd)
				
	
	SELECT
		@UserName = [Trustee].[DisplayName]
	FROM
		[Trustee]
	WHERE
		[Trustee].[ID] = dbo.adfGetCurrentUserID()
	
	SELECT
		@UserName as [UserName],
		@PeriodStart as [PeriodStart],
		DATEADD(day, -1, @PeriodEnd) as [PeriodEnd],
		[Project].[FileAs] as [ProjectName],
		ISNULL([Company].[FileAs], ' ') as [SupplierCompanyName],
		[Project].[ContractSubject] as [ContractName],
		[Project].[CurrencyCode] as [Currency],
		[Employee].[FileAs] as [ProjectManager],
		[PropertyValue].[Value] as [Partner]	
	FROM
		[Project]
		LEFT OUTER JOIN [Company]
			ON [Company].[ID] = [Project].[CustomerCompanyID]
		INNER JOIN [Employee]
			ON [Employee].[ID] = [Project].[ProjectManagerEmployeeID]
		LEFT OUTER JOIN [Property]
			ON [Property].[Name] = ''
		LEFT OUTER JOIN [PropertyValue]
			ON [PropertyValue].[DocumentID] = @ProjectID
			AND [PropertyValue].[DocumentClass] = [Project].[Class]
			AND [PropertyValue].[PropertyID] = [Property].[ID]
 	WHERE
		[Project].[ID] = @ProjectID
	

	SET @Date = @PeriodStart
	WHILE @Date < @PeriodEnd
		BEGIN
			INSERT INTO @Dates ([Date]) VALUES (@Date)
			SET @Date = DATEADD(day, 1, @Date) 
		END

	SELECT
		[Dates].[Date] as [Date],
		[Employee].[FileAs] as [Employee],
		[Qualification].[FileAs] as [Qualification],
		ISNULL([Task].[FileAs], '') +
			(CASE WHEN [Task].[FileAs] IS NULL 
			THEN '' ELSE ' / ' END) + 
			ISNULL([TimeEntry].[FileAs], '') as [Task],
	  	0.01*CEILING([EntryAmount].[Amount]*100) as [TimeDuration],
		([EntryAmount].[Price]) as [Rate]			
	FROM
		@Dates as [Dates]
		INNER JOIN [TimeEntry]
			ON (CAST(CONVERT(varchar(8), [TimeEntry].[StartTime], 112) as Datetime)) =
				 (CAST(CONVERT(varchar(8), [Dates].[Date], 112) as Datetime))			
			AND [TimeEntry].[ProjectID] = @ProjectID	
			AND [TimeEntry].[State] IN (3,6)
			AND [TimeEntry].[Billable] = 1
		INNER JOIN [EntryAmount]
			ON [EntryAmount].[ID] = [TimeEntry].[ID]
		INNER JOIN [Employee]
			ON [Employee].[ID] = [TimeEntry].[EmployeeID]
		INNER JOIN [Assignment]
			ON [Assignment].[ID] = [TimeEntry].[AssignmentID]
		LEFT JOIN [Qualification]
			ON [Qualification].[ID] = [Assignment].[QualificationID]
		LEFT OUTER JOIN [Task]
			ON [Task].[ID] = [TimeEntry].[TaskID]
	ORDER BY
		[Dates].[Date],
		[EntryAmount].[Price] DESC,
		[Employee].[FileAs],
		[Task].[FileAs]

	RETURN 0
GO

GRANT EXEC ON ReportProjectCostOfServiceTimeExpense TO PUBLIC
GO