IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportResourcePlanPeriod')
	BEGIN
		PRINT 'Dropping Procedure ReportResourcePlanPeriod'
		DROP  Procedure  ReportResourcePlanPeriod
	END

GO

PRINT 'Creating Procedure ReportResourcePlanPeriod'
GO
--------------------------------------------------------------------------------------
-- Copyright (c) 2003 by Avicom
--------------------------------------------------------------------------------------
-- $Archive: $
-- $Author: $
-- $Revision: $
-- $Modtime: $
-- $Date: $
--
-- Description: this stored procedure ...........
-- Input:	.........
-- Output:      0 - success, negative number - otherwise
--
-- Notes:       no
--
--
/* $Log: $ 
   $NoKeywords: $ 
--------------------------------------------------------------------------------------*/
CREATE Procedure ReportResourcePlanPeriod
	@PeriodSelector	int,
	@CompanyID		int,
	@DivisionSelector int,
	@DivisionID		TIdentifier
AS
	SET NOCOUNT ON
		IF @DivisionID IS NULL AND @DivisionSelector=2 
	BEGIN
		RAISERROR('#DivisionIsNotSelected', 16, -1)
		RETURN 1
	END
	
	DECLARE
		@PeriodStart	  datetime,
		@PeriodEnd		  datetime,
		@PeriodEnd1		  datetime,
		@PeriodEnd2		  datetime,
		@TodayDate		  datetime,
		@DayCount		  int,
		@MonthCount		  int,
		@QuarterCount     int		
	
	SET @TodayDate = CAST(CONVERT(varchar(8), GETDATE(), 112) AS DATETIME)
	SET @DayCount = DATEPART(day, @TodayDate)
	SET @QuarterCount = DATEPART(quarter,@TodayDate)
	SET @MonthCount = DATEPART(month,@TodayDate)
		
	SET @PeriodStart = CASE @PeriodSelector
		WHEN 0 THEN DATEADD(month, 1, DATEADD(day, 1 - @DayCount, @TodayDate))
		WHEN 1 THEN DATEADD(quarter, @QuarterCount, DATEADD(month, 1 - @MonthCount, DATEADD(day, 1 - @DayCount, @TodayDate)))	
	END		
	SET @PeriodEnd = CASE @PeriodSelector
		WHEN 0 THEN DATEADD(month, 3, @PeriodStart)
		WHEN 1 THEN DATEADD(quarter, 3, @PeriodStart)
	END
	SET @PeriodEnd1 = CASE @PeriodSelector
		WHEN 0 THEN DATEADD(month, 1, @PeriodStart)
		WHEN 1 THEN DATEADD(quarter, 1, @PeriodStart)
	END
	SET @PeriodEnd2 = CASE @PeriodSelector
		WHEN 0 THEN DATEADD(month, 2, @PeriodStart)
		WHEN 1 THEN DATEADD(quarter, 2, @PeriodStart)
	END
	
	EXECUTE ReportResourcePlanPeriodHeader @PeriodSelector, @PeriodStart, @PeriodEnd, @PeriodEnd1, @PeriodEnd2, @TodayDate, @CompanyID,  @DivisionSelector,@DivisionID
	
	DECLARE
		@q	table(			
			[QualificationID]	int,
			[QualificationName] varchar(256),
			[EmployeeCount]		int				
		)

	INSERT INTO @q(
		[QualificationID],
		[QualificationName],
		[EmployeeCount]	
	)
	
	SELECT
		[Qualification].[ID],
		[Qualification].[FileAs],
		Count([Employee].[ID])
	FROM 
		[Qualification]
		LEFT OUTER JOIN [Employee]
			ON [Qualification].[ID] = [Employee].[QualificationID]
		LEFT OUTER JOIN [Company]
			ON [Employee].[CompanyID] = [Company].[ID]
		LEFT OUTER JOIN [Division] 
			ON [Employee].[DivisionID] = [Division].[ID]
	WHERE
		[Company].[Own] = 1 AND(@CompanyID IS NULL OR [Company].[ID] = @CompanyID) 	
		AND
		(
			@DivisionSelector = 0 OR 
			(@DivisionSelector = 1 AND [Employee].[DivisionID] IS NULL) OR
			(@DivisionSelector = 2 AND ([Employee].[DivisionID] = @DivisionID OR (@DivisionID IS NULL AND [Employee].[DivisionID] IS NOT NULL)))
		)
	GROUP BY
		[Qualification].[ID],
		[Qualification].[FileAs]
	
	
	SELECT
	q.[QualificationName] AS [Qualification],
	q.[EmployeeCount] AS [EmployeeCount],
	SUM(CASE
		WHEN [Project].[ProjectTypeID] = 1 AND [BusyEntry].[Date] >= @PeriodStart AND [BusyEntry].[Date] < @PeriodEnd1
		THEN ([BusyEntry].[Planned] - [BusyEntry].[Canceled]) / 60.00
		ELSE 0
	END) AS [Hours11],
	SUM(CASE
		WHEN [Project].[ProjectTypeID] = 2 AND [BusyEntry].[Date] >= @PeriodStart AND [BusyEntry].[Date] < @PeriodEnd1
		THEN ([BusyEntry].[Planned] - [BusyEntry].[Canceled]) / 60.00
		ELSE 0
	END) AS [Hours12],
	SUM(CASE
		WHEN [Project].[ProjectTypeID] = 3 AND [BusyEntry].[Date] >= @PeriodStart AND [BusyEntry].[Date] < @PeriodEnd1
		THEN ([BusyEntry].[Planned] - [BusyEntry].[Canceled]) / 60.00
		ELSE 0
	END) AS [Hours13],
	SUM(CASE
		WHEN [Project].[ProjectTypeID] = 4 AND [BusyEntry].[Date] >= @PeriodStart AND [BusyEntry].[Date] < @PeriodEnd1
		THEN ([BusyEntry].[Planned] - [BusyEntry].[Canceled]) / 60.00
		ELSE 0
	END) AS [Hours14],
	SUM(CASE
		WHEN [Project].[ProjectTypeID] = 5 AND [BusyEntry].[Date] >= @PeriodStart AND [BusyEntry].[Date] < @PeriodEnd1
		THEN ([BusyEntry].[Planned] - [BusyEntry].[Canceled]) / 60.00
		ELSE 0
	END) AS [Hours15],
	
	
	SUM(CASE
		WHEN [Project].[ProjectTypeID] = 1 AND [BusyEntry].[Date] >= @PeriodEnd1 AND [BusyEntry].[Date] < @PeriodEnd2
		THEN ([BusyEntry].[Planned] - [BusyEntry].[Canceled]) / 60.00
		ELSE 0
	END) AS [Hours21],
	SUM(CASE
		WHEN [Project].[ProjectTypeID] = 2 AND [BusyEntry].[Date] >= @PeriodEnd1 AND [BusyEntry].[Date] < @PeriodEnd2
		THEN ([BusyEntry].[Planned] - [BusyEntry].[Canceled]) / 60.00
		ELSE 0
	END) AS [Hours22],
	SUM(CASE
		WHEN [Project].[ProjectTypeID] = 3 AND [BusyEntry].[Date] >= @PeriodEnd1 AND [BusyEntry].[Date] < @PeriodEnd2
		THEN ([BusyEntry].[Planned] - [BusyEntry].[Canceled]) / 60.00
		ELSE 0
	END) AS [Hours23],
	SUM(CASE
		WHEN [Project].[ProjectTypeID] = 4 AND [BusyEntry].[Date] >= @PeriodEnd1 AND [BusyEntry].[Date] < @PeriodEnd2
		THEN ([BusyEntry].[Planned] - [BusyEntry].[Canceled]) / 60.00
		ELSE 0
	END) AS [Hours24],
	SUM(CASE
		WHEN [Project].[ProjectTypeID] = 5 AND [BusyEntry].[Date] >= @PeriodEnd1 AND [BusyEntry].[Date] < @PeriodEnd2
		THEN ([BusyEntry].[Planned] - [BusyEntry].[Canceled]) / 60.00
		ELSE 0
	END) AS [Hours25],
	
	SUM(CASE
		WHEN [Project].[ProjectTypeID] = 1 AND [BusyEntry].[Date] >= @PeriodEnd2 AND [BusyEntry].[Date] < @PeriodEnd
		THEN ([BusyEntry].[Planned] - [BusyEntry].[Canceled]) / 60.00
		ELSE 0
	END) AS [Hours31],
	SUM(CASE
		WHEN [Project].[ProjectTypeID] = 2 AND [BusyEntry].[Date] >= @PeriodEnd2 AND [BusyEntry].[Date] < @PeriodEnd
		THEN ([BusyEntry].[Planned] - [BusyEntry].[Canceled]) / 60.00
		ELSE 0
	END) AS [Hours32],
	SUM(CASE
		WHEN [Project].[ProjectTypeID] = 3 AND [BusyEntry].[Date] >= @PeriodEnd2 AND [BusyEntry].[Date] < @PeriodEnd
		THEN ([BusyEntry].[Planned] - [BusyEntry].[Canceled]) / 60.00
		ELSE 0
	END) AS [Hours33],
	SUM(CASE
		WHEN [Project].[ProjectTypeID] = 4 AND [BusyEntry].[Date] >= @PeriodEnd2 AND [BusyEntry].[Date] < @PeriodEnd
		THEN ([BusyEntry].[Planned] - [BusyEntry].[Canceled]) / 60.00
		ELSE 0
	END) AS [Hours34],
	SUM(CASE
		WHEN [Project].[ProjectTypeID] = 5 AND [BusyEntry].[Date] >= @PeriodEnd2 AND [BusyEntry].[Date] < @PeriodEnd
		THEN ([BusyEntry].[Planned] - [BusyEntry].[Canceled]) / 60.00
		ELSE 0
	END) AS [Hours35]
	
	FROM @q AS q
		LEFT OUTER JOIN [Assignment]
			ON q.[QualificationID] = [Assignment].[QualificationID]
		LEFT OUTER JOIN [BusyEntry]
			ON [Assignment].[ID] = [BusyEntry].[AssignmentID]
			AND [BusyEntry].[Date] >= @PeriodStart AND [BusyEntry].[Date] < @PeriodEnd
		LEFT OUTER JOIN [Project]
			ON [BusyEntry].[ProjectID] = [Project].[ID]	AND
			([Project].[SupplierCompanyID] = @CompanyID OR @CompanyID IS NULL)
	WHERE [Project].[State] in(1,2,3,4) AND ([BusyEntry].[Planned] - [BusyEntry].[Canceled]) != 0					
	GROUP BY
		q.[QualificationName],
		q.[EmployeeCount]	


RETURN 0
GO

GRANT EXEC ON ReportResourcePlanPeriod TO PUBLIC

GO
