IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportRevenueDynamicsByServiceTypeHeader')
	BEGIN
		PRINT 'Dropping Procedure ReportRevenueDynamicsByServiceType'
		DROP  Procedure  ReportRevenueDynamicsByServiceType
	END

GO

PRINT 'Creating Procedure ReportRevenueDynamicsByServiceType'
GO

/******************************************************************************
**		File: ReportEmployeesTimeAllocationByProject.sql
**		Name: ReportEmployeesTimeAllocationByProject
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: ?
**		Date: ?
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		21.10.2011	MAN			   
**		21.10.2011	MAN			     " "
**		19.10.2012	MAB			     
*******************************************************************************/
CREATE PROCEDURE [dbo].[ReportRevenueDynamicsByServiceType]
      @CompanyID TIdentifier,
      @CurrencySelector int,
      @CostCenterID TIdentifier,
	  @CostCenterSelector int,
      @ServiceTypeSelector int,
      @InvoiceSelector int,
      @DateSelector int,
      @PeriodEnd TDate,
      @CurrentQuarterIncluded int

AS

   SET NOCOUNT ON

   DECLARE 
      @PeriodStart  TDate,
      @InvoicePrevPeriodEnd TDate,
      @InvoicePeriodEnd TDate,
      @Quarter int,
      @Total float, @Rate float,
      @Prefix nvarchar(5),
      @CurrencyCode TCode3,
      @Value TVariant,
      @ToCurrencyCode TCode3
   
  DECLARE @RevenueHeader Table(CompanyName TName,
                               CurrencyCode nvarchar(32),
                               CostCenterName TName,
                               SeriveIncludedName  TName,
                               InvoiceState TName,
                               PeriodStart TDate, 
                               PeriodEnd TDate,
                               UserName TName)
  INSERT INTO @RevenueHeader(CompanyName, 
                             CurrencyCode,
                             CostCenterName,
                             SeriveIncludedName,
                             InvoiceState,
                             PeriodStart, 
                             PeriodEnd,
                             UserName)         
  EXEC  ReportRevenueDynamicsByServiceTypeHeader
        @CompanyID, @CurrencySelector, @CostCenterID, @CostCenterSelector,
        @ServiceTypeSelector, @InvoiceSelector, @DateSelector, 
        @PeriodStart = @PeriodStart OUTPUT,
        @PeriodEnd = @PeriodEnd OUTPUT 


   EXEC adfParameterGet 'BaseCurrency', 'CommonBusiness', @Value = @Value OUTPUT   
   SET @CurrencyCode = CAST(@Value AS nvarchar(32))
   
   EXEC adfParameterGet 'NationalCurrency', 'CommonBusiness', @Value = @Value OUTPUT   
   SET @ToCurrencyCode = CAST(@Value AS nvarchar(32))

   IF @PeriodEnd = CAST(YEAR(GetDate())as char(4))
      SET @InvoicePeriodEnd = GetDate()
   ELSE
      SET @InvoicePeriodEnd = dateadd(year, 1, @PeriodEnd)
  
   SET @InvoicePrevPeriodEnd = dateadd(year, -1, @InvoicePeriodEnd)   

   DECLARE @Revenue TABLE(Revenue float, ServiceType varchar(MAX), QuarterId int)
   INSERT INTO @Revenue
   SELECT  
		CASE @CurrencySelector
			WHEN 0 
				THEN SUM([InvoiceLine].[TotalWithVATBC]) 
            WHEN 1 
				THEN 
					SUM([InvoiceLine].[TotalWithVATBC]*
						dbo.pjm6fnCurrencyGetRate(@CurrencyCode,[Invoice].[Date], @ToCurrencyCode)) 
		END AS Revenue,
		CASE
			WHEN [ServiceType].[FileAs] IS NULL
				THEN ' '
			ELSE 
        		[ServiceType].[FileAs]
		END AS FileAs,
        CASE 
			WHEN CAST(YEAR(Invoice.Date)as char(4)) = @PeriodEnd 
					THEN DATENAME(quarter, Invoice.Date)+4
                WHEN CAST(YEAR(Invoice.Date)as char(4)) = @PeriodStart 
					THEN DATENAME(quarter, Invoice.Date)
        END  AS QuarterId
   FROM [InvoiceLine]
   LEFT OUTER JOIN [ServiceType]
		ON [InvoiceLine].[ServiceTypeID] = [ServiceType].[ID]
   INNER JOIN [Invoice]
		ON [InvoiceLine].[InvoiceID] = [Invoice].[ID]
   INNER JOIN Project
		ON [Invoice].[ProjectID] = [Project].ID
   INNER JOIN [Company] 
		ON [Project].[CustomerCompanyID] = [Company].[ID] 
   WHERE 
   (	
		(
			@InvoiceSelector = 0 
			AND 
			[Invoice].[State] = 5 
		) 
		OR 
		(
			@InvoiceSelector = 1 
			AND 
			[Invoice].[State] IN (2,5)
		)
	) 
	AND 
	(
		(
			[Invoice].[Date] BETWEEN @PeriodStart AND @InvoicePrevPeriodEnd
		) 
		OR
		(
			[Invoice].[Date] BETWEEN @PeriodEnd AND @InvoicePeriodEnd
		)
	) 
	AND
	(
		@ServiceTypeSelector = 0 
		OR
		@ServiceTypeSelector = 1 
		AND
		(
			[ServiceType].[RatesDepended] = 1 
			OR
			[ServiceType].[ID] IS NULL
		)
		OR
		@ServiceTypeSelector = 2 
		AND 
		[ServiceType].[RatesDepended] = 0
	) 
	AND
	(
		[Project].[SupplierCompanyID] = @CompanyID 
		OR 
		@CompanyID IS NULL
	) 
	AND
	(
		(
			[Project].[CostCenterID] = @CostCenterID 
			AND 
			@CostCenterSelector = 1
		) 
		OR 
		(
			[Project].[CostCenterID] IS NULL
			AND 
			@CostCenterID IS NULL 
			AND @CostCenterSelector = 1
		) 
		OR
		@CostCenterSelector = 0
	)
   GROUP BY 
	[InvoiceLine].[ServiceTypeID], 
	[Invoice].[Date],
	[ServiceType].[FileAs]

  
   DECLARE @RevenueDynamics TABLE
   (
		ServiceType varchar(MAX), 
		RowNumber int,
        Quarter1 float, 
		Quarter2 float, 
        Quarter3 float, 
		Quarter4 float,
        Quarter5 float, 
		Quarter6 float, 
        Quarter7 float, 
		Quarter8 float
	)
   INSERT INTO @RevenueDynamics 
   SELECT ServiceType,
		CASE
			WHEN  ServiceType=' '
				THEN 999
			ELSE
				ROW_NUMBER() OVER(ORDER BY ServiceType)
		END AS NumOrder,
          ISNULL([1],0),
		  ISNULL([2],0), 
          ISNULL([3],0), 
		  ISNULL([4],0),
          ISNULL([5],0), 
		  ISNULL([6],0), 
          ISNULL([7],0),
		  ISNULL([8],0) 
   FROM 
		(
			SELECT 
				ServiceType,
				QuarterId, 
				Revenue
			FROM @Revenue
			
		) AS A
   PIVOT (SUM(Revenue) FOR QuarterId IN ([1],[2],[3],[4],[5],[6],[7],[8])) AS B

 

  SET @Quarter = DATENAME(quarter, @InvoicePeriodEnd) 
  
  IF @CurrentQuarterIncluded = 1 AND 
     @PeriodEnd = CAST(YEAR(GetDate())as char(4))
  BEGIN   
      IF @Quarter = 1 
      UPDATE @RevenueDynamics SET Quarter1 = NULL, Quarter5 = NULL

      IF @Quarter = 2
      UPDATE @RevenueDynamics SET Quarter2 = NULL, Quarter6 = NULL 

      IF @Quarter = 3
      UPDATE @RevenueDynamics  SET Quarter3 = NULL, Quarter7 = NULL
								   
      IF @Quarter = 4
      UPDATE @RevenueDynamics  SET Quarter4 = NULL, Quarter8 = NULL

   END

  IF @PeriodEnd = CAST(YEAR(GetDate())as char(4))
   BEGIN   
      IF @Quarter = 1 
      UPDATE @RevenueDynamics SET Quarter2 = NULL, Quarter3 = NULL, 
                                  Quarter4 = NULL, Quarter6 = NULL, 
                                  Quarter7 = NULL, Quarter8 = NULL 
      IF @Quarter = 2
      UPDATE @RevenueDynamics SET Quarter3 = NULL, Quarter7 = NULL, 
                                  Quarter4 = NULL, Quarter8 = NULL 
      IF @Quarter = 3
      UPDATE @RevenueDynamics SET Quarter4=NULL, Quarter8=NULL
   END
      
   SELECT 
       @Total = SUM(ISNULL(Quarter5,0) + ISNULL(Quarter6,0)+
                    ISNULL(Quarter7,0)+ISNULL(Quarter8,0)) 
   FROM @RevenueDynamics 
   
   SET @Rate = CASE  
                 WHEN @Total < 1000 THEN 1
                 WHEN @Total >= 1000 and @Total < 10000000 THEN 0.001
                 WHEN @Total >= 10000000 and @Total < 10000000000 THEN 0.000001
                 WHEN @Total >= 10000000000 THEN 0.000000001
               END
   SET @Prefix = CASE  
                 WHEN @Total < 1000 THEN ''
                 WHEN @Total >= 1000 and @Total < 10000000 THEN '.'
                 WHEN @Total >= 10000000 and @Total < 10000000000 THEN '.'
                 WHEN @Total >= 10000000000 THEN '.'
               END
    
   UPDATE @RevenueHeader
   SET CurrencyCode = @Prefix + CurrencyCode
   
   SELECT * FROM @RevenueHeader
   
   DECLARE @i int;

   SELECT  
		ServiceType,
		ROW_NUMBER() OVER(ORDER BY ((ISNULL(Quarter5, 0) + ISNULL(Quarter6, 0) + ISNULL(Quarter7, 0) + ISNULL(Quarter8, 0))) * @Rate DESC) AS NumOrder,
		Quarter1 * @Rate Quarter1,
		Quarter2 * @Rate Quarter2,
		Quarter3 * @Rate Quarter3,
		Quarter4 * @Rate Quarter4,
		Quarter5 * @Rate Quarter5,
		Quarter6 * @Rate Quarter6,
		Quarter7 * @Rate Quarter7,
		Quarter8 * @Rate Quarter8,
		((ISNULL(Quarter1,0) + ISNULL(Quarter2,0)+
		ISNULL(Quarter3,0) + ISNULL(Quarter4,0)))*@Rate as  TotalPrevYear,
		((ISNULL(Quarter5,0) + ISNULL(Quarter6,0)+
		ISNULL(Quarter7,0) + ISNULL(Quarter8,0)))*@Rate as  TotalYear        
  FROM @RevenueDynamics
  ORDER BY NumOrder

RETURN 0
GO

GRANT EXEC ON ReportRevenueDynamicsByServiceType TO PUBLIC

GO
