IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportTimesheetOfProject')
	BEGIN
		PRINT 'Dropping Procedure ReportTimesheetOfProject'
		DROP  Procedure  ReportTimesheetOfProject
	END

GO

PRINT 'Creating Procedure ReportTimesheetOfProject'
GO

--------------------------------------------------------------------------------------
-- Copyright (c) 2003 by Avicom
--------------------------------------------------------------------------------------
-- $Archive: $
-- $Author: $
-- $Revision: $
-- $Modtime: $
-- $Date: $
--
-- Description: this stored procedure ...........
-- Input:	.........
-- Output:      0 - success, negative number - otherwise
--
-- Notes:       no
--
--
/* $Log: $ 
   $NoKeywords: $ 
--------------------------------------------------------------------------------------*/
CREATE Procedure ReportTimesheetOfProject
	@DateSelector		int,
	@WeekStart			Tdatetime,
	@EmployeeID			int,
	@ProjectSelector	int,
	@ActiveProjectID	TIdentifier,
	@NotActiveProjectID TIdentifier
	
AS
	SET NOCOUNT ON
	SET DATEFIRST 1
	
	IF @ProjectSelector = 0 AND @ActiveProjectID IS NULL
	BEGIN
		RAISERROR('#ProjectIsNotSelected', 16, -1)
		RETURN 1
	END
	
	IF @ProjectSelector = 1 AND @NotActiveProjectID IS NULL
	BEGIN
		RAISERROR('#ProjectIsNotSelected', 16, -1)
		RETURN 1
	END
		
	DECLARE 
		@Date			TDate,
		@NextDate		TDate,
		@ProjectID		TIdentifier
		
		SET @Date = CAST(CONVERT(varchar(8), GETDATE(), 112) AS datetime)
	
		SET @WeekStart = CASE @DateSelector
			WHEN 0 THEN DATEADD(day, 1 - DATEPART(weekday, @Date), @Date)
			WHEN 1 THEN DATEADD(week, -1, DATEADD(day, 1 - DATEPART(weekday, @Date), @Date))
			ELSE CAST(CONVERT(varchar(8), @WeekStart, 112) AS datetime)
		END
		
		SET @NextDate = CASE @DateSelector
			WHEN 0 THEN DATEADD(day, 1, @Date)
			ELSE DATEADD(week, 1, @WeekStart)
		END	
		
		SET @ProjectID = CASE @ProjectSelector
			WHEN 0 THEN @ActiveProjectID
			WHEN 1 THEN @NotActiveProjectID
			END	

	SELECT 
		@EmployeeID = [ID]
	FROM 
		[Employee] 
	WHERE 
		([Employee].[ID] = @EmployeeID) OR
		(@EmployeeID IS NULL AND [UserID] = dbo.adfGetCurrentUserID())
	
	EXECUTE ReportTimesheetOfProjectHeader @EmployeeID, @WeekStart, @NextDate, @ProjectID

	SELECT
	[Task].[FileAs] AS [TaskName],
			
	SUM(CASE WHEN DATEPART(WEEKDAY,[TimeEntry].[StartTime]) = 1
				 THEN [TimeEntry].[BillableDuration] * [TimeEntry].[Billable] / 60.0
				ELSE 0 END) AS [Calculation1],
	SUM(CASE WHEN DATEPART(WEEKDAY,[TimeEntry].[StartTime]) = 1 AND [TimeEntry].[Overtime] = 1
				 THEN [TimeEntry].[BillableDuration] * [TimeEntry].[Billable] / 60.0
				ELSE 0 END) AS [Overtime1],							
	
	SUM(CASE WHEN DATEPART(WEEKDAY,[TimeEntry].[StartTime]) = 2
				 THEN [TimeEntry].[BillableDuration] * [TimeEntry].[Billable] / 60.0
				ELSE 0 END) AS [Calculation2],
	SUM(CASE WHEN DATEPART(WEEKDAY,[TimeEntry].[StartTime]) = 2 AND [TimeEntry].[Overtime] = 1
				 THEN [TimeEntry].[BillableDuration] * [TimeEntry].[Billable] / 60.0
				ELSE 0 END) AS [Overtime2],
			
	SUM(CASE WHEN DATEPART(WEEKDAY,[TimeEntry].[StartTime]) = 3
				 THEN [TimeEntry].[BillableDuration] * [TimeEntry].[Billable] / 60.0
				ELSE 0 END) AS [Calculation3],
	SUM(CASE WHEN DATEPART(WEEKDAY,[TimeEntry].[StartTime]) = 3 AND [TimeEntry].[Overtime] = 1
				 THEN [TimeEntry].[BillableDuration] * [TimeEntry].[Billable] / 60.0
				ELSE 0 END) AS [Overtime3],
				
	SUM(CASE WHEN DATEPART(WEEKDAY,[TimeEntry].[StartTime]) = 4
				 THEN [TimeEntry].[BillableDuration] * [TimeEntry].[Billable] / 60.0
				ELSE 0 END) AS [Calculation4],
	SUM(CASE WHEN DATEPART(WEEKDAY,[TimeEntry].[StartTime]) = 4 AND [TimeEntry].[Overtime] = 1
				 THEN [TimeEntry].[BillableDuration] * [TimeEntry].[Billable] / 60.0
				ELSE 0 END) AS [Overtime4],
			
	SUM(CASE WHEN DATEPART(WEEKDAY,[TimeEntry].[StartTime]) = 5
				 THEN [TimeEntry].[BillableDuration] * [TimeEntry].[Billable] / 60.0
				ELSE 0 END) AS [Calculation5],
	SUM(CASE WHEN DATEPART(WEEKDAY,[TimeEntry].[StartTime]) = 5 AND [TimeEntry].[Overtime] = 1
				 THEN [TimeEntry].[BillableDuration] * [TimeEntry].[Billable] / 60.0
				ELSE 0 END) AS [Overtime5],
			
	SUM(CASE WHEN DATEPART(WEEKDAY,[TimeEntry].[StartTime]) = 6
				 THEN [TimeEntry].[BillableDuration] * [TimeEntry].[Billable] / 60.0
				ELSE 0 END) AS [Calculation6],
	SUM(CASE WHEN DATEPART(WEEKDAY,[TimeEntry].[StartTime]) = 6 AND [TimeEntry].[Overtime] = 1
				 THEN [TimeEntry].[BillableDuration] * [TimeEntry].[Billable] / 60.0
				ELSE 0 END) AS [Overtime6],
				
	SUM(CASE WHEN DATEPART(WEEKDAY,[TimeEntry].[StartTime]) = 7
				 THEN [TimeEntry].[BillableDuration] * [TimeEntry].[Billable] / 60.0
				ELSE 0 END) AS [Calculation7],
	SUM(CASE WHEN DATEPART(WEEKDAY,[TimeEntry].[StartTime]) = 7 AND [TimeEntry].[Overtime] = 1
				 THEN [TimeEntry].[BillableDuration] * [TimeEntry].[Billable] / 60.0
				ELSE 0 END) AS [Overtime7]			
	
	FROM
		[vwTimeEntry] as [TimeEntry]
		LEFT OUTER JOIN [Task]
			ON [TimeEntry].[TaskID] = [Task].[ID]	 
		
	WHERE
		[TimeEntry].[EmployeeID] = @EmployeeID AND
		[TimeEntry].[ProjectID] = @ProjectID AND
		([TimeEntry].[StartTime] >= @WeekStart AND [TimeEntry].[StartTime] < @NextDate)
		 AND [TimeEntry].[State]in(3,6)
		
	GROUP BY
		[Task].[FileAs]
		

RETURN 0
GO

GRANT EXEC ON ReportTimesheetOfProject TO PUBLIC

GO
