IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'VistaWordCalculationPhoneCall')
	BEGIN
		PRINT 'Dropping Procedure VistaWordCalculationPhoneCall'
		DROP  Procedure  VistaWordCalculationPhoneCall
	END

GO

PRINT 'Creating Procedure VistaWordCalculationPhoneCall'
GO

CREATE Procedure VistaWordCalculationPhoneCall
	@ID int,
	@Language TName = NULL
AS
	SET NOCOUNT ON
	
	DECLARE
		@phoneClass TClass,
		@calculationClass TClass,
		@DocumentCalculationClass TClass,
		@TotalLines	decimal(18,2),
		@Total money,
		@TotalLinesVAT money,
		@VATRate decimal(18,4),
		@VATRateCount int,
		@VATIsIncluded TBool,
		@Code TName,
		@ApplyVAT TBool,
		@RatesWithVAT TBool

	SET	@phoneClass = dbo.adfGetClassByName('Pjm5.PhoneCall')
	SET	@calculationClass = dbo.adfGetClassByName('Pjm5.Calculation')
	
	SELECT
		@DocumentCalculationClass = [Calculation].[DocumentClass],
		@ApplyVAT = [Project].[ApplyVAT],
		@RatesWithVAT = [Project].[RatesWithVAT],
		@VATRate = [Calculation].[VATRate]
	FROM
		[Calculation]
		INNER JOIN [Project]
			ON [Project].[ID] = [Calculation].[ProjectID]
	WHERE
		[Calculation].[ID] = @ID
		
	SET @VATIsIncluded = 0
	
	DECLARE @t TABLE(
		[ID] TIdentifier,
		[Date] Tdate,
		[EmployeeID] TIdentifier,
		[EmployeeInitials] TCode,
		[PhoneCodeID] TIdentifier,
		[PhoneCode] TCode,		
		[PhoneCodeFileAs] TName,
		[ExpenseFileAs] TNotes,
		[Price] Tmoney,
		[Amount] TAmount,
		[Total] Tmoney,
		[VAT] Tmoney
	)
	
		INSERT INTO @t
			([ID], 
			[Date],
			[EmployeeID],
			[EmployeeInitials],
			[PhoneCodeID],
			[PhoneCode],
			[PhoneCodeFileAs],
			[ExpenseFileAs],
			[Price],
			[Amount],
			[Total],
			[VAT])
		SELECT
			[CalculationLine].[ID],
			[Expense].[Date],
			[Employee].[ID],
			[Employee].[Initials],
			[PhoneCallCode].[ID],
			[PhoneCallCode].[Code],
			[PhoneCallCode].[FileAs],
			[CalculationLine].[Description],
			
			CASE 
				WHEN [CalculationLine].[VATIsIncluded] = 1 AND [CalculationLine].[Amount] != 0
					THEN ([CalculationLine].[Amount] * [CalculationLine].[Price] - [CalculationLine].[VAT]) / [CalculationLine].[Amount]
				ELSE [CalculationLine].[Price]
			END,
			[CalculationLine].[Amount],
			CASE 
				WHEN [CalculationLine].[VATIsIncluded] = 1 AND @ApplyVAT!= 1
					THEN ([CalculationLine].[Amount] * [CalculationLine].[Price] - [CalculationLine].[VAT])
				ELSE [CalculationLine].[Amount] * [CalculationLine].[Price]				
			END,
			[CalculationLine].[VAT]
		FROM
			[CalculationLine]
			INNER JOIN [Expense]
				ON [Expense].[Class] = [CalculationLine].[DocumentClass] AND
					[Expense].[ID] = [CalculationLine].[DocumentID]
			INNER JOIN [Employee]	
				ON [Employee].[ID] = [Expense].[EmployeeID]
			INNER JOIN [PhoneCall]
				ON [Expense].[ID] = [PhoneCall].[ExpenseID]
			INNER JOIN [PhoneCallCode]
				ON [PhoneCallCode].[ID] = [PhoneCall].[PhoneCallCodeID]
		WHERE 
			[CalculationLine].[CalculationID] = @ID

		SELECT @Total = SUM(ROUND([Total], 2)) FROM @t				
		IF @RatesWithVAT = 0
		BEGIN
			SET @TotalLines = @Total
			SET @TotalLinesVAT = ROUND(@Total * @VATRate * @ApplyVAT, 2)
		END
		ELSE
		BEGIN
			SET @TotalLines = ROUND(@Total / (1 + @VATRate * @ApplyVAT), 2)
			SET @TotalLinesVAT = @Total - @TotalLines
		END
		
	DECLARE @AdvanceFlag TBool
	IF EXISTS(SELECT * FROM [CalculationAdvance] WHERE [CalculationID] = @ID)
		SET @AdvanceFlag = 1
	ELSE
		SET @AdvanceFlag = 0
		
	SELECT
		[Calculation].[ID],
		[Calculation].[Number],
		[Calculation].[Date],
		[Calculation].[FileAs],
		[Calculation].[PeriodStart],
		[Calculation].[PeriodEnd],

		[Calculation].[ProjectID],
		[Project].[FileAs] AS [ProjectFileAs],
		[Project].[Number] AS [ProjectNumber],
		[Project].[ContractNumber] AS [ContractNumber],
		[Project].[ContractDate] AS [ContractDate],
		[Project].[SupplierCompanyID],
		[Project].[CustomerCompanyID],
		
		[CustomerCompany].[LegalName] AS [CustomerCompanyLegalName],
		[SupplierCompany].[LegalName] AS [SupplierCompanyLegalName],
		
		[SupplierCompany].[ExecutiveEmployeeID],
		[SupplierEmployee].[LastName] + 
			ISNULL(' ' + [SupplierEmployee].[FirstName], '') + 
				ISNULL(' ' + [SupplierEmployee].[MiddleName], '') AS [ExecutiveName],
		[SupplierEmployee].[FileAs] AS [ExecutiveFileAs],
		[SupplierEmployeePosition].[ID] AS [ExecutivePositionID],
		[SupplierEmployeePosition].[FileAs] AS [ExecutivePositionFileAs],

		[Calculation].[Total],
		[Calculation].[VATRate] * 100 AS [VATRate],
		[Calculation].[VAT],
		[Calculation].[TotalWithVAT],
		CASE
			WHEN [Project].[ApplyVAT] = 1 THEN @VATIsIncluded
			ELSE 2		 
		END AS [VATFlag],

		@TotalLines AS [TotalLines],
		@TotalLinesVAT AS [TotalLinesVAT],
		@TotalLines + @TotalLinesVAT AS [TotalLinesWithVAT],
		@AdvanceFlag AS [AdvanceFlag],

		[Calculation].[Total] - @TotalLines AS [TotalAdvance],
		[Calculation].[VAT] - @TotalLinesVAT AS [TotalAdvanceVAT],
		[Calculation].[TotalWithVAT] - @TotalLines - @TotalLinesVAT AS [TotalAdvanceWithVAT],
		
		[Currency].[ID] AS [CurrencyID],
		[Currency].[FileAs] AS [CurrencyFileAs],
		[Currency].[Code] AS [CurrencyCode],
		CASE 
			WHEN dbo.adfPropertyValueGetText([Currency].[Class], [Currency].[ID], '00000001-0000-0000-0000-000000000000') = 'False' 
				THEN 0
			ELSE 1 
		END AS [CurrencyMale]
	FROM
		[Calculation]
		INNER JOIN [Project]
			ON [Calculation].[ProjectID] = [Project].[ID]
		INNER JOIN [Currency]
			ON [Calculation].[CurrencyCode] = [Currency].[Code]
		LEFT OUTER JOIN [Company] AS [CustomerCompany]	
			ON [Project].[CustomerCompanyID] = [CustomerCompany].[ID]
		LEFT OUTER JOIN [Company] AS [SupplierCompany]	
			ON [Project].[SupplierCompanyID] = [SupplierCompany].[ID]
		LEFT OUTER JOIN [Employee] AS [SupplierEmployee]
			ON [SupplierCompany].[ExecutiveEmployeeID] = [SupplierEmployee].[ID]
		LEFT OUTER JOIN [Position] AS [SupplierEmployeePosition]
			ON [SupplierEmployee].[PositionID] = [SupplierEmployeePosition].[ID]
	WHERE 
		[Calculation].[ID] = @ID	
		
	SELECT
		[ID], 
		[Date],
		[EmployeeID],
		[EmployeeInitials],
		[PhoneCode],
		[PhoneCodeFileAs],
		[ExpenseFileAs],
		[Price],
		[Amount],
		[Total],
		[VAT]
	FROM @t
	ORDER BY [Date]
	
	SELECT
		[PhoneCode],
		[PhoneCodeFileAs],
		[Price],
		SUM([Amount]) AS [TotalAmount],
		SUM([Total]) AS [TotalPrice],
		[PhoneCodeID]
	FROM @t
	GROUP BY [PhoneCode],
			[PhoneCodeID],
			[PhoneCodeFileAs],
			[Price]
	DECLARE @author TName
	SELECT @author = [FileAs] FROM [Employee] WHERE [ID] = dbo.adfGetCurrentEmployeeID()
	SELECT
      [Calculation].[FileAs] AS [Title],
      [Project].[FileAs] AS [Subject],
      @author AS [Author],
      [Employee].[FileAs] AS [Manager],
      [Company].[FileAs] AS [Company],
      dbo.fnPjm5GetCategoryList(@ID, @calculationClass) AS [Category],
      @Code + [Project].[Number] AS [Keywords]
     FROM
		[Calculation]
		INNER JOIN [Project]
			ON [Calculation].[ProjectID] = [Project].[ID]
		INNER JOIN [Company]
			ON [Project].[SupplierCompanyID] = [Company].[ID]
		INNER JOIN [Employee]
			ON [Employee].[ID] = [Project].[ProjectManagerEmployeeID]
     WHERE
		[Calculation].[ID] = @ID
	
	RETURN 0
GO

GRANT EXEC ON VistaWordCalculationPhoneCall TO PUBLIC
GO


