IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'VistaWordRequestInvoice')
	BEGIN
		PRINT 'Dropping Procedure VistaWordRequestInvoice'
		DROP  Procedure  VistaWordRequestInvoice
	END

GO

PRINT 'Creating Procedure VistaWordRequestInvoice'
GO

CREATE Procedure VistaWordRequestInvoice
	@ID int,
	@Language Tname = NULL	
AS
	SET NOCOUNT ON
	DECLARE
		@Total money,
		@TotalWithVAT money,
		@VAT money	,
		@VATRate decimal(18,4),
		@VATRateCount int,
		@Currency TName,
		@AdvanceValue TMoney,
		@AdvanceValueWithoutVAT TMoney,
		@AdvanceVAT TMoney,
		@PaymentValue TMoney,
		@PaymentVAT TMoney,
		@RemainValue TMoney,
		@RemainVAT TMoney,
		@Class TClass,
		@ApplyVAT TBool,
		@Code TName,
		@CompanyClass TClass,
		@EmployeeClass TClass,
		@ProjectID TIdentifier,
		@ContactID TIdentifier,
		@SupplierID TIdentifier,
		@CustomerID TIdentifier,
		@CurrencyCode TCode,
		@OfferRu nvarchar(2000),
		@OfferEn nvarchar(2000),
		@CurrencyRate TMoney
		
	SET @CompanyClass = dbo.adfGetClassByName('Adf.Company')
	SET @EmployeeClass = dbo.adfGetClassByName('Adf.Employee')
	SET @Code = CASE WHEN @Language = 'en' THEN 'Invoice; ' ELSE '; ' END	
	SELECT
		@VATRate = MAX([Calculation].[VATRate]),
		@VATRateCount = COUNT(DISTINCT [Calculation].[VATRate])
	FROM
		[InvoiceLine]
			INNER JOIN [Calculation]
				ON  [Calculation].[ID] = [InvoiceLine].[DocumentID] AND
						[Calculation].[Class] = [InvoiceLine].[DocumentClass]
	WHERE [InvoiceLine].[InvoiceID]=@ID
	
	SELECT
		@ProjectID = [Project].[ID],
		@ContactID = [Project].[ResponsiblePersonEmployeeID],
		@Currency = CASE [Project].[InvoiceCurrency] WHEN 0 THEN 'Project' ELSE 'Payment' END,
		@CurrencyCode = CASE [Project].[InvoiceCurrency] WHEN 0 THEN [Project].[CurrencyCode] ELSE [Invoice].[CurrencyCode] END,
		@Class = [Invoice].[Class],
		@Total = CASE [Project].[InvoiceCurrency]
			WHEN 0 THEN [Invoice].[TotalPC]
			ELSE [Invoice].[Total]
		END,
		@VAT = CASE [Project].[InvoiceCurrency]
			WHEN 0 THEN [Invoice].[VATPC]
			ELSE [Invoice].[VAT]
		END,
		@TotalWithVAT = CASE [Project].[InvoiceCurrency]
			WHEN 0 THEN [Invoice].[TotalWithVATPC]
			ELSE [Invoice].[TotalWithVAT]
		END,
		@ApplyVAT = [Project].[ApplyVAT],
		@CurrencyRate = [Invoice].[CurrencyRate],
		@SupplierID = [Invoice].[SupplierCompanyID],
		@CustomerID = [Invoice].[CustomerCompanyID]
	FROM
		[Invoice]
		INNER JOIN [Project]
			ON [Invoice].[ProjectID] = [Project].[ID]
	WHERE
		[Invoice].[ID] = @ID	
		
	SELECT 
		@AdvanceValue = SUM(ISNULL(
			CASE
				WHEN @Currency = 'Payment'
					THEN [Invoice].[TotalWithVAT]
				WHEN @Currency = 'Project'
					THEN [Invoice].[TotalWithVATPC]
			END, 0.0)),
		@AdvanceVAT = SUM(ISNULL(
			CASE
				WHEN @Currency = 'Payment'
					THEN [Invoice].[VAT]
				WHEN @Currency = 'Project'
					THEN [Invoice].[VATPC]
			END, 0.0)),
		@AdvanceValueWithoutVAT = SUM(ISNULL(
			CASE
				WHEN @Currency = 'Payment'
					THEN [Invoice].[Total]
				WHEN @Currency = 'Project'
					THEN [Invoice].[TotalPC]
			END, 0.0))
	FROM
		[AdvanceInvoice] 
		INNER JOIN [Invoice]
			ON [Invoice].[ID] = [AdvanceInvoice].[AdvanceInvoiceID]
	WHERE
		[AdvanceInvoice].[InvoiceID] = @ID
	
		
	SELECT 
		@PaymentValue = SUM(ISNULL(
			CASE
				WHEN @Currency = 'Payment'
					THEN [PaymentDetail].[PaymentValue]
				WHEN @Currency = 'Project'
					THEN [PaymentDetail].[Value]
			END, 0.0))
	FROM
		[AdvanceInvoice] 
		INNER JOIN [Invoice]
			ON [Invoice].[ID] = [AdvanceInvoice].[AdvanceInvoiceID]
		INNER JOIN [PaymentDetail]
			ON [PaymentDetail].[InvoiceID] = [Invoice].[ID]
	WHERE
		[AdvanceInvoice].[InvoiceID] = @ID
	
	SET @PaymentValue = ISNULL(@PaymentValue, 0)
	
	SET @RemainValue =
		CASE 
			WHEN @TotalWithVAT > ISNULL(@AdvanceValue, 0.0) THEN @TotalWithVAT - ISNULL(@AdvanceValue, 0.0) 
			ELSE 0.0
		END
	SET @RemainVAT =
		CASE
			WHEN @VAT > ISNULL(@AdvanceVAT, 0.0) THEN @VAT - ISNULL(@AdvanceVAT, 0.0) 
			ELSE 0.0
		END

	SELECT
		[Invoice].[ID],
		[Invoice].[FileAs],
		[Invoice].[Number],
		[Invoice].[Date],
		[Invoice].[DueDate],
		(CASE WHEN [Invoice].[InvoiceExpirationPeriodType] = 1 THEN
			dbo.fnPjm5GetWorkingDays([Invoice].[Date], [Invoice].[DueDate]) 
		ELSE
			DATEDIFF(day, [Invoice].[Date], [Invoice].[DueDate]) + 1
		END) AS [ExpirationPeriod],
		[Invoice].[InvoiceExpirationPeriodType] as [ExpirationPeriodType],
		
		[Invoice].[ProjectID],
		[Project].[FileAs] AS [ProjectFileAs],
		[Project].[Number] AS [ProjectNumber],
		[Project].[ContractNumber] AS [ContractNumber],
		[Project].[ContractDate] AS [ContractDate],
		[Invoice].[SupplierCompanyID],
		[Invoice].[CustomerCompanyID],

		[BankAccount].[ID] AS [BankAccountID],
		[BankAccount].[BankName] AS [BankName],
		[BankAccount].[IntermediaryBank] AS [SBankName],
		[BankAccount].[City] AS [BankCity],
		[BankAccount].[BankCode] AS [BankCode],
		[BankAccount].[Account] AS [CAccount],
		[BankAccount].[IntermediaryAccount] AS [SAccount],
		[BankAccount].[IntermediarySWIFT] AS [IntermediarySWIFT],

		[CustomerCompany].[LegalName] AS [CustomerCompanyLegalName],
		[SupplierCompany].[LegalName] AS [SupplierCompanyLegalName],

		[SupplierCompany].[LegalCode] AS [SupplierCompanyLegalCode],
		[SupplierCompany].[KPP] AS [SupplierCompanyKPP],

		[CustomerCompany].[LegalCode] AS [CustomerCompanyLegalCode],
		[CustomerCompany].[KPP] AS [CustomerCompanyKPP],

		[CustomerCompany].[ExecutiveEmployeeID] AS [CustomerExecutiveEmployeeID],
		[CustomerExecutive].[LastName] + 
			ISNULL(' ' + [CustomerExecutive].[FirstName], '') + 
				ISNULL(' ' + [CustomerExecutive].[MiddleName], '') AS [CustomerExecutiveName],
		[CustomerExecutive].[FileAs] AS [CustomerExecutiveFileAs],
		[CustomerExecutivePosition].[ID] AS [CustomerExecutivePositionID],
		[CustomerExecutivePosition].[FileAs] AS [CustomerExecutivePositionFileAs],

		[CustomerContact].[ID] AS [CustomerContactEmployeeID],
		[CustomerContact].[LastName] + 
			ISNULL(' ' + [CustomerContact].[FirstName], '') + 
				ISNULL(' ' + [CustomerContact].[MiddleName], '') AS [CustomerContactName],
		[CustomerContact].[FileAs] AS [CustomerContactFileAs],
		[CustomerContactPosition].[ID] AS [CustomerContactPositionID],
		[CustomerContactPosition].[FileAs] AS [CustomerContactPositionFileAs],

		[SupplierCompany].[ExecutiveEmployeeID] AS [SupplierExecutiveEmployeeID],
		[SupplierExecutive].[LastName] + 
			ISNULL(' ' + [SupplierExecutive].[FirstName], '') + 
				ISNULL(' ' + [SupplierExecutive].[MiddleName], '') AS [SupplierExecutiveName],
		[SupplierExecutive].[FileAs] AS [SupplierExecutiveFileAs],
		[SupplierExecutivePosition].[ID] AS [SupplierExecutivePositionID],
		[SupplierExecutivePosition].[FileAs] AS [SupplierExecutivePositionFileAs],

		[SupplierCompany].[AccountantEmployeeID] AS [SupplierAccountantEmployeeID],
		[SupplierAccountant].[LastName] + 
			ISNULL(' ' + [SupplierAccountant].[FirstName], '') + 
				ISNULL(' ' + [SupplierAccountant].[MiddleName], '') AS [SupplierAccountantName],
		[SupplierAccountant].[FileAs] AS [SupplierAccountantFileAs],
		[SupplierAccountantPosition].[ID] AS [SupplierAccountantPositionID],
		[SupplierAccountantPosition].[FileAs] AS [SupplierAccountantPositionFileAs],

		@Total AS [Total],
		@VAT - ISNULL(@AdvanceVAT, 0) AS [VAT],
		CASE
			WHEN [Project].[ApplyVAT] = 0 THEN @Total
			ELSE @Total + @VAT
		END - ISNULL(@AdvanceValue, 0) AS [TotalWithVAT],
		CASE
			WHEN @Total IS NULL THEN 0
			ELSE 1
		END	AS [TotalFlag],
		
		dbo.fnPjm5CurrencyToString(@Total, @CurrencyCode) AS [TotalCurrencyCode],
		dbo.fnPjm5CurrencyToString(@VAT, @CurrencyCode) AS [VATCurrencyCode],
		CASE
			WHEN [Project].[ApplyVAT] = 0 THEN dbo.fnPjm5CurrencyToString(@Total, @CurrencyCode)
			ELSE dbo.fnPjm5CurrencyToString((@Total + @VAT), @CurrencyCode)
		END AS [TotalWithVATCurrencyCode],

		@AdvanceValue AS [AdvanceValue],
		@AdvanceVAT AS [AdvanceVAT],
		@AdvanceValueWithoutVAT AS [AdvanceValueWithoutVAT],
		CASE
			WHEN ISNULL(@AdvanceValue, 0.0) = 0 THEN 0
			ELSE 1 
		END	AS [AdvanceFlag],
		dbo.fnPjm5CurrencyToString(@AdvanceValue, @CurrencyCode) AS [AdvanceValueCurrencyCode],
		dbo.fnPjm5CurrencyToString(@AdvanceVAT, @CurrencyCode) AS [AdvanceVATCurrencyCode],

		@PaymentValue AS [PaymentValue],
		@PaymentVAT AS [PaymentVAT],
		CASE
			WHEN ISNULL(@PaymentValue, 0.0) = 0 THEN 0
			ELSE 1 
		END	AS [PaymentFlag],
		dbo.fnPjm5CurrencyToString(ISNULL(@PaymentValue, 0.0), @CurrencyCode) AS [PaymentValueCurrencyCode],
		dbo.fnPjm5CurrencyToString(ISNULL(@PaymentVAT, 0.0), @CurrencyCode) AS [PaymentVATCurrencyCode],

		@RemainValue AS [RemainValue],
		@RemainVAT AS [RemainVAT],
		CASE
			WHEN ISNULL(@RemainValue, 0.0) = 0 THEN 0
			ELSE 1
		END	AS [RemainFlag],
		dbo.fnPjm5CurrencyToString(@RemainValue, @CurrencyCode) AS [RemainValueCurrencyCode],
		dbo.fnPjm5CurrencyToString(@RemainVAT, @CurrencyCode) AS [RemainVATCurrencyCode],
		CASE
			WHEN [Project].[ApplyVAT] = 0 THEN 0
			WHEN [Project].[ApplyVAT] = 1 AND @VATRateCount = 1 THEN (@VATRate * 100)
			ELSE NULL
		END AS [VATRate],
		CASE
			WHEN [Project].[ApplyVAT] = 1 AND @VATRateCount = 1 THEN 1
			ELSE 0
		END AS [VATFlag],
		CASE
			WHEN [Project].[ApplyVAT] = 0 THEN 0
			ELSE 1
		END	AS [VATRateFlag],	

		CASE @Currency WHEN 'Payment' THEN [Currency].[ID] ELSE [ProjectCurrency].[ID] END AS [CurrencyID],
		CASE @Currency WHEN 'Payment' THEN [Currency].[FileAs] ELSE [ProjectCurrency].[FileAs] END AS [CurrencyFileAs],
		CASE @Currency WHEN 'Payment' THEN [Currency].[Code] ELSE [ProjectCurrency].[Code] END AS [CurrencyCode],
		CASE 
			WHEN @Currency = 'Payment' AND
				dbo.adfPropertyValueGetText([Currency].[Class], [Currency].[ID], '00000001-0000-0000-0000-000000000000') = 'False' 
				THEN 0
			WHEN @Currency != 'Payment' AND
				dbo.adfPropertyValueGetText([ProjectCurrency].[Class], [ProjectCurrency].[ID], '00000001-0000-0000-0000-000000000000') = 'False' 
				THEN 0
			ELSE 1 
		END AS [CurrencyMale],
		[Invoice].[CurrencyCode] AS [InvoiceCurrency]		
	FROM
		[Invoice]
		INNER JOIN [Project]
			ON [Invoice].[ProjectID] = [Project].[ID]
		INNER JOIN [Currency]
			ON [Invoice].[CurrencyCode] = [Currency].[Code]
		INNER JOIN [Currency] AS [InvoiceCurrency]
			ON [Invoice].[CurrencyCode] = [InvoiceCurrency].[Code]
		INNER JOIN [Currency] AS [ProjectCurrency]
			ON [Project].[CurrencyCode] = [ProjectCurrency].[Code]
						
		INNER JOIN [Company] AS [SupplierCompany]	
			ON [Invoice].[SupplierCompanyID] = [SupplierCompany].[ID]
		INNER JOIN [Company] AS [CustomerCompany]	
			ON [Invoice].[CustomerCompanyID] = [CustomerCompany].[ID]
			
		LEFT OUTER JOIN [Employee] AS [SupplierExecutive]
			ON [SupplierCompany].[ExecutiveEmployeeID] = [SupplierExecutive].[ID]
		LEFT OUTER JOIN [Position] AS [SupplierExecutivePosition]
			ON [SupplierExecutive].[PositionID] = [SupplierExecutivePosition].[ID]

		LEFT OUTER JOIN [Employee] AS [SupplierAccountant]
			ON [SupplierCompany].[AccountantEmployeeID] = [SupplierAccountant].[ID]
		LEFT OUTER JOIN [Position] AS [SupplierAccountantPosition]
			ON [SupplierAccountant].[PositionID] = [SupplierAccountantPosition].[ID]

		LEFT OUTER JOIN [Employee] AS [CustomerExecutive]
			ON [CustomerCompany].[ExecutiveEmployeeID] = [CustomerExecutive].[ID]
		LEFT OUTER JOIN [Position] AS [CustomerExecutivePosition]
			ON [CustomerExecutive].[PositionID] = [CustomerExecutivePosition].[ID]

		LEFT OUTER JOIN [Employee] AS [CustomerContact]
			ON [Project].[ResponsiblePersonEmployeeID] = [CustomerContact].[ID]
		LEFT OUTER JOIN [Position] AS [CustomerContactPosition]
			ON [CustomerContact].[PositionID] = [CustomerContactPosition].[ID]

		LEFT OUTER JOIN [BankAccount]
			ON [Invoice].[SupplierBankAccountID] = [BankAccount].[ID]
	WHERE 
		[Invoice].[ID] = @ID		

	IF @Currency = 'Payment'
	BEGIN
		SELECT
			[ServiceRequest].[Number],
			[ServiceRequestLine].[FactAmount],
			@CurrencyRate*
			[ServiceRequestLine].[Price] AS [Price],
			@CurrencyRate*
			[ServiceRequestLine].[FactAmount] * [ServiceRequestLine].[Price] AS [Total],
			COALESCE(
				dbo.adfPropertyValueGetTextByName([InvoiceLine].[DocumentClass], [InvoiceLine].[DocumentID], 
					'    '),
				dbo.adfPropertyValueGetTextByName([Service].[Class], [Service].[ID], 
					'    '),
				[Service].[FileAs]) AS [ServiceName],
			COALESCE(
				dbo.adfPropertyValueGetText([InvoiceLine].[DocumentClass], [InvoiceLine].[DocumentID],
					'00000001-0000-0000-0000-000000000000'),
				 dbo.adfPropertyValueGetText([Service].[Class],[Service].[ID],
					'00000001-0000-0000-0000-000000000000'),[Service].[FileAs]) AS 	[ServiceNameOtherLang],
			ISNULL([ServiceRequestLine].[Description], [ServiceRequest].[FileAs]) AS [Description]
		FROM
			[InvoiceLine]
			INNER JOIN [Calculation]	
				ON [Calculation].[ID] = [InvoiceLine].[DocumentID] AND
					[Calculation].[Class] = [InvoiceLine].[DocumentClass]	
			INNER JOIN [CalculationLine]
				ON [CalculationLine].[CalculationID]=[Calculation].[ID]
			INNER JOIN [ServiceRequest]
				ON [ServiceRequest].[ID] = [CalculationLine].[DocumentID] AND
					[ServiceRequest].[Class] = [CalculationLine].[DocumentClass]	
			INNER JOIN [ServiceRequestLine]	
				ON [ServiceRequestLine].[ServiceRequestID] = [ServiceRequest].[ID]
			INNER JOIN [ServiceAssignment]
				ON [ServiceAssignment].[ID] = [ServiceRequestLine].[ServiceAssignmentID]
			INNER JOIN [Service]
				ON [Service].[ID] = [ServiceAssignment].[ServiceID]					
		WHERE 
			[InvoiceLine].[InvoiceID] = @ID	
	
	SELECT 
		[TimeEntry].[ActivityTypeID] AS [ID],
		[TimeEntry].[FileAs] AS [FileAs],
		@CurrencyRate*
		CASE 
			WHEN [CalculationLine].[VATIsIncluded] = 1 AND @ApplyVAT!= 1
				THEN ([CalculationLine].[Amount] * [CalculationLine].[Price] - [CalculationLine].[VAT])
			ELSE [CalculationLine].[Amount] * [CalculationLine].[Price]				
		END AS [Total]
	FROM
		[InvoiceLine]
		INNER JOIN [Calculation]
			ON  [Calculation].[ID] = [InvoiceLine].[DocumentID] AND
					[Calculation].[Class] = [InvoiceLine].[DocumentClass]
		INNER JOIN [CalculationLine]
			ON [CalculationLine].[CalculationID]=[Calculation].[ID]
		INNER JOIN [TimeEntry]
			ON [CalculationLine].[DocumentClass]=[TimeEntry].[Class] AND
				[CalculationLine].[DocumentID]=[TimeEntry].[ID]
	WHERE 
		[InvoiceLine].[InvoiceID] = @ID	
	
	SELECT
		[ExpenseCode].[ID] AS [ID],
		[Expense].[FileAs] AS [FileAs],
		CASE WHEN [Expense].[FromCurrencyCode]=@CurrencyCode THEN ([Expense].[Price]*[Expense].[Amount]-[Expense].[VAT])
		ELSE @CurrencyRate*[Expense].[TotalPC] END AS [Total]
	FROM
		[InvoiceLine]
			INNER JOIN [Calculation]
				ON  [Calculation].[ID] = [InvoiceLine].[DocumentID] AND
						[Calculation].[Class] = [InvoiceLine].[DocumentClass]
			INNER JOIN [CalculationLine]
				ON [CalculationLine].[CalculationID]=[Calculation].[ID]
			INNER JOIN [Expense]
				ON [CalculationLine].[DocumentClass]=[Expense].[Class] AND
					[CalculationLine].[DocumentID]=[Expense].[ID]
			INNER JOIN [Expensecode]
				ON [ExpenseCode].[ID] = [Expense].[ExpenseCodeID] AND
					[ExpenseCode].[ID]!=1
	WHERE 
		[InvoiceLine].[InvoiceID] = @ID	
			
			
	SELECT
		[PhoneCallCode].[ID] AS [ID],
		[PhoneCall].[FileAs] AS [FileAs],
		@CurrencyRate*
		CASE 
			WHEN [CalculationLine].[VATIsIncluded] = 1 AND @ApplyVAT!= 1
				THEN ([CalculationLine].[Amount] * [CalculationLine].[Price] - [CalculationLine].[VAT])
			ELSE [CalculationLine].[Amount] * [CalculationLine].[Price]				
		END AS [Total]
	FROM
		[InvoiceLine]
		INNER JOIN [Calculation]
			ON  [Calculation].[ID] = [InvoiceLine].[DocumentID] AND
					[Calculation].[Class] = [InvoiceLine].[DocumentClass]
		INNER JOIN [CalculationLine]
			ON [CalculationLine].[CalculationID]=[Calculation].[ID]
		INNER JOIN [Expense]
				ON [CalculationLine].[DocumentClass]=[Expense].[Class] AND
					[CalculationLine].[DocumentID]=[Expense].[ID]
		INNER JOIN [PhoneCall]
			ON [Expense].[ID]=[PhoneCall].[ExpenseID]
		INNER JOIN [PhoneCallCode]
			ON [PhoneCallCode].[ID]=[PhoneCall].[PhoneCallCodeID]
	WHERE 
			[InvoiceLine].[InvoiceID] = @ID	
	END
	ELSE
	BEGIN
		SELECT
			[ServiceRequest].[Number],
			[ServiceRequestLine].[FactAmount],
			[ServiceRequestLine].[Price] AS [Price],
			[ServiceRequestLine].[FactAmount] * [ServiceRequestLine].[Price] AS [Total],
			COALESCE(
				dbo.adfPropertyValueGetTextByName([InvoiceLine].[DocumentClass], [InvoiceLine].[DocumentID], 
					'    '),
				dbo.adfPropertyValueGetTextByName([Service].[Class], [Service].[ID], 
					'    '),
				[Service].[FileAs]) AS [ServiceName],
			COALESCE(
				dbo.adfPropertyValueGetText([InvoiceLine].[DocumentClass], [InvoiceLine].[DocumentID],
					'00000001-0000-0000-0000-000000000000'),
				 dbo.adfPropertyValueGetText([Service].[Class],[Service].[ID],
					'00000001-0000-0000-0000-000000000000'),[Service].[FileAs])	AS [ServiceNameOtherLang],
			ISNULL([ServiceRequestLine].[Description], [ServiceRequest].[FileAs]) AS [Description]
		FROM
			[InvoiceLine]
			INNER JOIN [Calculation]	
				ON [Calculation].[ID] = [InvoiceLine].[DocumentID] AND
					[Calculation].[Class] = [InvoiceLine].[DocumentClass]	
			INNER JOIN [CalculationLine]
				ON [CalculationLine].[CalculationID]=[Calculation].[ID]
			INNER JOIN [ServiceRequest]
				ON [ServiceRequest].[ID] = [CalculationLine].[DocumentID] AND
					[ServiceRequest].[Class] = [CalculationLine].[DocumentClass]	
			INNER JOIN [ServiceRequestLine]	
				ON [ServiceRequestLine].[ServiceRequestID] = [ServiceRequest].[ID]
			INNER JOIN [ServiceAssignment]
				ON [ServiceAssignment].[ID] = [ServiceRequestLine].[ServiceAssignmentID]
			INNER JOIN [Service]
				ON [Service].[ID] = [ServiceAssignment].[ServiceID]					
		WHERE 
			[InvoiceLine].[InvoiceID] = @ID	
	
	SELECT 
		[TimeEntry].[ActivityTypeID] AS [ID],
		[TimeEntry].[FileAs] AS [FileAs],
		CASE 
				WHEN [CalculationLine].[VATIsIncluded] = 1 AND @ApplyVAT!= 1
					THEN ([CalculationLine].[Amount] * [CalculationLine].[Price] - [CalculationLine].[VAT])
				ELSE [CalculationLine].[Amount] * [CalculationLine].[Price]				
		END AS [Total]
	FROM
			[InvoiceLine]
			INNER JOIN [Calculation]
				ON  [Calculation].[ID] = [InvoiceLine].[DocumentID] AND
						[Calculation].[Class] = [InvoiceLine].[DocumentClass]
			INNER JOIN [CalculationLine]
				ON [CalculationLine].[CalculationID]=[Calculation].[ID]
			INNER JOIN [TimeEntry]
				ON [CalculationLine].[DocumentClass]=[TimeEntry].[Class] AND
					[CalculationLine].[DocumentID]=[TimeEntry].[ID]
	WHERE 
			[InvoiceLine].[InvoiceID] = @ID		
				
	SELECT
		[ExpenseCode].[ID] AS [ID],
		[Expense].[FileAs] AS [FileAs],
		[Expense].[TotalPC] AS [Total]
	FROM
		[InvoiceLine]
			INNER JOIN [Calculation]
				ON  [Calculation].[ID] = [InvoiceLine].[DocumentID] AND
						[Calculation].[Class] = [InvoiceLine].[DocumentClass]
			INNER JOIN [CalculationLine]
				ON [CalculationLine].[CalculationID]=[Calculation].[ID]
			INNER JOIN [Expense]
						ON [CalculationLine].[DocumentClass]=[Expense].[Class] AND
							[CalculationLine].[DocumentID]=[Expense].[ID]
			INNER JOIN [Expensecode]
						ON [ExpenseCode].[ID] = [Expense].[ExpenseCodeID] AND
							[ExpenseCode].[ID]!=1
	WHERE 
			[InvoiceLine].[InvoiceID] = @ID	
			
		SELECT
		[PhoneCallCode].[ID] AS [ID],
		[PhoneCall].[FileAs] AS [FileAs],
		CASE 
				WHEN [CalculationLine].[VATIsIncluded] = 1 AND @ApplyVAT!= 1
					THEN ([CalculationLine].[Amount] * [CalculationLine].[Price] - [CalculationLine].[VAT])
				ELSE [CalculationLine].[Amount] * [CalculationLine].[Price]				
		END AS [Total]
	FROM
		[InvoiceLine]
		INNER JOIN [Calculation]
			ON  [Calculation].[ID] = [InvoiceLine].[DocumentID] AND
					[Calculation].[Class] = [InvoiceLine].[DocumentClass]
		INNER JOIN [CalculationLine]
			ON [CalculationLine].[CalculationID]=[Calculation].[ID]
		INNER JOIN [Expense]
				ON [CalculationLine].[DocumentClass]=[Expense].[Class] AND
					[CalculationLine].[DocumentID]=[Expense].[ID]
		INNER JOIN [PhoneCall]
			ON [Expense].[ID]=[PhoneCall].[ExpenseID]
		INNER JOIN [PhoneCallCode]
			ON [PhoneCallCode].[ID]=[PhoneCall].[PhoneCallCodeID]
	WHERE 
			[InvoiceLine].[InvoiceID] = @ID	
	END 
		
	DECLARE @author TName
	SELECT @author = [FileAs] FROM [Employee] WHERE [ID] = dbo.adfGetCurrentEmployeeID()
	SELECT
      [Invoice].[FileAs] AS [Title],
      [Project].[FileAs] AS [Subject],
      @author AS [Author],
      [Employee].[FileAs] AS [Manager],
      [Company].[FileAs] AS [Company],
      dbo.fnPjm5GetCategoryList(@ID, @Class) AS [Category],
      @Code + [Project].[Number] AS [Keywords]
     FROM
		[Invoice]
		INNER JOIN [Project]
			ON [Invoice].[ProjectID] = [Project].[ID]
		INNER JOIN [Company]
			ON [Project].[SupplierCompanyID] = [Company].[ID]
		INNER JOIN [Employee]
			ON [Employee].[ID] = [Project].[ProjectManagerEmployeeID]
     WHERE
		[Invoice].[ID] = @ID

		
RETURN 0
GO

GRANT EXEC ON VistaWordRequestInvoice TO PUBLIC

GO
