IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'ReportWordCompany')
	BEGIN
		PRINT 'Dropping Procedure ReportWordCompany'
		DROP  Procedure  ReportWordCompany
	END

GO

PRINT 'Creating Procedure ReportWordCompany'
GO

--------------------------------------------------------------------------------------
-- Copyright (c) 2003 by Avicom
--------------------------------------------------------------------------------------
-- $Archive: $
-- $Author: $
-- $Revision: $
-- $Modtime: $
-- $Date: $
--
-- Description: this stored procedure ...........
-- Input:	.........
-- Output:      0 - success, negative number - otherwise
--
-- Notes:       no
--
--
/* $Log: $ 
   $NoKeywords: $ 
--------------------------------------------------------------------------------------*/
CREATE Procedure ReportWordCompany
	@ID int,
	@Language TName = NULL
AS
	SET NOCOUNT ON
	DECLARE @Class TClass
	SET @Class = dbo.adfGetClassByName('Adf.Company')
	
	SELECT
		[Company].[Class],
		[Company].[ID],
		[Company].[LegalName],
		[Company].[FileAs],
		[Company].[BankAccountID],
		[Company].[CompanySizeID],
		[Company].[CompanyTurnoverID],
		[Company].[KPP],
		[Company].[FoundationDate],
		[Company].[LastContact],
		[Company].[NextContact],
		[Company].[LegalCode],
		[Company].[ExecutiveEmployeeID],
		[Company].[AccountantEmployeeID],
		[Company].[ManagerEmployeeID],
		[Company].[Comments],
		[ExecutiveEmployee].[LastName] + ISNULL(' ' + [ExecutiveEmployee].[FirstName], '') + ISNULL(' ' + [ExecutiveEmployee].[MiddleName], '')
			AS [ExecutiveEmployeeName],
		[AccountantEmployee].[LastName] + ISNULL(' ' + [AccountantEmployee].[FirstName], '') + ISNULL(' ' + [AccountantEmployee].[MiddleName], '')
			AS [AccountantEmployeeName],
		[ManagerEmployee].[LastName] + ISNULL(' ' + [ManagerEmployee].[FirstName], '') + ISNULL(' ' + [ManagerEmployee].[MiddleName], '')
			 AS [ManagerEmployeeName],
		[ExecutiveEmployee].[FileAs] AS [ExecutiveEmployeeFileAs],
		[AccountantEmployee].[FileAs] AS [AccountantEmployeeFileAs],
		[ManagerEmployee].[FileAs] AS [ManagerEmployeeFileAs],
		
		[ExecutiveEmployee].[PositionID] AS [ExecutiveEmployeePositionID],
		[AccountantEmployee].[PositionID] AS [AccountantEmployeePositionID],
		[ManagerEmployee].[PositionID] AS [ManagerEmployeePositionID],
		dbo.fnPjm5GetContactList([Company].[ID], [Company].[Class]) AS [Contacts],
		dbo.fnPjm5GetCategoryList([Company].[ID], [Company].[Class]) AS [Categories],
		dbo.fnPjm5GetIndustryBranchList([Company].[ID]) AS [IndustryBranchList],
		dbo.fnPjm5GetPhoneList([Company].[ID], [Company].[Class]) AS [Phonelist],
		dbo.fnPjm5GetAttachmentList([Company].[ID], [Company].[Class]) AS [AttachmentList]
	FROM
		[Company]
		LEFT OUTER JOIN [Employee] AS [ExecutiveEmployee]
			ON [Company].[ExecutiveEmployeeID] = [ExecutiveEmployee].[ID]
		LEFT OUTER JOIN [Employee] AS [AccountantEmployee]
			ON [Company].[AccountantEmployeeID] = [AccountantEmployee].[ID]
		LEFT OUTER JOIN [Employee] AS [ManagerEmployee]
			ON [Company].[ManagerEmployeeID] = [ManagerEmployee].[ID]
	WHERE
		[Company].[ID] = @ID
	
	SELECT
		[Address].[AddressTypeID],
		[Address].[Street],
		[Address].[City],
		[Address].[Region],
		[Address].[PostalCode],
		[Address].[Country],
		[Address].[Mail],
		dbo.fnPjm5AddressAsString([Address].[Street], [Address].[City],[Address].[Region],[Address].[PostalCode],[Address].[Country]) AS [AsString]
	FROM
		[Address]
	WHERE
		[Address].[BusinessCardID] = @ID AND 
		[Address].[BusinessCardClass] = @Class
		
	SELECT
		[Phone].[PhoneTypeID],
		[Phone].[Phone]
	FROM
		[Phone]	
	WHERE
		[Phone].[BusinessCardID] = @ID AND 
		[Phone].[BusinessCardClass] = @Class


	SELECT
		[Email].[EmailTypeID],
		[Email].[Email],
		[Email].[DisplayAs]
	FROM
		[Email]
	WHERE
		[Email].[BusinessCardID] = @ID AND 
		[Email].[BusinessCardClass] = @Class
	
	SELECT
		[Employee].[Class],
		[Employee].[ID],
		[Employee].[State],
		[Employee].[FileAs],
		[Employee].[FileAs],
		[Employee].[PositionID],
		[Employee].[QualificationID],
		[Employee].[DivisionID],
		[Employee].[HireDate],
		[Employee].[FireDate],
		[Employee].[LastContact],
		[Employee].[NextContact],
		[Employee].[UserID],
		[Position].[FileAs] AS [PositionFileAs],
		[Qualification].[FileAs] AS [QualificationFileAs],
		[Division].[FileAs] AS [DivisionFileAs],
		dbo.fnPjm5GetPhoneList([Employee].[ID], [Employee].[Class])	AS [Phonelist]
	FROM
		[Employee]
		LEFT OUTER JOIN [Position]
			ON [Employee].[PositionID] = [Position].[ID]
		LEFT OUTER JOIN [Division]
			ON [Employee].[DivisionID] = [Division].[ID]
		LEFT OUTER JOIN [Qualification]
			ON [Employee].[QualificationID] = [Qualification].[ID]
	WHERE
		[Employee].[CompanyID] = @ID

	DECLARE @author TName
	SELECT @author = [FileAs] FROM [Employee] WHERE [ID] = dbo.adfGetCurrentEmployeeID()
	SELECT
		[Company].[LegalName] AS [Title],
		[Company].[FileAs] AS [Subject],
		@author AS [Author],
		NULL AS [Manager],
		[Company].[FileAs] AS [Company],
		dbo.fnPjm5GetCategoryList([Company].[ID], [Company].[Class]) AS [Category],
		NULL AS [Keywords]
     FROM
		[Company]
     WHERE
		[Company].[ID] = @ID

	RETURN 0
GO

GRANT EXEC ON ReportWordCompany TO PUBLIC
GO
