SET QUOTED_IDENTIFIER ON
GO

ALTER PROCEDURE [pjm5ProcessNotificationEvents]
AS
	SET NOCOUNT ON

	DECLARE @message_body XML,
			@message_type_name NVARCHAR(256),
            @dialog UNIQUEIDENTIFIER ;

	WHILE (1 = 1)
	BEGIN
		WAITFOR(
			RECEIVE TOP(1) 
				@message_type_name = message_type_name,
				@message_body = message_body,
				@dialog = conversation_handle
			FROM [ProjectMateEventNotificationQueue]
		), TIMEOUT 2000;

		IF @@ROWCOUNT = 0
		BEGIN
			BREAK;
		END

		IF (@message_type_name = 'http://schemas.microsoft.com/SQL/ServiceBroker/EndDialog')
		BEGIN
	        END CONVERSATION @dialog ;
		END
		ELSE
		BEGIN
			DECLARE @FromID TIdentifier, 
					@EventType TName, 
					@DocumentClassName TCode, 
					@DocumentID TIdentifier, 
					@Data xml,
					@DocumentClass TClass
			SELECT
				@FromID = T.c.value('FromID[1]', 'int'),
				@EventType = T.c.value('EventType[1]', 'nvarchar(256)'),
				@DocumentClassName = T.c.value('DocumentClassName[1]', 'varchar(32)'),
				@DocumentID = T.c.value('DocumentID[1]', 'int'),
				@Data = T.c.query('Data')
			FROM 
				@message_body.nodes('DocumentChangeEvent') T(c)
			
			SET @DocumentClass = dbo.adfGetClassByName(@DocumentClassName)
			
			EXECUTE AS USER = 'dbo'
			
			DECLARE @sql nvarchar(max), @params nvarchar(max), @result int
			
			SET @sql = N'EXEC @result = [dbo].[GenerateEvents' + @EventType + '] @FromID, @EventType, @DocumentClass, @DocumentID, @Data';
			SET @params = N'@result int OUTPUT, @FromID int, @EventType nvarchar(32), @DocumentClass smallint, @DocumentID int, @Data xml';
			
			EXEC sp_executesql @sql, @params, @result OUTPUT, @FromID, @EventType, @DocumentClass, @DocumentID, @Data
			
			RETURN 0
		END
	END
	RETURN 0;
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5PostDocumentChangeNotificationEvent]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5PostDocumentChangeNotificationEvent'
		DROP PROCEDURE [dbo].[pjm5PostDocumentChangeNotificationEvent]
	END
GO

PRINT 'Creating procedure pjm5PostDocumentChangeNotificationEvent'
GO


/******************************************************************************
**		Name: pjm5PostDocumentChangeNotificationEvent
**		Desc: 
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Dmitry.Kolchev
**		Date: 10/12/2006
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE PROCEDURE [pjm5PostDocumentChangeNotificationEvent]
	@EventType TName,
	@DocumentClassName TCode,
	@DocumentId TIdentifier,
	@Data xml
AS
	SET NOCOUNT ON;
	
	DECLARE @dialog UNIQUEIDENTIFIER;
	
	BEGIN DIALOG CONVERSATION @dialog
		FROM SERVICE [http://schemas.projectmate.ru/Notifications/EventNotificationService]
		TO SERVICE 'http://schemas.projectmate.ru/Notifications/EventNotificationService'
		ON CONTRACT [http://schemas.projectmate.ru/Notifications/PostEventNotification]
		WITH ENCRYPTION = OFF;
		
	DECLARE @EventData XML;
	
	SET @EventData = (SELECT [FromID], [EventType], [DocumentClassName], [DocumentID], [Data] FROM
		(SELECT
			dbo.adfGetCurrentUserID() as [FromID],
			@EventType as [EventType],
			@DocumentClassName as [DocumentClassName],
			@DocumentID as [DocumentID],
			@Data as [Data]
			) as [DocumentChangeEvent]
		FOR XML AUTO, ELEMENTS);
	
	SEND ON CONVERSATION @dialog
		MESSAGE TYPE [http://schemas.projectmate.ru/Notifications/DocumentChangeEvent] (@EventData);
		
	END CONVERSATION @dialog;
	
	RETURN 0;
GO

