IF EXISTS (SELECT * FROM sysobjects WHERE type = 'TR' AND name = 'pjm5trStatementLineInsert')
	BEGIN
		PRINT 'Dropping Trigger pjm5trStatementLineInsert'
		DROP  Trigger pjm5trStatementLineInsert
	END
GO

/******************************************************************************
**		File: 
**		Name: pjm5trStatementLineInsert
**		Desc: 
**
**		This template can be customized:
**              
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:				Description:
**		--------		--------				-------------------------------------------
**    
*******************************************************************************/

PRINT 'Creating Trigger pjm5trStatementLineInsert'
GO
CREATE Trigger pjm5trStatementLineInsert 
ON [StatementLine] FOR INSERT
AS
BEGIN
	DECLARE
		@CalculationClass TClass,
		@StatementClass TClass

	SET @CalculationClass = dbo.adfGetClassByName('Pjm5.Calculation')	
	SET @StatementClass = dbo.adfGetClassByName('Pjm5.Statement')	
	IF EXISTS(
		SELECT * 
		FROM 
			[Attachment]
			INNER JOIN [inserted]
				ON ([inserted].[DocumentClass] = [Attachment].[DocumentClass] AND
					[inserted].[DocumentID] = [Attachment].[DocumentID] AND
					[Attachment].[AttachmentTypeID] = 3)
		WHERE
			[Attachment].[LinkDocumentClass] IN (@CalculationClass, @StatementClass)
		)
	BEGIN
		ROLLBACK TRANSACTION
		RAISERROR('#DocumentAlreadyLinked', 18, -1)
		RETURN
	END

	INSERT INTO [Attachment]
		(
		[DocumentClass], [DocumentID], [Name],
		[LinkDocumentClass], [LinkDocumentID], [AttachmentTypeID]
		)
	SELECT
		[inserted].[DocumentClass], [inserted].[DocumentID], '',
		[Statement].[Class], [Statement].[ID], 3
	FROM
		[inserted]
		INNER JOIN [Statement]
			ON [Statement].[ID] = [inserted].[StatementID]
	WHERE
		[inserted].[DocumentID] IS NOT NULL AND
		[inserted].[DocumentClass] != dbo.adfGetClassByName('Pjm5.ServiceAssignment')
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN
	END

	UPDATE
		[Calculation]
	SET
		[Calculation].[State] = CASE
			WHEN [Calculation].[State] = 2 THEN 3
			ELSE [Calculation].[State]
		END,
		[Calculation].[StatementApproved] = 1,
		[Calculation].[Modified] = DEFAULT,
		[Calculation].[ModifiedBy] = DEFAULT
	FROM
		[Calculation]
		INNER JOIN [inserted]
			ON [Calculation].[Class] = [inserted].[DocumentClass] AND 
				[Calculation].[ID] = [inserted].[DocumentID]
	WHERE
		[Calculation].[State] = 2 OR
		[Calculation].[State] = 3 AND [Calculation].[InvoiceApproved] = 0
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotApproveInvoiceCalculation', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END

	UPDATE
		[TimeEntry]
	SET
		[TimeEntry].[DivisionID] = [Employee].[DivisionID],
		[TimeEntry].[State] = 3,
		[TimeEntry].[Modified] = DEFAULT,
		[TimeEntry].[ModifiedBy] = DEFAULT
	FROM
		[TimeEntry]
		INNER JOIN [Employee]
			ON [Employee].[ID] = [TimeEntry].[EmployeeID]
		INNER JOIN [inserted]
			ON [TimeEntry].[Class] = [inserted].[DocumentClass] AND 
				[TimeEntry].[ID] = [inserted].[DocumentID] AND
				[TimeEntry].[State] = 2
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotApproveInvoiceTimeEntry', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END

	UPDATE
		[Expense]
	SET
		[Expense].[DivisionID] = [Employee].[DivisionID],
		[Expense].[State] = 3,
		[Expense].[Modified] = DEFAULT,
		[Expense].[ModifiedBy] = DEFAULT
	FROM
		[Expense]
		INNER JOIN [Employee]
			ON [Employee].[ID] = [Expense].[EmployeeID]
		INNER JOIN [inserted]
			ON [Expense].[Class] = [inserted].[DocumentClass] AND 
				[Expense].[ID] = [inserted].[DocumentID] AND
				[Expense].[State] = 2
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotApproveInvoiceExpense', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END
	
	UPDATE
		[ServiceRequest]
	SET
		[ServiceRequest].[DivisionID] = [Employee].[DivisionID],
		[ServiceRequest].[State] = 4,
		[ServiceRequest].[Modified] = DEFAULT,
		[ServiceRequest].[ModifiedBy] = DEFAULT
	FROM
		[ServiceRequest]
		INNER JOIN [Employee]
			ON [Employee].[ID] = [ServiceRequest].[EmployeeID]
		INNER JOIN [inserted]
			ON [ServiceRequest].[Class] = [inserted].[DocumentClass] AND 
				[ServiceRequest].[ID] = [inserted].[DocumentID] AND
				[ServiceRequest].[State] = 3
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotApproveInvoiceServiceRequest', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END

	UPDATE
		[TimeEntry]
	SET
		[TimeEntry].[State] = 6,
		[TimeEntry].[Modified] = DEFAULT,
		[TimeEntry].[ModifiedBy] = DEFAULT
	FROM
		[TimeEntry]
		INNER JOIN [inserted]
			ON [TimeEntry].[Class] = [inserted].[DocumentClass] AND 
				[TimeEntry].[ID] = [inserted].[DocumentID]
	WHERE
		[TimeEntry].[State] != 6
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotApproveInvoiceTimeEntry', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END
	
	UPDATE
		[Expense]
	SET
		[Expense].[State] = 6,
		[Expense].[Modified] = DEFAULT,
		[Expense].[ModifiedBy] = DEFAULT
	FROM
		[Expense]
		INNER JOIN [inserted]
			ON [Expense].[Class] = [inserted].[DocumentClass] AND 
				[Expense].[ID] = [inserted].[DocumentID]
	WHERE
		[Expense].[State] != 6
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotApproveInvoiceExpense', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END

	UPDATE
		[ServiceRequest]
	SET
		[ServiceRequest].[State] = 5,
		[ServiceRequest].[Modified] = DEFAULT,
		[ServiceRequest].[ModifiedBy] = DEFAULT
	FROM
		[ServiceRequest]
		INNER JOIN [inserted]
			ON [ServiceRequest].[Class] = [inserted].[DocumentClass] AND 
				[ServiceRequest].[ID] = [inserted].[DocumentID]
	WHERE
		[ServiceRequest].[State] != 5
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotApproveInvoiceServiceRequest', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END
END

GO

IF EXISTS (SELECT * FROM sysobjects WHERE type = 'TR' AND name = 'pjm5trStatementLineDelete')
	BEGIN
		PRINT 'Dropping Trigger pjm5trStatementLineDelete'
		DROP  Trigger pjm5trStatementLineDelete
	END
GO

/******************************************************************************
**		File: 
**		Name: pjm5trStatementLineDelete
**		Desc: 
**
**		This template can be customized:
**              
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:				Description:
**		--------		--------				-------------------------------------------
**    
*******************************************************************************/

PRINT 'Creating Trigger pjm5trStatementLineDelete'
GO
CREATE Trigger pjm5trStatementLineDelete 
ON [StatementLine] FOR DELETE
AS
BEGIN
	DELETE [Attachment]
	FROM
		[Attachment]
		INNER JOIN [deleted]
			ON ([deleted].[DocumentClass] = [Attachment].[DocumentClass] AND 
				[deleted].[DocumentID] = [Attachment].[DocumentID])
		INNER JOIN [Statement]
			ON ([Statement].[ID] = [deleted].[StatementID] AND
				[Statement].[Class] = [Attachment].[LinkDocumentClass] AND 
				[Statement].[ID] = [Attachment].[LinkDocumentID])
	WHERE
		[Attachment].[AttachmentTypeID] = 3
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN
	END
	
	UPDATE
		[Calculation]
	SET
		[Calculation].[StatementApproved] = 0,
		[Calculation].[Modified] = DEFAULT,
		[Calculation].[ModifiedBy] = DEFAULT
	FROM
		[Calculation]
		INNER JOIN [deleted]
			ON [Calculation].[Class] = [deleted].[DocumentClass] AND 
				[Calculation].[ID] = [deleted].[DocumentID]
	WHERE [Calculation].[StatementApproved] = 1 
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotRecommitStatementCalculation', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END
	
	UPDATE
		[Calculation]
	SET
		[Calculation].[State] = 2
	FROM
		[Calculation]
		INNER JOIN [deleted]
			ON [Calculation].[Class] = [deleted].[DocumentClass] AND 
				[Calculation].[ID] = [deleted].[DocumentID]
	WHERE
		[Calculation].[State] = 3 AND
		NOT EXISTS(
			SELECT * 
			FROM [FactureLine] 
				INNER JOIN [Facture]
					ON [Facture].[ID] = [FactureLine].[FactureID]
			WHERE 
				[Facture].[State] IN (1, 2) AND
				[DocumentClass] = [Calculation].[Class] AND 
				[DocumentID] = [Calculation].[ID]
			) AND
		NOT EXISTS(
			SELECT * 
			FROM [InvoiceLine] 
				INNER JOIN [Invoice]
					ON [Invoice].[ID] = [InvoiceLine].[InvoiceID]
			WHERE 
				[Invoice].[State] != 3 AND
				[DocumentClass] = [Calculation].[Class] AND 
				[DocumentID] = [Calculation].[ID]
			)
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotRecommitStatementCalculation', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END
	
	UPDATE
		[TimeEntry]
	SET
		[TimeEntry].[State] = 3,
		[TimeEntry].[Modified] = DEFAULT,
		[TimeEntry].[ModifiedBy] = DEFAULT
	FROM
		[TimeEntry]
		INNER JOIN [deleted]
			ON [TimeEntry].[Class] = [deleted].[DocumentClass] AND 
				[TimeEntry].[ID] = [deleted].[DocumentID]
	WHERE
		[TimeEntry].[State] = 6 AND
		NOT EXISTS(
			SELECT * 
			FROM [FactureLine] 
				INNER JOIN [Facture]
					ON [Facture].[ID] = [FactureLine].[FactureID]
			WHERE 
				[Facture].[State] IN (1, 2) AND
				[DocumentClass] = [TimeEntry].[Class] AND 
				[DocumentID] = [TimeEntry].[ID]
			) AND
		NOT EXISTS(
			SELECT * 
			FROM [InvoiceLine] 
				INNER JOIN [Invoice]
					ON [Invoice].[ID] = [InvoiceLine].[InvoiceID]
			WHERE 
				[Invoice].[State] IN (2, 4, 5) AND
				[DocumentClass] = [TimeEntry].[Class] AND 
				[DocumentID] = [TimeEntry].[ID]
			)
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotRecommitInvoiceTimeEntry', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END
	
	UPDATE
		[Expense]
	SET
		[Expense].[State] = 3,
		[Expense].[Modified] = DEFAULT,
		[Expense].[ModifiedBy] = DEFAULT
	FROM
		[Expense]
		INNER JOIN [deleted]
			ON [Expense].[Class] = [deleted].[DocumentClass] AND 
				[Expense].[ID] = [deleted].[DocumentID]
	WHERE
		[Expense].[State] = 6 AND
		NOT EXISTS(
			SELECT * 
			FROM [FactureLine] 
				INNER JOIN [Facture]
					ON [Facture].[ID] = [FactureLine].[FactureID]
			WHERE 
				[Facture].[State] IN (1, 2) AND
				[DocumentClass] = [Expense].[Class] AND 
				[DocumentID] = [Expense].[ID]
			) AND
		NOT EXISTS(
			SELECT * 
			FROM [InvoiceLine] 
				INNER JOIN [Invoice]
					ON [Invoice].[ID] = [InvoiceLine].[InvoiceID]
			WHERE 
				[Invoice].[State] IN (2, 4, 5) AND
				[DocumentClass] = [Expense].[Class] AND 
				[DocumentID] = [Expense].[ID]
			)
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotRecommitInvoiceExpense', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END

	UPDATE
		[ServiceRequest]
	SET
		[ServiceRequest].[State] = 4,
		[ServiceRequest].[Modified] = DEFAULT,
		[ServiceRequest].[ModifiedBy] = DEFAULT
	FROM
		[ServiceRequest]
		INNER JOIN [deleted]
			ON [ServiceRequest].[Class] = [deleted].[DocumentClass] AND 
				[ServiceRequest].[ID] = [deleted].[DocumentID]
	WHERE
		[ServiceRequest].[State] = 5 AND
		NOT EXISTS(
			SELECT * 
			FROM [FactureLine] 
				INNER JOIN [Facture]
					ON [Facture].[ID] = [FactureLine].[FactureID]
			WHERE 
				[Facture].[State] IN (1, 2) AND
				[DocumentClass] = [ServiceRequest].[Class] AND 
				[DocumentID] = [ServiceRequest].[ID]
			) AND
		NOT EXISTS(
			SELECT * 
			FROM [InvoiceLine] 
				INNER JOIN [Invoice]
					ON [Invoice].[ID] = [InvoiceLine].[InvoiceID]
			WHERE 
				[Invoice].[State] IN (2, 4, 5) AND
				[DocumentClass] = [ServiceRequest].[Class] AND 
				[DocumentID] = [ServiceRequest].[ID]
			)
	IF @@error != 0
	BEGIN
		RAISERROR('#CannotRecommitInvoiceServiceRequest', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END

	DECLARE @timeClass TClass
	SET @timeClass = dbo.adfGetClassByName('Pjm5.TimeEntry')
	UPDATE
		[EntryAmount]
	SET
		[Amount] = ROUND([TimeEntry].[RoundedDuration] / 60.0, 2),
		[Price] = ISNULL([TimeEntry].[Rate], 0)
	FROM 
		[EntryAmount]
		INNER JOIN [TimeEntry]
			ON [TimeEntry].[ID] = [EntryAmount].[ID]
		INNER JOIN [deleted]
			ON [deleted].[DocumentClass] = [TimeEntry].[Class] AND
				[deleted].[DocumentID] = [TimeEntry].[ID]
		INNER JOIN [Statement]
			ON [Statement].[ID] = [deleted].[StatementID]
	WHERE
		[Statement].[State] != 4 AND
		NOT EXISTS (
			SELECT *
			FROM
				[InvoiceLine]
				INNER JOIN [deleted]
					ON [InvoiceLine].[DocumentClass] = [deleted].[DocumentClass] AND
						[InvoiceLine].[DocumentID] = [deleted].[DocumentID]
				INNER JOIN [Invoice]
					ON [Invoice].[ID] = [InvoiceLine].[InvoiceID]
			WHERE
				[InvoiceLine].[DocumentClass] = @timeClass AND
				[Invoice].[State] != 3
		) AND
		NOT EXISTS (
			SELECT *
			FROM
				[FactureLine]
				INNER JOIN [deleted]
					ON [FactureLine].[DocumentClass] = [deleted].[DocumentClass] AND
						[FactureLine].[DocumentID] = [deleted].[DocumentID]
				INNER JOIN [Facture]
					ON [Facture].[ID] = [FactureLine].[FactureID]
			WHERE
				[FactureLine].[DocumentClass] = @timeClass AND
				[Facture].[State] != 3
		)
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN
	END			
END

GO

IF EXISTS (SELECT * FROM sysobjects WHERE type = 'TR' AND name = 'pjm5trStatementLineUpdate')
	BEGIN
		PRINT 'Dropping Trigger pjm5trStatementLineUpdate'
		DROP  Trigger pjm5trStatementLineUpdate
	END
GO

/******************************************************************************
**		File: 
**		Name: pjm5trStatementLineUpdate
**		Desc: 
**
**		This template can be customized:
**              
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:				Description:
**		--------		--------				-------------------------------------------
**    
*******************************************************************************/

PRINT 'Creating Trigger pjm5trStatementLineUpdate'
GO
CREATE Trigger pjm5trStatementLineUpdate 
ON [StatementLine] FOR INSERT, UPDATE, DELETE
AS
BEGIN
	IF @@ROWCOUNT = 0
		RETURN

    IF EXISTS (
		SELECT *
		FROM [inserted]
		WHERE 
			[inserted].[VATIsIncluded] = 1 AND 
			[inserted].[Price] * [inserted].[Amount] < [inserted].[VAT]
	)
	BEGIN
		RAISERROR('#wrongvatvalue', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END
	
	DECLARE 
		@timeClass TClass,
		@value TVariant,
		@BaseCurrency TCode3,
		@NationalCurrency TCode3
		
	SET @timeClass = dbo.adfGetClassByName('Pjm5.TimeEntry')
	IF EXISTS(
		SELECT *
		FROM 
			[EntryAmount]
			INNER JOIN [inserted]
				ON [inserted].[DocumentClass] = @timeClass AND
					[inserted].[DocumentID] = [EntryAmount].[ID]
			INNER JOIN [deleted]
				ON [deleted].[DocumentClass] = [inserted].[DocumentClass] AND
					[deleted].[DocumentID] = [inserted].[DocumentID]
			INNER JOIN [InvoiceLine]
				ON [InvoiceLine].[DocumentClass] = @timeClass AND
					[InvoiceLine].[DocumentID] = [EntryAmount].[ID]
			INNER JOIN [Invoice]
				ON [Invoice].[ID] = [InvoiceLine].[InvoiceID]
		WHERE
			[Invoice].[State] != 3 AND
			(
				[InvoiceLine].[Amount] != [inserted].[Amount] OR 
				[InvoiceLine].[PricePC] != [inserted].[PricePC]
			)
	)
	BEGIN
		RAISERROR('#CannotChangeEntryAmountOrPrice', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END

	IF EXISTS(
		SELECT *
		FROM 
			[EntryAmount]
			INNER JOIN [inserted]
				ON [inserted].[DocumentClass] = @timeClass AND
					[inserted].[DocumentID] = [EntryAmount].[ID]
			INNER JOIN [deleted]
				ON [deleted].[DocumentClass] = [inserted].[DocumentClass] AND
					[deleted].[DocumentID] = [inserted].[DocumentID]
			INNER JOIN [FactureLine]
				ON [FactureLine].[DocumentClass] = @timeClass AND
					[FactureLine].[DocumentID] = [EntryAmount].[ID]
			INNER JOIN [Facture]
				ON [Facture].[ID] = [FactureLine].[FactureID]
		WHERE
			[Facture].[State] != 3 AND
			(
				[FactureLine].[Amount] != [inserted].[Amount] OR 
				[FactureLine].[OriginalPricePC] != [inserted].[PricePC]
			)
	)
	BEGIN
		RAISERROR('#CannotChangeEntryAmountOrPrice', 18, -1)
		ROLLBACK TRANSACTION
		RETURN
	END
	
	UPDATE
		[EntryAmount]
	SET
		[Amount] = [inserted].[Amount],
		[Price] = [inserted].[PricePC]
	FROM 
		[EntryAmount]
		INNER JOIN [inserted]
			ON [inserted].[DocumentClass] = @timeClass AND
				[inserted].[DocumentID] = [EntryAmount].[ID]
	WHERE
		[EntryAmount].[Amount] != [inserted].[Amount] OR 
		[EntryAmount].[Price] != [inserted].[PricePC]
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN
	END
	
	EXEC adfParameterGet 'NationalCurrency', 'CommonBusiness', @value OUTPUT	
	SET @NationalCurrency = CAST(@value AS varchar(3))
	EXEC adfParameterGet 'BaseCurrency', 'CommonBusiness', @value OUTPUT	
	SET @BaseCurrency = CAST(@value AS varchar(3))

	DECLARE @changed TABLE ([ID] int, [ApplyVAT] bit)
	INSERT INTO @changed ([ID], [ApplyVAT])
	SELECT
		ISNULL([inserted].[StatementID], [deleted].[StatementID]),
		[Project].[ApplyVAT]
	FROM
		[inserted]
		FULL OUTER JOIN [deleted]
			ON [inserted].[ID] = [deleted].[ID]
		INNER JOIN [Statement]
			ON 	[Statement].[ID] = ISNULL([inserted].[StatementID], [deleted].[StatementID])
		INNER JOIN [Project]
			ON [Project].[ID] = [Statement].[ProjectID]
	WHERE
		[Statement].[State] != 4

	DECLARE @ID int, @ApplyVAT bit
	DECLARE @total money, @totalwithvat money, @totalPC money, @totalwithvatPC money, @totalBC money, @totalwithvatBC money
	DECLARE @totals TABLE ([ID] int, [ApplyVAT] bit, [Total] money, [TotalWithVAT] money, [TotalPC] money null, [TotalWithVATPC] money null, [TotalBC] money null, [TotalWithVATBC] money null)
	DECLARE documents CURSOR FAST_FORWARD FOR SELECT [ID], [ApplyVAT] FROM @changed
	
	OPEN documents
	FETCH NEXT FROM documents INTO @ID, @ApplyVAT
	WHILE @@FETCH_STATUS = 0
	BEGIN
		SELECT
			@total = ISNULL(SUM(ROUND(
				CASE 
					WHEN [StatementLine].[VATIsIncluded] = 0
						THEN [StatementLine].[Amount] * [StatementLine].[Price]
					ELSE [StatementLine].[Amount] * [StatementLine].[Price] - [StatementLine].[VAT]
				END, [Statement].[Scale])), 0),		
			@totalwithvat = ISNULL(SUM(ROUND(
				CASE 
					WHEN [StatementLine].[VATIsIncluded] = 0
						THEN [StatementLine].[Amount] * [StatementLine].[Price] + [StatementLine].[VAT]
					ELSE [StatementLine].[Amount] * [StatementLine].[Price]
				END, [Statement].[Scale])), 0),
			@totalPC = ISNULL(SUM(ROUND(
				CASE 
					WHEN [StatementLine].[VATIsIncluded] = 0
						THEN [StatementLine].[Amount] * [StatementLine].[PricePC]
					ELSE [StatementLine].[Amount] * [StatementLine].[PricePC] - [StatementLine].[VATPC]
				END, [Statement].[Scale])), 0),		
			@totalwithvatPC = ISNULL(SUM(ROUND(
				CASE 
					WHEN [StatementLine].[VATIsIncluded] = 0
						THEN [StatementLine].[Amount] * [StatementLine].[PricePC] + [StatementLine].[VATPC]
					ELSE [StatementLine].[Amount] * [StatementLine].[PricePC]
				END, [Statement].[Scale])), 0)
		FROM
			[Statement]
			INNER JOIN [StatementLine]
				ON [StatementLine].[StatementID] = [Statement].[ID]
		WHERE
			[Statement].[ID] = @ID
		IF @ApplyVAT = 0
		BEGIN
			SET @totalwithvat = @total
			SET @totalwithvatPC = @totalPC
		END

		INSERT INTO @totals ([ID], [ApplyVAT], [Total], [TotalWithVAT], [TotalPC], [TotalWithVATPC])
		VALUES (@ID, @ApplyVAT, @total, @totalwithvat, ISNULL(@totalPC, @total), ISNULL(@totalwithvatPC, @totalwithvat))
		FETCH NEXT FROM documents INTO @ID, @ApplyVAT
	END
	CLOSE documents
	DEALLOCATE documents

		
	UPDATE
		[Statement]
	SET
		[Total] = ROUND(ISNULL([Total].[Total], 0), CASE [Project].[ApplyVAT] WHEN 0 THEN 2 ELSE [Statement].[Scale] END),
		[TotalWithVAT] = ROUND(ISNULL([Total].[TotalWithVAT], 0), 2),
		[TotalPC] = ROUND(ISNULL([Total].[TotalPC] ,0), CASE [Project].[ApplyVAT] WHEN 0 THEN 2 ELSE [Statement].[Scale] END),
		[TotalWithVATPC] = ROUND(ISNULL([Total].[TotalWithVATPC], 0), 2),
		[TotalBC]= ROUND(CASE 
						WHEN [Project].[CurrencyCode] = @BaseCurrency
							THEN ISNULL([Total].[TotalPC], 0)
						WHEN [Statement].[CurrencyCode] = @BaseCurrency
							THEN ISNULL([Total].[Total], 0)
						WHEN [Project].[CurrencyCode] = @NationalCurrency
							THEN ISNULL([Total].[TotalPC], 0) / [Statement].[BaseCurrencyRate]
						ELSE ISNULL([Total].[TotalPC], 0) * [Statement].[BaseCurrencyRate]
					END, 2),
		[TotalWithVATBC] = ROUND(CASE 
						WHEN [Project].[CurrencyCode] = @BaseCurrency
							THEN ISNULL([Total].[TotalWithVATPC], 0)
						WHEN [Statement].[CurrencyCode] = @BaseCurrency
							THEN ISNULL([Total].[TotalWithVAT], 0)
						WHEN [Project].[CurrencyCode] = @NationalCurrency
							THEN ISNULL([Total].[TotalWithVATPC],0) / [Statement].[BaseCurrencyRate]
						ELSE ISNULL([Total].[TotalWithVATPC],0) * [Statement].[BaseCurrencyRate]
					END, 2),
		[Modified] = DEFAULT,
		[ModifiedBy] = DEFAULT		
	FROM
		[Statement]
		INNER JOIN [Project]
			ON [Project].[ID] = [Statement].[ProjectID]
		INNER JOIN @totals AS [Total]
			ON 	[Statement].[ID] = [Total].[ID]		
	WHERE
		[Statement].[State] != 4
	IF @@ERROR != 0
	BEGIN
		ROLLBACK TRANSACTION
		RETURN
	END
END

GO