IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5TaskGet]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5TaskGet'
		DROP PROCEDURE [dbo].[pjm5TaskGet]
	END
GO

PRINT 'Creating procedure pjm5TaskGet'
GO

/******************************************************************************
**		File: pjm5TaskGet.sql
**		Name: pjm5TaskGet
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Andrew.Maklakov
**		Date: 01/20/2005 13:49:21
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE PROCEDURE [pjm5TaskGet]
	@ID TIdentifier
AS
	SET NOCOUNT ON
	DECLARE
		@budget money,
		@value TVariant,
		@date datetime,
		@ProjectID TIdentifier,
		@StartDate datetime,
		@DueDate datetime,
		@AllowFullUpdate TBool,
		@UserID TIdentifier,
		@ViewAllTasks TBool,
		@CurrentEmployeeID TIdentifier,
		@IsFinanceEnable	bit,
		@ViewAllFinance TBool,
		@ViewFinance TBool,
		@IsPM TBool,
		@IsMember TBool
		
	SET @CurrentEmployeeID = dbo.adfGetCurrentEmployeeID()
	SET @ViewAllTasks = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllTasks'))
	SELECT 
		@ProjectID = [ProjectID],
		@StartDate = [StartDate],
		@DueDate = [DueDate]
	FROM
		[Task]
	WHERE
		[ID] = @ID 
		
	SET @AllowFullUpdate = dbo.fnPjm5IsProjectManager(@ProjectID, @CurrentEmployeeID)
	SET @UserID = dbo.adfGetCurrentUserID()
	SET @ViewAllFinance = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllFinance'))
	SET @ViewFinance = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewFinance'))
	SET @IsPM = dbo.fnPjm5IsProjectManager(@ProjectID, @CurrentEmployeeID)
	SET @IsMember = @IsPM | dbo.fnPjm5IsProjectMember(@ProjectID, @CurrentEmployeeID)
	
	SET @IsFinanceEnable = @IsMember & @ViewFinance
	SET @IsFinanceEnable = @IsFinanceEnable | @ViewAllFinance | @IsPM

	if @ViewAllTasks = 0 AND 
		@AllowFullUpdate = 0 AND
		dbo.fnPjm5IsProjectMember(@ProjectID, @CurrentEmployeeID) = 0
	BEGIN
		RAISERROR('#accessdenied', 18, -1)
		RETURN 1
	END
	
	SELECT
		@date = GETDATE(),
		@budget = SUM([Billable]*[BillableHour] * [Rate])
	FROM
		[vwTimeEntry] as [TimeEntry]
	WHERE
		[TaskID] = @ID AND
		[State] IN (2, 3)
		
	SELECT
		@budget = ISNULL(@budget, 0) + ISNULL([Amount] * [Price] * [CurrencyRate], 0)
	FROM
		[Expense]
	WHERE
		[TaskID] = @ID AND
		[State] IN (2, 3)
	
	SELECT
		[Task].[Class],
		[Task].[ID],
		[Task].[State],
		[Task].[Flag],
		[Task].[FileAs],
		[Task].[ProjectID],
		[Task].[PriorityID],
		[Task].[ParentID],
		[Task].[StartDate],
		[Project].[CurrencyCode],
		[Task].[DueDate],
		[Task].[EndDate],
		[Task].[Duration],
		CAST([Task].[ManHour] / 60.0 AS decimal(18,4)) AS [ManHour],
		[Task].[Budget],
		CAST(ROUND([Task].[PercentComplete],2) * 100 as int) as [PercentComplete],
		[Task].[Milestone],
		[Task].[SendStatusReport],
		[Task].[Comments],
		[Task].[Created],
		[Task].[CreatedBy],
		[Task].[Modified],
		[Task].[ModifiedBy],
		[Task].[Timestamp],
		[Task].[RealManHour],
		[Task].[TimeRealBudget] + [Task].[ExpenseRealBudget] AS [RealBudget],
		[Task].[PlannedManHour],
		[Task].[PlannedBudget],
		CASE
			WHEN @AllowFullUpdate = 1 OR [Task].[State] IN (7, 8) THEN CAST(1 AS bit)
			ELSE CAST(0 AS bit)
		END AS [AllowFullUpdate],
		CASE
			WHEN @AllowFullUpdate = 0 AND [Task].[State] NOT IN (7, 8) THEN CAST(1 AS bit)
			ELSE CAST(0 AS bit)
		END AS [PercentUpdateOnly],
		ISNULL([UserReminder].[State], CAST(0 as int)) AS [ReminderState],
		CASE
			WHEN [UserReminder].[OriginalInterval] IS NOT NULL THEN
				DATEADD(minute,-[UserReminder].[OriginalInterval],[Task].[DueDate])
			ELSE
				DATEADD(minute,
					-dbo.fnPjm5GetReminderInterval([Task].[Class], 'TD', @UserID),
					[Task].[DueDate])
		END
		AS [ReminderTime],
		[TaskWbs].[TaskIndex],
		[TaskWbs].[Wbs],
		CASE 
			WHEN (@IsFinanceEnable = 1 AND [Project].[ProjectTypeID] = 1) 		
				THEN 1
			ELSE 0
		END AS [HasFinanceAccess]
	FROM
		[pjm5vwTask] AS [Task]
		INNER JOIN [TaskWbs]
			ON [TaskWbs].[TaskID] = [Task].[ID]
		INNER JOIN [Project]
			ON [Project].[ID] = [Task].[ProjectID]
		LEFT OUTER JOIN [Reminder]
			ON ([Reminder].[DocumentClass] = [Task].[Class] AND
				[Reminder].[DocumentID] = [Task].[ID] AND
				[Reminder].[Subtype] = 'TD')
		LEFT OUTER JOIN [UserReminder]
			ON ([Reminder].[ID] = [UserReminder].[ReminderID] AND
				[UserReminder].[UserID] = @UserID)
	WHERE
		[Task].[ID] = @ID

	SELECT
		[Assignment].[ID],
		[Assignment].[Class],
		[Assignment].[State],
		[Assignment].[FileAs],
		[TaskAssignment].[Units],
		[TaskAssignment].[Work],
		[TaskAssignment].[RemainingWork],
		[TaskAssignment].[RemainingOvertimeWork],
		[TaskAssignment].[State] as [TaskAssignmentState]
	FROM
		[vwAssignment] AS [Assignment]
		INNER JOIN [TaskAssignment]
			ON [TaskAssignment].[AssignmentID] = [Assignment].[ID]
	WHERE
		[TaskAssignment].[TaskID] = @ID
		
	SELECT
		[TaskAssignment].[TaskID],
		[BusyEntry].[AssignmentID],
		[BusyEntry].[EmployeeID],
		[BusyEntry].[Date],
		[BusyEntry].[Planned],
		[BusyEntry].[Canceled],
		[BusyEntry].[Committed]
	FROM
		[TaskAssignment]
		INNER JOIN [vwAssignment]
			ON [vwAssignment].[ID] = [TaskAssignment].[AssignmentID]
		INNER JOIN [BusyEntry]
			ON ([BusyEntry].[AssignmentID] = [vwAssignment].[ID] AND
				[BusyEntry].[TaskID] = [TaskAssignment].[TaskID])
	WHERE
		[TaskAssignment].[TaskID] = @ID
		
	SELECT
		[MsTask].[ID]
	FROM
		[MsTask]
			INNER JOIN [Task]
				ON [Task].[MsTaskID] = [MsTask].[ID]
	WHERE
		[Task].[ID] = @ID

	/*DECLARE
		@Class TClass,
		@RecurrencePatternID TIdentifier
	SET @Class = dbo.adfGetClassByName('Pjm5.Task')
	SELECT @RecurrencePatternID = [RecurrencePatternID] FROM [Document] WHERE [Document].[Class] = @Class AND [Document].[ID] = @ID
	SELECT
		[RecurrencePattern].[ID],
		[RecurrencePattern].[StartDate],
		[RecurrencePattern].[EndDate],
		[RecurrencePattern].[Occurrences],
		[RecurrencePattern].[RecurrenceType],
		[RecurrencePattern].[Interval],
		[RecurrencePattern].[DayOfWeekMask],
		[RecurrencePattern].[Instance],
		[RecurrencePattern].[MonthOfYear],
		[RecurrencePattern].[DayOfMonth]
	FROM
		[RecurrencePattern]
	WHERE
		[RecurrencePattern].[ID] = @RecurrencePatternID*/

	RETURN 0
GO

GRANT EXECUTE ON [pjm5TaskGet] TO PUBLIC
GO 