IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5TaskRequestBrowse]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5TaskRequestBrowse'
		DROP PROCEDURE [dbo].[pjm5TaskRequestBrowse]
	END
GO

PRINT 'Creating procedure pjm5TaskRequestBrowse'
GO

SET QUOTED_IDENTIFIER ON
GO

/******************************************************************************
**		File: pjm5TaskRequestBrowse.sql
**		Name: pjm5TaskRequestBrowse
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Andrew.Maklakov
**		Date: 01/20/2005 13:49:21
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**		9.04.10		KOV				 @DateSelector  WHERE   
**									(     )
**
**		15.04.10	KOV				  " "  ""
**      13.10.10    BVY               ""  "" 
**      21.10.10    BVY                    ,     
*******************************************************************************/
CREATE PROCEDURE [pjm5TaskRequestBrowse]
	@Presentation varchar(32),
	@StateSelector	INT,
	@AuthorID TIdentifier,
	@EmployeeID TIdentifier,
	@DateSelector int,
	@PeriodStart TDateTime,
	@PeriodEnd TDateTime,
	@AcceptedSelector INT 
AS
	SET NOCOUNT ON

	DECLARE 
		@CurrentEmployeeID TIdentifier,
		@CurrentUserID TIdentifier,
		@CreatedBy TIdentifier,
		@Now datetime,
		@IsAssistant TBool,
		@IsExecutive TBool,
		@AccessToPublicFolders TBool,
		@ViewAllFinance TBool
		
		
	SET @AccessToPublicFolders = dbo.adfHasAccessRight(dbo.adfGetRightID('AccessToPublicFolders'))
	SET @IsAssistant = dbo.adfHasAccessRight(dbo.adfGetRightID('Assistant'))
	SET @IsExecutive = dbo.adfHasAccessRight(dbo.adfGetRightID('Executive'))
	SET @CurrentEmployeeID = dbo.adfGetCurrentEmployeeID()
	SET @CurrentUserID = dbo.adfGetCurrentUserID()
	SET @ViewAllFinance = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllFinance'))
	SET @Now = GETDATE()
	
	IF @AuthorID IS NOT NULL
		SELECT @CreatedBy = ISNULL([UserID], -1) FROM [Employee] WHERE [ID] = @AuthorID

	IF @Presentation = 'ForMeToday'
	BEGIN
		SET @DateSelector = 0
		SET @PeriodStart = CONVERT(datetime, CONVERT(varchar(8), @Now, 112), 112)
		SET @PeriodEnd = DATEADD(day, 1, @PeriodStart)
	END
	ELSE IF @Presentation = 'ForMeNext7Days'
	BEGIN
		SET @DateSelector = 0
		SET @PeriodStart = CONVERT(datetime, CONVERT(varchar(8), @Now, 112), 112)
		SET @PeriodEnd = DATEADD(day, 7, @PeriodStart)
	END
	ELSE
	BEGIN
		IF @DateSelector = 1
			SET @PeriodStart = CAST(CAST(YEAR(@Now) AS varchar(4)) + '0101' AS datetime)
		ELSE IF @DateSelector = 2
			SET @PeriodStart = CAST(CAST(YEAR(@Now)+1 AS varchar(4)) + '0101' AS datetime)
		ELSE IF @DateSelector = 3
			SET @PeriodStart = DATEADD(day, 1-DATEPART(dayofyear, @PeriodStart), @PeriodStart)
		SET @PeriodStart = CONVERT(datetime, CONVERT(varchar(8), @PeriodStart, 112), 112)
		SET @PeriodEnd = DATEADD(year, 1, @PeriodStart)
	END
	
	SELECT
		[TaskRequest].[Class],
		[TaskRequest].[ID],
		[TaskRequest].[State],
		[TaskRequest].[Flag],
		[TaskRequest].[FileAs],
		[TaskRequest].[ProjectID],
		[TaskRequest].[PriorityID],
		[TaskRequest].[DueTime],
		[TaskRequest].[StartTime],
		[TaskRequest].[SendStatusReport],
		[TaskRequest].[TaskRequestStatusID],
		[TaskRequest].[PercentComplete],
		(CAST([TaskRequest].[PercentComplete] * 100 as int) / 25) * 25 as PC,
		[TaskRequest].[DocumentCardID],
		[TaskRequest].[SupervisorEmployeeID],
		[DocumentCard].[FileAs] AS [DocumentCardFileAs],
		[DocumentCard].[CardOwnerID],
		[TaskRequest].[Comments],
		[TaskRequest].[ExternalID],
		[TaskRequest].[Created],
		[TaskRequest].[CreatedBy],
		[TaskRequest].[Modified],
		[TaskRequest].[ModifiedBy],
		[TaskRequest].[Timestamp],
		CASE 
			WHEN @ViewAllFinance = 1 OR [Project].[ProjectManagerEmployeeID] = @CurrentEmployeeID
				THEN [TaskRequest].[ActualBudget]
			ELSE -1
		END AS [ActualBudget],
		[TaskRequest].[ActualManHour],
		CASE 
			WHEN @ViewAllFinance = 1 OR [Project].[ProjectManagerEmployeeID] = @CurrentEmployeeID
				THEN [TaskRequest].[Budget]
			ELSE -1
		END AS [Budget],
		[TaskRequest].[ManHour]
	FROM
		[TaskRequest]
		LEFT OUTER JOIN [Project] ON [Project].[ID] = [TaskRequest].[ProjectID]
		LEFT OUTER JOIN [DocumentCard]
			ON [DocumentCard].[ID] = [TaskRequest].[DocumentCardID]
	WHERE
		(
			@AccessToPublicFolders = 1 OR
			[TaskRequest].[DocumentCardID] IS NULL
			
		) AND
		(
			@CreatedBy IS NULL OR [TaskRequest].[CreatedBy] = @CreatedBy
		) AND
		(
			@DateSelector = 0 OR 
			(
				COALESCE([TaskRequest].[DueTime], [TaskRequest].[Created]) >= @PeriodStart
				AND
				COALESCE([TaskRequest].[StartTime], @Now) < @PeriodEnd
			)
		) AND
		(
			@EmployeeID IS NULL OR 
			EXISTS(
				SELECT * 
				FROM [TaskRequestAssignment] 
				WHERE 
					[TaskRequestAssignment].[TaskRequestID] = [TaskRequest].[ID] AND 
					[TaskRequestAssignment].[EmployeeID]=@EmployeeID
				)
		) AND
		(
			(@Presentation = 'Own' AND-- 
				(
					@StateSelector = 0 OR 
					@StateSelector = 1 AND [TaskRequest].[State] IN (1, 2) OR
					@StateSelector = 2 AND [TaskRequest].[State] = 3 OR
					@StateSelector = 3 AND [TaskRequest].[State] = 4 OR
					@StateSelector = 4 AND [TaskRequest].[State] = 5
				) AND
					[TaskRequest].[CreatedBy] = @CurrentUserID AND	
				(
				  @AcceptedSelector=0 
				  OR 
				  ( @AcceptedSelector=1 AND 
				    EXISTS(SELECT [TaskRequestAssignment].[Accepted] FROM [TaskRequestAssignment] 
				    WHERE [TaskRequest].[ID]=[TaskRequestAssignment].[TaskRequestID] AND [TaskRequestAssignment].[Accepted]=0)) 
				  OR
				  (EXISTS(SELECT [TaskRequestAssignment].[Accepted] FROM [TaskRequestAssignment] 
				    WHERE [TaskRequest].[ID]=[TaskRequestAssignment].[TaskRequestID] AND [TaskRequestAssignment].[Accepted] IS NULL))
				)	
			)
			OR
			(@Presentation = 'Control' AND-- 
				(
					@StateSelector = 0 OR 
					@StateSelector = 1 AND [TaskRequest].[State] IN (1, 2) OR
					@StateSelector = 2 AND [TaskRequest].[State] = 3 OR
					@StateSelector = 3 AND [TaskRequest].[State] = 4 OR
					@StateSelector = 4 AND [TaskRequest].[State] = 5
				) AND
				[TaskRequest].[SupervisorEmployeeID] = @CurrentEmployeeID
			)
			OR
			(
				@Presentation = 'OwnDraft' AND
				[TaskRequest].[State] = 1 AND
				[TaskRequest].[CreatedBy] = @CurrentUserID
			)
			OR
			(@Presentation = 'ControlDraft' AND
				[TaskRequest].[State] = 1 AND
				[TaskRequest].[SupervisorEmployeeID] = @CurrentEmployeeID
			)
			OR
			(@Presentation = 'All' AND -- 
				(
					@StateSelector = 0 OR 
					[TaskRequest].[State] = @StateSelector
				) AND
				(
					(
						@IsExecutive = 1 OR
						@IsAssistant = 1 OR
						[TaskRequest].[CreatedBy] = @CurrentUserID OR 
						[TaskRequest].[SupervisorEmployeeID] = @CurrentEmployeeID OR
						--EXISTS(SELECT * FROM [vwAssignment] WHERE [vwAssignment].[ProjectID] = [TaskRequest].[ProjectID] AND [vwAssignment].[EmployeeID]=@CurrentEmployeeID) OR
						dbo.fnPjm5IsProjectMember([TaskRequest].[ProjectID], @CurrentEmployeeID) = 1 OR
						dbo.fnPjm5IsProjectManager([TaskRequest].[ProjectID], @CurrentEmployeeID) = 1 OR
						((EXISTS(SELECT * FROM [TaskRequestAssignment] WHERE [TaskRequestAssignment].[TaskRequestID] = [TaskRequest].[ID] AND [TaskRequestAssignment].[EmployeeID]=@CurrentEmployeeID)) AND [TaskRequest].[ProjectID] IS NULL)
					)
				)
			)
			OR
			(@Presentation = 'ForMe' 
				AND
				((@StateSelector = 0 AND [TaskRequest].[State] IN (2, 3, 5))
					OR (@StateSelector = 1 AND [TaskRequest].[State] = 2)
					OR (@StateSelector = 2 AND [TaskRequest].[State] = 3)
					OR (@StateSelector = 3 AND [TaskRequest].[State] = 5))
				AND
					(EXISTS(SELECT * FROM [TaskRequestAssignment] WHERE [TaskRequestAssignment].[TaskRequestID] = [TaskRequest].[ID] AND [TaskRequestAssignment].[EmployeeID]=@CurrentEmployeeID))
				--dbo.fnPjm5IsProjectMember([TaskRequest].[ProjectID], @CurrentEmployeeID) = 1 
				--(EXISTS(SELECT * FROM [vwAssignment] WHERE [vwAssignment].[ProjectID] = [TaskRequest].[ProjectID] AND [vwAssignment].[EmployeeID]=@CurrentEmployeeID))
			)			
			OR
			(@Presentation = 'ForEmployee'
				AND
				((@StateSelector = 0 AND [TaskRequest].[State] IN (2, 3, 4, 5))
					OR (@StateSelector = 1 AND [TaskRequest].[State] = 2)
					OR (@StateSelector = 2 AND [TaskRequest].[State] = 3)
					OR (@StateSelector = 3 AND [TaskRequest].[State] = 4)
					OR (@StateSelector = 4 AND [TaskRequest].[State] = 5)
				)
				--AND
				--(EXISTS(SELECT * FROM [TaskRequestAssignment] WHERE [TaskRequestAssignment].[TaskRequestID] = [TaskRequest].[ID] AND  [TaskRequestAssignment].[EmployeeID]=@CurrentEmployeeID))
			)
			OR
			(@Presentation = 'ForMeToday' 
				AND 
				(
					([TaskRequest].[State] = 2
					AND 
					COALESCE([TaskRequest].[StartTime], [TaskRequest].[DueTime], @Now) < @PeriodEnd)
				OR
					([TaskRequest].[State] = 3 
					AND 
					[TaskRequest].[Modified] BETWEEN @PeriodStart AND @Now)
				)
				AND
					(EXISTS(SELECT * FROM [TaskRequestAssignment] WHERE [TaskRequestAssignment].[TaskRequestID] = [TaskRequest].[ID] AND [TaskRequestAssignment].[EmployeeID]=@CurrentEmployeeID))

					--dbo.fnPjm5IsProjectMember([TaskRequest].[ProjectID], @CurrentEmployeeID) = 1 
					--(EXISTS(SELECT * FROM [vwAssignment] WHERE [vwAssignment].[ProjectID] = [TaskRequest].[ProjectID] AND [vwAssignment].[EmployeeID]=@CurrentEmployeeID))
			)
			OR
			(@Presentation = 'ForMeNext7Days' 
				AND 
				(
					([TaskRequest].[State] = 2
					AND 
					COALESCE([TaskRequest].[StartTime], [TaskRequest].[DueTime], @Now) < @PeriodEnd)
				OR
					([TaskRequest].[State] = 3 
					AND 
					[TaskRequest].[Modified] BETWEEN @PeriodStart AND @Now)
				)
				AND
				(EXISTS(SELECT * FROM [TaskRequestAssignment] WHERE [TaskRequestAssignment].[TaskRequestID] = [TaskRequest].[ID] AND [TaskRequestAssignment].[EmployeeID]=@CurrentEmployeeID))

				--dbo.fnPjm5IsProjectMember([TaskRequest].[ProjectID], @CurrentEmployeeID) = 1 
				--(EXISTS(SELECT * FROM [vwAssignment] WHERE [vwAssignment].[ProjectID] = [TaskRequest].[ProjectID] AND [vwAssignment].[EmployeeID]=@CurrentEmployeeID))
			)
		)	
	RETURN 0
GO

GRANT EXECUTE ON [pjm5TaskRequestBrowse] TO PUBLIC
GO

IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5TaskRequestDocumentBrowse]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
	BEGIN
		PRINT 'Dropping procedure pjm5TaskRequestDocumentBrowse'
		DROP PROCEDURE [dbo].[pjm5TaskRequestDocumentBrowse]
	END
GO

PRINT 'Creating procedure pjm5TaskRequestDocumentBrowse'
GO

SET QUOTED_IDENTIFIER ON
GO

/******************************************************************************
**		File: pjm5TaskRequestDocumentBrowse.sql
**		Name: pjm5TaskRequestDocumentBrowse
**		Desc: this procedure automatically generated by Avicom.Adf.Generator
**
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**      ----------						-----------
**
**		Auth: Andrew.Maklakov
**		Date: 01/20/2005 13:49:21
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
/*CREATE PROCEDURE [pjm5TaskRequestDocumentBrowse]
	@Presentation varchar(32),
	@StateSelector	INT
AS
	SET NOCOUNT ON

	DECLARE @CurrentEmployeeID TIdentifier,
		@CurrentUserID TIdentifier,
		@StartTime datetime,
		@EndTime datetime,
		@Now datetime,
		@IsAssistant TBool
		
	SET @IsAssistant = dbo.adfHasAccessRight(dbo.adfGetRightID('Assistant'))
	SET @CurrentEmployeeID = dbo.adfGetCurrentEmployeeID()
	SET @CurrentUserID = dbo.adfGetCurrentUserID()
	SET @Now = GETDATE()

	IF @Presentation = 'ForMeToday'
	BEGIN
		SET @StartTime = CONVERT(datetime, CONVERT(varchar(8), @Now, 112), 112)
		SET @EndTime = DATEADD(day, 1, @StartTime)
	END
	ELSE IF @Presentation = 'ForMeNext7Days'
	BEGIN
		SET @StartTime = CONVERT(datetime, CONVERT(varchar(8), @Now, 112), 112)
		SET @EndTime = DATEADD(day, 7, @StartTime)
	END
	
	SELECT
		[TaskRequest].[Class],
		[TaskRequest].[ID],
		[TaskRequest].[State],
		[TaskRequest].[Flag],
		[TaskRequest].[FileAs],
		[TaskRequest].[ProjectID],
		[TaskRequest].[PriorityID],
		[TaskRequest].[DueTime],
		[TaskRequest].[StartTime],
		[TaskRequest].[SendStatusReport],
		[TaskRequest].[TaskRequestStatusID],
		[TaskRequest].[PercentComplete],
		(CAST([TaskRequest].[PercentComplete] * 100 as int) / 25) * 25 as PC,
		[TaskRequest].[DocumentCardID],
		[DocumentCard].[FileAs] AS [DocumentCardFileAs],
		[DocumentCard].[CardOwnerID],
		[TaskRequest].[Comments],
		[TaskRequest].[ExternalID],
		[TaskRequest].[Created],
		[TaskRequest].[CreatedBy],
		[TaskRequest].[Modified],
		[TaskRequest].[ModifiedBy],
		[TaskRequest].[Timestamp]
	FROM
		[TaskRequest]
		INNER JOIN [DocumentCard]
			ON [DocumentCard].[ID] = [TaskRequest].[DocumentCardID]
	WHERE
		(@Presentation = 'Own' 
			AND 
			(@StateSelector = 0 OR (@StateSelector = 1 AND [TaskRequest].[State] IN (1, 2))
								OR (@StateSelector = 2 AND [TaskRequest].[State] = 3)
								OR (@StateSelector = 3 AND [TaskRequest].[State] = 4))
			AND
			[TaskRequest].[CreatedBy] = @CurrentUserID
		)
		OR
		(@Presentation = 'All' AND 
			(@StateSelector = 0 OR (@StateSelector != 0 AND [TaskRequest].[State] = @StateSelector))
			AND
			(
				@IsAssistant = 1
				OR
				[TaskRequest].[CreatedBy] = @CurrentUserID 
				OR 
				EXISTS(SELECT * FROM [TaskRequestAssignment] WHERE [TaskRequestAssignment].[TaskRequestID] = [TaskRequest].[ID] AND [TaskRequestAssignment].[EmployeeID]=@CurrentEmployeeID)
				OR
				dbo.fnPjm5IsProjectManager([TaskRequest].[ProjectID], @CurrentEmployeeID) = 1
			)
		)
		OR
		(@Presentation = 'ForMe' 
			AND
			((@StateSelector = 0 AND [TaskRequest].[State] IN (2, 3))
				OR (@StateSelector = 1 AND [TaskRequest].[State] = 2)
				OR (@StateSelector = 2 AND [TaskRequest].[State] = 3))
			AND
			(EXISTS(SELECT * FROM [TaskRequestAssignment] WHERE [TaskRequestAssignment].[TaskRequestID] = [TaskRequest].[ID] AND [TaskRequestAssignment].[EmployeeID]=@CurrentEmployeeID))
		)			
		OR
		(@Presentation = 'ForMeToday' 
			AND 
			(
				([TaskRequest].[State] = 2
				AND 
				COALESCE([TaskRequest].[StartTime], [TaskRequest].[DueTime], @Now) < @EndTime)
			OR
				([TaskRequest].[State] = 3 
				AND 
				[TaskRequest].[Modified] BETWEEN @StartTime AND @Now)
			)
			AND
			(EXISTS(SELECT * FROM [TaskRequestAssignment] WHERE [TaskRequestAssignment].[TaskRequestID] = [TaskRequest].[ID] AND [TaskRequestAssignment].[EmployeeID]=@CurrentEmployeeID))
		)
		OR
		(@Presentation = 'ForMeNext7Days' 
			AND 
			(
				([TaskRequest].[State] = 2
				AND 
				COALESCE([TaskRequest].[StartTime], [TaskRequest].[DueTime], @Now) < @EndTime)
			OR
				([TaskRequest].[State] = 3 
				AND 
				[TaskRequest].[Modified] BETWEEN @StartTime AND @Now)
			)
			AND
			(EXISTS(SELECT * FROM [TaskRequestAssignment] WHERE [TaskRequestAssignment].[TaskRequestID] = [TaskRequest].[ID] AND [TaskRequestAssignment].[EmployeeID]=@CurrentEmployeeID))
		)
			
	RETURN 0*/
GO

--GRANT EXECUTE ON [pjm5TaskRequestDocumentBrowse] TO PUBLIC
GO

