IF EXISTS (SELECT * FROM sysobjects WHERE type = 'TR' AND name = 'pjm6trTaskRequestAssignmentInsert')
	BEGIN
		PRINT 'Dropping Trigger pjm6trTaskRequestAssignmentInsert'
		DROP  Trigger pjm6trTaskRequestAssignmentInsert
	END
GO

/******************************************************************************
**		File: 
**		Name: pjm6trTaskRequestAssignmentInsert
**		Desc: 
**
**		This template can be customized:
**              
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:				Description:
**		--------		--------				-------------------------------------------
**    
*******************************************************************************/

PRINT 'Creating Trigger pjm6trTaskRequestAssignmentInsert'
GO
CREATE TRIGGER pjm6trTaskRequestAssignmentInsert 
ON [TaskRequestAssignment] FOR INSERT
AS
BEGIN
    IF @@rowcount = 0
       RETURN
	SET NOCOUNT ON
	DECLARE @CurrentUserID TIdentifier
	SET @CurrentUserID = dbo.adfGetCurrentUserID()
	
	DELETE 
	FROM [TaskRequestAssignmentResponse]
	FROM [inserted]
	WHERE
		[inserted].[TaskRequestID] = [TaskRequestAssignmentResponse].[TaskRequestID] AND
			[inserted].[EmployeeID] = [TaskRequestAssignmentResponse].[EmployeeID]
	
	INSERT INTO [TaskRequestAssignmentResponse] ([TaskRequestID], [EmployeeID], [Response])
	SELECT [TaskRequestID], [EmployeeID], [Accepted]
	FROM [inserted]
	
	DECLARE @user TIdentifier, @taskrequest TIdentifier, @rv int
	DECLARE users CURSOR FAST_FORWARD FOR
		SELECT
			[inserted].[TaskRequestID], [Employee].[UserID]
		FROM
			[inserted]
			INNER JOIN [TaskRequest]
				ON [TaskRequest].[ID] = [inserted].[TaskRequestID]
			INNER JOIN [Employee]
				ON [inserted].[EmployeeID] = [Employee].[ID]
		WHERE
			[TaskRequest].[State] = 2
	OPEN users
	FETCH NEXT FROM users INTO @taskrequest, @user
	WHILE @@FETCH_STATUS = 0
	BEGIN
		EXEC pjm6TaskRequestAssignmentAppendNotification @taskrequest, @user
		FETCH NEXT FROM users INTO @taskrequest, @user
	END
	CLOSE users
	DEALLOCATE users
END
GO

IF EXISTS (SELECT * FROM sysobjects WHERE type = 'TR' AND name = 'pjm6trTaskRequestAssignmentDelete')
	BEGIN
		PRINT 'Dropping Trigger pjm6trTaskRequestAssignmentDelete'
		DROP  Trigger pjm6trTaskRequestAssignmentDelete
	END
GO

/******************************************************************************
**		File: 
**		Name: pjm6trTaskRequestAssignmentDelete
**		Desc: 
**
**		This template can be customized:
**              
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:				Description:
**		--------		--------				-------------------------------------------
**    
*******************************************************************************/

PRINT 'Creating Trigger pjm6trTaskRequestAssignmentDelete'
GO
CREATE TRIGGER pjm6trTaskRequestAssignmentDelete 
ON [TaskRequestAssignment] FOR DELETE
AS
BEGIN
    IF @@rowcount = 0
       RETURN
	SET NOCOUNT ON
	DECLARE @CurrentUserID TIdentifier
	SET @CurrentUserID = dbo.adfGetCurrentUserID()
	
	DECLARE @user TIdentifier, @taskrequest TIdentifier, @rv int
	DECLARE users CURSOR FAST_FORWARD FOR
		SELECT
			[deleted].[TaskRequestID], [Employee].[UserID]
		FROM
			[deleted]
			INNER JOIN [TaskRequest]
				ON [TaskRequest].[ID] = [deleted].[TaskRequestID]
			INNER JOIN [Employee]
				ON [deleted].[EmployeeID] = [Employee].[ID]
		WHERE
			[TaskRequest].[State] = 2 AND
			[deleted].[Accepted] <> 2
	OPEN users
	FETCH NEXT FROM users INTO @taskrequest, @user
	WHILE @@FETCH_STATUS = 0
	BEGIN
		EXEC pjm6TaskRequestAssignmentDeleteNotification @taskrequest, @user
		FETCH NEXT FROM users INTO @taskrequest, @user
	END
	CLOSE users
	DEALLOCATE users
END
GO

IF EXISTS (SELECT * FROM sysobjects WHERE type = 'TR' AND name = 'pjm6trTaskRequestAssignmentUpdate')
	BEGIN
		PRINT 'Dropping Trigger pjm6trTaskRequestAssignmentUpdate'
		DROP  Trigger pjm6trTaskRequestAssignmentUpdate
	END
GO

/******************************************************************************
**		File: 
**		Name: pjm6trTaskRequestAssignmentInsert
**		Desc: 
**
**		This template can be customized:
**              
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:				Description:
**		--------		--------				-------------------------------------------
**    
*******************************************************************************/

PRINT 'Creating Trigger pjm6trTaskRequestAssignmentUpdate'
GO
CREATE TRIGGER pjm6trTaskRequestAssignmentUpdate 
ON [TaskRequestAssignment] FOR UPDATE
AS
BEGIN
    IF @@rowcount = 0
       RETURN
	SET NOCOUNT ON
			
	UPDATE [TaskRequestAssignmentResponse]
	SET
		[TaskRequestAssignmentResponse].[Response] = [inserted].[Accepted]
	FROM [inserted]
	WHERE 
		[TaskRequestAssignmentResponse].[TaskRequestID] = [inserted].[TaskRequestID] AND
		[TaskRequestAssignmentResponse].[EmployeeID] = [inserted].[EmployeeID]


END
GO