 IF EXISTS (SELECT * FROM sysobjects WHERE type = 'P' AND name = 'pjm5ContactActivityBrowse')
	BEGIN
		PRINT 'Dropping Procedure pjm5ContactActivityBrowse'
		DROP  Procedure  pjm5ContactActivityBrowse
	END

GO

PRINT 'Creating Procedure pjm5ContactActivityBrowse'
GO
/******************************************************************************
**		File: 
**		Name: pjm5ContactActivityBrowse
**		Desc: 
**
**		This template can be customized:
**              
**		Return values:
** 
**		Called by:   
**              
**		Parameters:
**		Input							Output
**     ----------							-----------
**
**		Auth: 
**		Date: 
*******************************************************************************
**		Change History
*******************************************************************************
**		Date:		Author:			Description:
**		--------	--------		-------------------------------------------
**    
*******************************************************************************/
CREATE Procedure pjm5ContactActivityBrowse
	@Class TClass,
	@ID TIdentifier
AS
	SET NOCOUNT ON
	
	DECLARE @TimeEntryClass TClass, 
			@EmployeeClass TClass,
			@CompanyClass TClass,
			@CompanyID TIdentifier
			
	DECLARE
			@ViewAllFinance TBool,
			@CurrentEmployeeID TIdentifier
	SET @ViewAllFinance = dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllFinance'))
	SET @CurrentEmployeeID = dbo.adfGetCurrentEmployeeID()

	SELECT 
		@TimeEntryClass = dbo.adfGetClassByName('Pjm5.TimeEntry'),
		@CompanyClass = dbo.adfGetClassByName('Adf.Company'),
		@EmployeeClass = dbo.adfGetClassByName('Adf.Employee')

	IF @Class = @CompanyClass
	BEGIN
		SELECT DISTINCT
			[TimeEntry].[Class],
			[TimeEntry].[ID],
			[TimeEntry].[State],
			[TimeEntry].[Flag],
			[TimeEntry].[FileAs],
			[TimeEntry].[ActivityTypeID],
			[TimeEntry].[EmployeeID],
			[TimeEntry].[ProjectID],
			[TimeEntry].[TaskID],
			[TimeEntry].[StartTime],
			[TimeEntry].[Duration],
			[TimeEntry].[RoundedDuration],
			[TimeEntry].[Billable],
			[TimeEntry].[BillableDuration],
			[TimeEntry].[Overtime],
			[TimeEntry].[Rate],
			[TimeEntry].[CurrencyCode],
			[TimeEntry].[VATRate],
			CASE 
				WHEN @ViewAllFinance != 1 AND
					[Project].[ProjectManagerEmployeeID] != @CurrentEmployeeID AND
					dbo.fnPjm5IsProjectApprover([Project].[ID], @CurrentEmployeeID) != 1
					THEN -1
				ELSE CAST([TimeEntry].[Billable] AS int) * [TimeEntry].[Rate] * [TimeEntry].[BillableHour]
			END AS [Sum],
			[TimeEntry].[Comments],
			[TimeEntry].[Created],
			[TimeEntry].[CreatedBy],
			[TimeEntry].[Modified],
			[TimeEntry].[ModifiedBy],
			[TimeEntry].[Timestamp],
			CASE
				WHEN [TimeEntry].[TaskID] IS NULL
					THEN (SELECT TOP(1) [DocumentClassName] FROM adfGetDocumentIdentity([TimeEntry].[DocumentID], [TimeEntry].[DocumentClass]))
					ELSE (SELECT dbo.adfGetDocumentClassNameByTable('Task'))
			END AS [DocumentClassName],
			CASE
				WHEN [TimeEntry].[TaskID] IS NULL
					THEN (SELECT TOP(1) [DocumentName] FROM adfGetDocumentIdentity([TimeEntry].[DocumentID], [TimeEntry].[DocumentClass]))
					ELSE (SELECT [Task].[FileAs] FROM [Task] WHERE [Task].[ID] = [TimeEntry].[TaskID])
			END AS [DocumentName]
		FROM
			[vwTimeEntry] as [TimeEntry]
			INNER JOIN [DocumentContact]
				ON ([TimeEntry].[ID] = [DocumentContact].[DocumentID] AND 
					[DocumentContact].[DocumentClass] = @TimeEntryClass)
			INNER JOIN 
				(SELECT 
						@ID as [ID], 
						@Class as [Class]
				UNION ALL
				SELECT
					[ID],
					[Class]
				FROM
					[Employee]
				WHERE
					[Employee].[CompanyID] = @ID) as [Contact]
				ON ([DocumentContact].[BusinessCardClass] = [Contact].[Class] AND
					[DocumentContact].[BusinessCardID] = [Contact].[ID])
			INNER JOIN [Project]
				ON [Project].[ID] = [TimeEntry].[ProjectID]
	END
	ELSE
	BEGIN
		SELECT
			[TimeEntry].[Class],
			[TimeEntry].[ID],
			[TimeEntry].[State],
			[TimeEntry].[Flag],
			[TimeEntry].[FileAs],
			[TimeEntry].[ActivityTypeID],
			[TimeEntry].[EmployeeID],
			[TimeEntry].[ProjectID],
			[TimeEntry].[TaskID],
			[TimeEntry].[StartTime],
			[TimeEntry].[Duration],
			[TimeEntry].[RoundedDuration],
			[TimeEntry].[Billable],
			[TimeEntry].[BillableDuration],
			[TimeEntry].[Overtime],
			[TimeEntry].[Rate],
			[TimeEntry].[CurrencyCode],
			[TimeEntry].[VATRate],
			CASE 
				WHEN @ViewAllFinance != 1 AND
					[Project].[ProjectManagerEmployeeID] != @CurrentEmployeeID AND
					[vwAssignment].[Approver] != 1
					THEN -1
				ELSE CAST([TimeEntry].[Billable] AS int) * [TimeEntry].[Rate] * [TimeEntry].[BillableHour]
			END AS [Sum],
			[TimeEntry].[Comments],
			[TimeEntry].[Created],
			[TimeEntry].[CreatedBy],
			[TimeEntry].[Modified],
			[TimeEntry].[ModifiedBy],
			[TimeEntry].[Timestamp],
			CASE
				WHEN [TimeEntry].[TaskID] IS NULL
					THEN (SELECT TOP(1) [DocumentClassName] FROM adfGetDocumentIdentity([TimeEntry].[DocumentID], [TimeEntry].[DocumentClass]))
					ELSE (SELECT dbo.adfGetDocumentClassNameByTable('Task'))
			END AS [DocumentClassName],
			CASE
				WHEN [TimeEntry].[TaskID] IS NULL
					THEN (SELECT TOP(1) [DocumentName] FROM adfGetDocumentIdentity([TimeEntry].[DocumentID], [TimeEntry].[DocumentClass]))
					ELSE (SELECT [Task].[FileAs] FROM [Task] WHERE [Task].[ID] = [TimeEntry].[TaskID])
			END AS [DocumentName]
			
		FROM
			[vwTimeEntry] as [TimeEntry]
			INNER JOIN [DocumentContact]
				ON ([TimeEntry].[ID] = [DocumentContact].[DocumentID] AND 
					[DocumentContact].[DocumentClass] = @TimeEntryClass)
			INNER JOIN [Project]
				ON [Project].[ID] = [TimeEntry].[ProjectID]
			LEFT OUTER JOIN [vwAssignment]
				ON [vwAssignment].[ProjectID] = [Project].[ID] AND
					[vwAssignment].[EmployeeID] = @CurrentEmployeeID AND
					[vwAssignment].[State] = 1
		WHERE
			[BusinessCardClass] = @Class AND [BusinessCardID] = @ID
	END
	RETURN 0
GO

GRANT EXEC ON pjm5ContactActivityBrowse TO PUBLIC
GO
