 IF EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[pjm5vwExpense]') and OBJECTPROPERTY(id, N'IsView') = 1)
	BEGIN
		PRINT 'Dropping view pjm5vwExpense'
		DROP VIEW [dbo].[pjm5vwExpense]
	END
GO

PRINT 'Creating view pjm5vwExpense'
GO

CREATE VIEW [pjm5vwExpense]
AS
	SELECT
		[Expense].[Class],
		[Expense].[ID],
		[Expense].[State],
		[Expense].[Flag],
		[Expense].[FileAs],
		[Expense].[EmployeeID],
		[Expense].[ProjectID],
		[Expense].[TaskID],
		[Expense].[ExpenseCodeID],
		[Expense].[Date],
		[Expense].[Amount],
		[Expense].[Billable],
		CASE
			WHEN 
				[Project].[ViewAllFinance] != 1 AND
				[Project].[ProjectManagerEmployeeID] != [Project].[CurrentEmployeeID] AND
				[Project].[ExpenseSecretary] != 1 AND
				[Expense].[EmployeeID] != [Project].[CurrentEmployeeID] AND
				[Expense].[CreatedBy] != [Project].[CurrentUserID] AND
				NOT ([vwAssignment].[Approver] = 1 OR [vwAssignment].[Administrator] = 1) AND
				dbo.fnPjm5HasFinansDataAccess([Project].[ID], [Project].[CurrentEmployeeID], NULL, NULL) != 1
				THEN -1000
			ELSE
				[Expense].[Price]
		END AS [Price],
		[Expense].[FromCurrencyCode],
		[Expense].[ToCurrencyCode],
		[Expense].[CurrencyRate],
		[Expense].[VATRate],
		CASE
			WHEN 
				[Project].[ViewAllFinance] != 1 AND
				[Project].[ProjectManagerEmployeeID] != [Project].[CurrentEmployeeID] AND
				[Project].[ExpenseSecretary] != 1 AND
				[Expense].[EmployeeID] != [Project].[CurrentEmployeeID] AND
				[Expense].[CreatedBy] != [Project].[CurrentUserID] AND
				NOT ([vwAssignment].[Approver] = 1 OR [vwAssignment].[Administrator] = 1) AND
				dbo.fnPjm5HasFinansDataAccess([Project].[ID], [Project].[CurrentEmployeeID], NULL, NULL) != 1
				THEN -1000
			ELSE
				[Expense].[VAT]
		END AS [VAT],
		[Expense].[VATIsIncluded],
		[Expense].[Comments],
		[Expense].[Created],
		[Expense].[CreatedBy],
		[Expense].[Modified],
		[Expense].[ModifiedBy],
		[Expense].[Timestamp],
		[Expense].[DocumentClass],
		[Expense].[DocumentID],
		CASE
			WHEN 
				[Project].[ViewAllFinance] != 1 AND
				[Project].[ProjectManagerEmployeeID] != [Project].[CurrentEmployeeID] AND
				[Project].[ExpenseSecretary] != 1 AND
				[Expense].[EmployeeID] != [Project].[CurrentEmployeeID] AND
				[Expense].[CreatedBy] != [Project].[CurrentUserID] AND
				NOT ([vwAssignment].[Approver] = 1 OR [vwAssignment].[Administrator] = 1) AND
				dbo.fnPjm5HasFinansDataAccess([Project].[ID], [Project].[CurrentEmployeeID], NULL, NULL) != 1
				THEN -1000
			ELSE
				CASE [Expense].[VATIsIncluded]
					WHEN 1 THEN 
						ISNULL([Expense].[Amount] * [Expense].[Price] - [Expense].[VAT], 0)
					ELSE ISNULL([Expense].[Amount] * [Expense].[Price] , 0)
				END 
		END AS [SumExpense],

		CASE
			WHEN 
				[Project].[ViewAllFinance] != 1 AND
				[Project].[ProjectManagerEmployeeID] != [Project].[CurrentEmployeeID] AND
				[Project].[ExpenseSecretary] != 1 AND
				[Expense].[EmployeeID] != [Project].[CurrentEmployeeID] AND
				[Expense].[CreatedBy] != [Project].[CurrentUserID] AND
				NOT ([vwAssignment].[Approver] = 1 OR [vwAssignment].[Administrator] = 1) AND
				dbo.fnPjm5HasFinansDataAccess([Project].[ID], [Project].[CurrentEmployeeID], NULL, NULL) != 1
				THEN -1000
			ELSE [Expense].[TotalPC]
		END AS [SumProjectCurrency],

		CASE
			WHEN 
				[Project].[ViewAllFinance] != 1 AND
				[Project].[ProjectManagerEmployeeID] != [Project].[CurrentEmployeeID] AND
				[Project].[ExpenseSecretary] != 1 AND
				[Expense].[EmployeeID] != [Project].[CurrentEmployeeID] AND
				[Expense].[CreatedBy] != [Project].[CurrentUserID] AND
				NOT ([vwAssignment].[Approver] = 1 OR [vwAssignment].[Administrator] = 1) AND
				dbo.fnPjm5HasFinansDataAccess([Project].[ID], [Project].[CurrentEmployeeID], NULL, NULL) != 1
				THEN -1000
			ELSE
				CASE [Expense].[VATIsIncluded]
					WHEN 1 THEN 
						ISNULL([Expense].[Amount] * [Expense].[Price], 0)
					ELSE ISNULL([Expense].[Amount] * [Expense].[Price]  + [Expense].[VAT], 0)
			END
		END AS [TotalSumExpense],

		CASE
			WHEN 
				[Project].[ViewAllFinance] != 1 AND
				[Project].[ProjectManagerEmployeeID] != [Project].[CurrentEmployeeID] AND
				[Project].[ExpenseSecretary] != 1 AND
				[Expense].[EmployeeID] != [Project].[CurrentEmployeeID] AND
				[Expense].[CreatedBy] != [Project].[CurrentUserID] AND
				NOT ([vwAssignment].[Approver] = 1 OR [vwAssignment].[Administrator] = 1) AND
				dbo.fnPjm5HasFinansDataAccess([Project].[ID], [Project].[CurrentEmployeeID], NULL, NULL) != 1
				THEN -1000
			ELSE [Expense].[TotalWithVATPC]
		END AS [TotalSumProjectCurrency]
	FROM
		[Expense]
		INNER JOIN (
			SELECT
				dbo.adfHasAccessRight(dbo.adfGetRightID('ViewAllFinance')) AS [ViewAllFinance],
				dbo.adfGetCurrentEmployeeID() AS [CurrentEmployeeID],
				dbo.adfGetCurrentUserID() AS [CurrentUserID],
				dbo.adfHasAccessRightByName('ManageExpenseWithoutAssignment') AS [ExpenseSecretary],
				[ID],
				[ProjectManagerEmployeeID]
			FROM
				[Project]
			) AS [Project]
			ON [Project].[ID] = [Expense].[ProjectID]
		LEFT OUTER JOIN [vwAssignment]
			ON [vwAssignment].[ProjectID] = [Project].[ID] and 
				[vwAssignment].[EmployeeID] = [Project].[CurrentEmployeeID] AND
				[vwAssignment].[State] = 1
	
GO
  